@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,16 @@
 #ifndef AI_ENGINE
 #define AI_ENGINE
 
-class AIengine
+#include <WORMUX_singleton.h>
+
+class AIengine : public Singleton<AIengine>
 {
- private:
-  static AIengine * singleton;
+protected:
+  friend class Singleton<AIengine>;
   AIengine();
 
  public:
-  static AIengine* GetInstance();
-  void Refresh();
+  void Refresh() const;
 };
 
 #endif
