@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #define AI_MOVEMENT_MODULE
 
 #include "include/base.h"
-#include "tool/point.h"
+#include <WORMUX_point.h>
 #include <set>
 
 class Character;
