@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,8 @@
 #include "team/macro.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-
+#include "include/app.h"
+#include "graphic/video.h"
 #include <iostream>
 
 
@@ -46,12 +47,53 @@ const Character* AIShootModule::FindShootableEnemy(const Character& shooter,
   FOR_ALL_LIVING_ENEMIES(shooter, team, character)
   {
     if ( IsDirectlyShootable(shooter, *character, shoot_angle) ) {
+      //TODO: don't return as soon as a match is found, but return the best
       return &(*character);
     }
   }
   return NULL;
 }
 
+// =================================================
+// Static method
+// =================================================
+// Returns true if not dangerous as the shooter pulls enemy
+// else returns false.
+// For example if the shooter with a given angle is in front of wall
+// he doesn't need to shoot the enemy (otherwises he shoots itself).
+// =================================================
+//
+//
+bool AIShootModule::IsBazookable(const Character& shooter,
+                                 double& angle)
+{
+  ActiveTeam().SetWeapon(Weapon::WEAPON_BAZOOKA); //see note in IsDirectlyShootable
+  Point2i tmp = ActiveTeam().GetWeapon().GetGunHolePosition();
+  // Set the rotation of "angle" radians
+  Point2i pos = Point2i::FromPolarCoordinates(sqrt(double(tmp.x * tmp.x + tmp.y * tmp.y)), double(tmp.ComputeAngle() + angle));
+
+  Point2i delta = Point2i(1, 0);
+  Point2i shoot_pos = shooter.GetCenter();
+
+  // Affine equation : y = ax + b.
+  double a = tan(angle);
+  double b = pos.y - (a * pos.x);
+  int distance = 0;
+
+  while (distance < 30)
+    {
+      if ( GetWorld().IsOutsideWorldX(pos.x) || GetWorld().IsOutsideWorldY(pos.y) ) {
+        break;
+      }
+      if (!GetWorld().IsInVacuum(pos.x, pos.y))
+        return false;
+      pos += delta;
+      pos.y = int(a * pos.x + b);
+      distance = shoot_pos.Distance(pos);
+    }
+  return true;
+}
+
 // =================================================
 // Static method
 // =================================================
@@ -60,33 +102,49 @@ const Character* AIShootModule::FindShootableEnemy(const Character& shooter,
 // potential enemy
 // Update the shoot_angle if it is ok
 // =================================================
-// This method is not perfect
-// It tests from the Center of the shooter
-// and not from the gun hole
-// =================================================
 bool AIShootModule::IsDirectlyShootable(const Character& shooter,
                                         const Character& enemy,
                                         double& shoot_angle)
 {
-  Point2i pos = shooter.GetCenter();
-  Point2i arrival = enemy.GetCenter();
-  Point2i departure = pos;
-  Point2i delta_pos;
+  // We need to use center point, because gunholePosition is location
+  // of last weapon of the ActiveTeam() and not the future gunholePos
+  // which will be select.
+
+  // HACK: use the gun to get a gunhole position
+  ActiveTeam().SetWeapon(Weapon::WEAPON_GUN);
+
+  // TODO: Please find an alternative to solve this tempory solution
+  Point2d pos = POINT2I_2_POINT2D(ActiveTeam().GetWeapon().GetGunHolePosition());
+  Point2d arrival = enemy.GetCenter();
 
   double original_angle = pos.ComputeAngle(arrival);
 
+  int delta_x = (pos.x > arrival.x) ? -1 : 1;
+  double a = tan(original_angle);
+  double b = pos.y - (a * pos.x);
+  uint ground_hitcount = 0;
+
   // compute to see if there any part of ground between the 2 characters
   // While test is not finished
   while (pos != arrival) {
-
-    // is there a collision on the ground ??
-    if (!world.IsInVacuum(pos.x, pos.y)) {
-      return false;
-    }
+    // XXX is rounding fine?
+    Point2i posi(int(pos.x+0.5), int(pos.y+0.5));
 
     // the point is outside the map
-    if ( world.IsOutsideWorldX(pos.x) || world.IsOutsideWorldY(pos.y) ) {
-      break;
+    if ( GetWorld().IsOutsideWorld(posi) )
+      {
+        return false;
+      }
+
+    // is there a collision on the ground ??
+    if (!GetWorld().IsInVacuum(posi)) {
+      // allow two pixels of slack - rifles have more than one shot, so
+      // don't let a thin wall or a top of a hill (shotgun) deter us
+      if (ground_hitcount < 3) {
+        ground_hitcount++;
+      } else {
+        return false;
+      }
     }
 
     // is there a collision with another character ?
@@ -94,12 +152,18 @@ bool AIShootModule::IsDirectlyShootable(const Character& shooter,
       if ( &(*other_character) != &shooter
            && &(*other_character) != &enemy ) {
 
-        if ( other_character->GetTestRect().Contains(pos) )
+        // Skip only if this character has the same team of shooter
+        // otherwises he's a enemy. (more reachable than the current)
+        if (other_character->GetTestRect().Contains(pos)
+            && (&other_character->GetTeam()) == (&shooter.GetTeam())) {
           return false;
-
+        }
       }
     }
-
+      pos.x += delta_x;
+      pos.y = a * pos.x + b;
+  }
+    /*
     // next step
     int diff_x = pos.x - arrival.x;
     int diff_y = pos.y - arrival.y;
@@ -122,52 +186,65 @@ bool AIShootModule::IsDirectlyShootable(const Character& shooter,
     pos += delta_pos;
   }
 
+
   // set the angle
   if (departure.x > arrival.x) {
     shoot_angle = InverseAngleRad(original_angle);
   } else {
     shoot_angle = original_angle;
   }
+    */
+  shoot_angle = original_angle;
 
   return true;
 }
 
 bool AIShootModule::SelectFiringWeapon(double /*shoot_angle*/) const
 {
-  // we choose between gun, sniper_rifle, shotgun and submachine gun
-  uint selected = uint(randomSync.GetDouble(0.0, 3.5));
-  switch (selected) {
-  case 0:
-    ActiveTeam().SetWeapon(Weapon::WEAPON_SHOTGUN);
-    if (ActiveTeam().GetWeapon().EnoughAmmo()) break;
-  case 1:
-    ActiveTeam().SetWeapon(Weapon::WEAPON_SNIPE_RIFLE);
-    if (ActiveTeam().GetWeapon().EnoughAmmo()) break;
-  case 2:
-    ActiveTeam().SetWeapon(Weapon::WEAPON_SUBMACHINE_GUN);
-    if (ActiveTeam().GetWeapon().EnoughAmmo()) break;
-  case 3:
-  default:
-    ActiveTeam().SetWeapon(Weapon::WEAPON_GUN);
-  }
+  // first create a list of usable weapons
+  std::vector<Weapon::Weapon_type> usable_weapons;
+  GetUsableFiringWeapons(usable_weapons);
 
-  // Check the angle
-  double angle = InRange_Double(m_angle, - (ActiveTeam().GetWeapon().GetMaxAngle()),
-                             - (ActiveTeam().GetWeapon().GetMinAngle()) );
+  uint count = usable_weapons.size();
+  if (count == 0) return false;
 
-  if (AbsoluteValue(angle-m_angle) > 0.08726/* 5 degree */) {
-    // angle is too wide for the weapon
-    return false;
-  }
-
-  // Check number of ammo
-  if ( ! ActiveTeam().GetWeapon().EnoughAmmo() ) {
-    return false;
-  }
+  // randomly choose a good one
+  // TODO: in the future add logic to discriminate between weapons
+  MSG_DEBUG("random.get", "AIShootModule::SelectFiringWeapon(...)");
+  uint selected = RandomSync().GetUint(0, count-1);
+  ActiveTeam().SetWeapon(usable_weapons.at(selected));
 
   return true;
 }
 
+void AIShootModule::GetUsableFiringWeapons(std::vector<Weapon::Weapon_type>& usable_weapons) const
+{
+  Weapon::Weapon_type weapon;
+
+  // all weapons from the RIFLE category minus the flamethrower
+  Weapon::Weapon_type weapons[4] = {Weapon::WEAPON_GUN, Weapon::WEAPON_SHOTGUN, Weapon::WEAPON_SNIPE_RIFLE, Weapon::WEAPON_SUBMACHINE_GUN };
+
+  // we choose between gun, sniper_rifle, shotgun and submachine gun
+  for (int i=0; i < 3; i++) {
+    weapon = weapons[i];
+    ActiveTeam().SetWeapon(weapon);
+
+    // Check the ammo
+    if (! ActiveTeam().GetWeapon().EnoughAmmo()) continue;
+
+    // Check the angle
+    double angle = InRange_Double(m_angle, - (ActiveTeam().GetWeapon().GetMaxAngle()),
+                             - (ActiveTeam().GetWeapon().GetMinAngle()) );
+    if (AbsoluteValue(angle-m_angle) > 0.03490/* 2 degrees */) {
+      // angle is too wide for the weapon
+      continue;
+    }
+
+    // the weapon is usable
+    usable_weapons.push_back(weapon);
+  }
+}
+
 // =================================================
 // Try to find an enemy which is shootable by
 // weapons like dynamite, mine, ...
@@ -202,6 +279,7 @@ bool AIShootModule::SelectProximityWeapon(const Character& enemy) const
 //   }
 
   // Dynamite
+  //TODO: also check there is no friendly character near
   if (life_points > 50) {
     ActiveTeam().SetWeapon(Weapon::WEAPON_DYNAMITE);
     if (ActiveTeam().GetWeapon().EnoughAmmo())
@@ -230,18 +308,29 @@ void AIShootModule::ShootWithBazooka()
     std::cout << "Ye = " << Ye << std::endl;
     std::cout << "Xs = " << Xs << std::endl;
     std::cout << "Ys = " << Ys << std::endl;
-    double angle = atan(wind.GetStrength() * 75.0 /*wind factor */ /(30.0/* g */ *20 /* mass*/) );
-    double Xpe = (Xe - Xs) * cos(angle) - (Ye - Ys) * sin(angle) + Xs;
-    double Ype = (Xe - Xs) * sin(angle) + (Ye - Ys) * cos(angle) + Ys;
-    Xe = Xpe;
-    Ye = Ype;
-    double V0x = (Xe - Xs ) / 80;
-    double V0y = V0x * (Ye - (Ys))/ (Xe - Xs -V0x) - 1/2.0 * sqrt(30*30 /* g² */+ wind.GetStrength() * 75.0 *wind.GetStrength() * 75.0  /20.0 /20.0 /* W²/m²*/ )  / V0x * (Xe - Xs - V0x)/40 /* pixel per metre */;
+    double angle = atan(Wind::GetRef().GetStrength() * 75.0 /*wind factor */ /(30.0/* g */ *20 /* mass*/) );
+
+    if (!IsBazookable(ActiveCharacter(), angle))
+      {
+        MSG_DEBUG("ai.shoot", "%s is not bazookable !\n", m_enemy->GetName().c_str());
+        //MSG_DEBUG("ai.shoot", "%s is not bazookable !", m_enemy.GetName());
+        ActiveTeam().SetWeapon(Weapon::WEAPON_SKIP_TURN);
+        Shoot();
+      }
+    else
+      {
+        double Xpe = (Xe - Xs) * cos(angle) - (Ye - Ys) * sin(angle) + Xs;
+        double Ype = (Xe - Xs) * sin(angle) + (Ye - Ys) * cos(angle) + Ys;
+        Xe = Xpe;
+        Ye = Ype;
+        double V0x = (Xe - Xs ) / 80;
+        double V0y = V0x * (Ye - (Ys))/ (Xe - Xs -V0x) - 1/2.0 * sqrt(30*30 /* g */+ Wind::GetRef().GetStrength() * 75.0 *Wind::GetRef().GetStrength() * 75.0  /20.0 /20.0 /* W/m*/ )  / V0x * (Xe - Xs - V0x)/40 /* pixel per metre */;
 
 
-    std::cout << "shooting " << V0x <<" "  <<"   " << V0y << " "<< " " <<  atan(V0y/V0x) << " " <<m_enemy->GetName() << std::endl;
-    ActiveTeam().AccessWeapon().PrepareShoot(sqrt(V0y*V0y + V0x*V0x), /*Xe*/m_enemy->GetCenterX() - Xs > 0 ? atan(V0y/V0x) - angle: -atan(V0y/V0x) + angle);
-    m_last_shoot_time = m_current_time;
+        std::cout << "shooting " << V0x <<" "  <<"   " << V0y << " "<< " " <<  atan(V0y/V0x) << " " <<m_enemy->GetName() << std::endl;
+        ActiveTeam().AccessWeapon().PrepareShoot(sqrt(V0y*V0y + V0x*V0x), /*Xe*/m_enemy->GetCenterX() - Xs > 0 ? atan(V0y/V0x) - angle: -atan(V0y/V0x) + angle);
+        m_last_shoot_time = m_current_time;
+      }
   }
 }
 
@@ -280,35 +369,20 @@ const Character* AIShootModule::FindEnemy()
 
   SetStrategy(NO_STRATEGY);
 
-  // Proximity enemy ?
-  m_enemy = FindProximityEnemy(ActiveCharacter());
-  if ( m_enemy != NULL ) {
-
-    SetStrategy(NEAR_FROM_ENEMY);
-
-    GameMessages::GetInstance()->Add(ActiveCharacter().GetName()+" has decided to injure "
-                                     + m_enemy->GetName());
-
-    if ( SelectProximityWeapon(*m_enemy) ) {
-      m_angle = 0;
-      ActiveCharacter().SetFiringAngle(m_angle);
-      return m_enemy;
-    }
-  }
-
   // "Gun-able" enemy ?
   m_enemy = FindShootableEnemy(ActiveCharacter(), m_angle);
   if ( m_enemy != NULL ) {
 
     SetStrategy(SHOOT_FROM_POINT);
 
-    GameMessages::GetInstance()->Add(ActiveCharacter().GetName()+" will shoot "
-                                     + m_enemy->GetName());
+    GameMessages::GetInstance()->Add(Format(_("%s will shoot %s"), ActiveCharacter().GetName().c_str(), m_enemy->GetName().c_str()));
 
     // we choose between gun, sniper_rifle, shotgun and submachine gun
     if ( SelectFiringWeapon(m_angle) ) {
       ActiveCharacter().SetFiringAngle(m_angle);
       return m_enemy;
+    } else {
+      m_enemy = NULL;
     }
   }
 
@@ -318,6 +392,21 @@ const Character* AIShootModule::FindEnemy()
     return m_enemy;
   }
 
+  // Proximity enemy ?
+  m_enemy = FindProximityEnemy(ActiveCharacter());
+  if ( m_enemy != NULL ) {
+
+    SetStrategy(NEAR_FROM_ENEMY);
+
+    GameMessages::GetInstance()->Add(Format(_("%s has decided to injure %s"), ActiveCharacter().GetName().c_str(), m_enemy->GetName().c_str()));
+
+    if ( SelectProximityWeapon(*m_enemy) ) {
+      m_angle = 0;
+      ActiveCharacter().SetFiringAngle(m_angle);
+      return m_enemy;
+    }
+  }
+
   m_current_strategy = NO_STRATEGY;
   m_angle = 0;
   m_enemy = NULL;
@@ -328,12 +417,17 @@ const Character* AIShootModule::FindEnemy()
 void AIShootModule::ChooseDirection() const
 {
   if ( m_enemy ) {
-    // TODO : Replace by a more clever function
+    // TODO : Replace by a cleverer function
     if ( abs(ActiveCharacter().GetCenterX() - m_enemy->GetCenterX()) <= 10 )
       return;
+    if (m_enemy->GetTestRect().Intersect(ActiveCharacter().GetTestRect()))
+      {
+        MSG_DEBUG("ai.shoot","%s is on or next to %s", ActiveCharacter().GetName().c_str(), m_enemy->GetName().c_str());
+        return;
+      }
 
-    MSG_DEBUG("ai", "Character: %d, enemy %d", 
-	      ActiveCharacter().GetCenterX(), m_enemy->GetCenterX());
+    MSG_DEBUG("ai", "Character: %d, enemy %d",
+              ActiveCharacter().GetCenterX(), m_enemy->GetCenterX());
 
     if ( ActiveCharacter().GetCenterX() < m_enemy->GetCenterX())
       ActiveCharacter().SetDirection(DIRECTION_RIGHT);
@@ -350,8 +444,7 @@ bool AIShootModule::Refresh(uint current_time)
   }
 
   m_current_time = current_time;
-
-  FindEnemy();
+  m_enemy = FindEnemy();
   ChooseDirection();
 
   switch (m_current_strategy) {
@@ -366,13 +459,16 @@ bool AIShootModule::Refresh(uint current_time)
     FOR_ALL_LIVING_ENEMIES(ActiveCharacter(), team, character) {
 //      if ( abs((*character).GetX() - ActiveCharacter().GetX()) <= 10 &&
 //                 abs ((*character).GetY() - ActiveCharacter().GetY()) < 60 ) {
-        if ( (*character).GetCenter().Distance( ActiveCharacter().GetCenter()) < 30) {
+        if ( (*character).GetCenter().Distance( ActiveCharacter().GetCenter()) < 40) {
               if (&(*character) != m_enemy) {
-                GameMessages::GetInstance()->Add(ActiveCharacter().GetName()+" changes target : "
-                                                 + (*character).GetName());
+                GameMessages::GetInstance()->Add(Format(_("%s changes target to %s"),
+							ActiveCharacter().GetName().c_str(),
+							(*character).GetName().c_str()));
               }
                m_enemy = &(*character);
                Shoot();
+               // If IA selected ProximityWeapon, he needs to go back, in the opposite direction (otherwises BOOM :-) )
+               ActiveCharacter().SetDirection( (ActiveCharacter().GetDirection()==DIRECTION_RIGHT) ? DIRECTION_LEFT : DIRECTION_RIGHT);
       }
     }
     break;
@@ -407,7 +503,8 @@ void AIShootModule::BeginTurn()
   SetStrategy(NO_STRATEGY);
 
   // Choose random direction for the moment
-  ActiveCharacter().SetDirection( randomSync.GetBool()?DIRECTION_LEFT:DIRECTION_RIGHT );
+  MSG_DEBUG("random.get", "AIShootModule::BeginTurn(...)");
+  ActiveCharacter().SetDirection( RandomSync().GetBool()?DIRECTION_LEFT:DIRECTION_RIGHT );
 }
 
 AIShootModule::AIShootModule(const AIMovementModule& to_remove) :
@@ -425,8 +522,8 @@ AIShootModule::AIShootModule(const AIMovementModule& to_remove) :
 void AIShootModule::SetStrategy(strategy_t new_strategy)
 {
   if (m_current_strategy != new_strategy) {
-    MSG_DEBUG("ai", "%s changes his strategy: %d -> %d", 
-	      ActiveCharacter().GetName().c_str(), m_current_strategy, new_strategy);
+    MSG_DEBUG("ai", "%s changes his strategy: %d -> %d",
+              ActiveCharacter().GetName().c_str(), m_current_strategy, new_strategy);
     if (IsLOGGING("ai")) {
       std::cout << "SetStrategy: " << new_strategy << std::endl;
     }
