@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,11 +22,14 @@
 #ifndef AI_SHOOT_MODULE_H
 #define AI_SHOOT_MODULE_H
 
+#include <vector>
 #include "include/base.h"
+#include "weapon/weapon.h"
 
 // Forward declararion
 class AIMovementModule;
 class Character;
+class Weapon;
 
 class AIShootModule
 {
@@ -62,10 +65,14 @@ class AIShootModule
                                   const Character& enemy,
                                   double& shoot_angle);
 
+  static bool IsBazookable(const Character& shooter, 
+			   double& angle);
+
   static const Character* FindShootableEnemy(const Character& shooter,
                                              double& shoot_angle);
 
   bool SelectFiringWeapon(double shoot_angle) const;
+  void GetUsableFiringWeapons(std::vector<Weapon::Weapon_type>& usable_weapons) const;
 
   void ShootWithBazooka();
   const Character* FindBazookaShootableEnemy(const Character& shooter) const;
