@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include <sstream>
 #include <iostream>
 #include <map>
+#include <WORMUX_debug.h>
 #include "character/body.h"
 #include "character/character.h"
 #include "character/clothe.h"
@@ -31,26 +32,25 @@
 #include "interface/mouse.h"
 #include "particles/body_member.h"
 #include "particles/teleport_member.h"
+#include "network/randomsync.h"
 #include "team/team.h"
 #include "team/teams_list.h"
-#include "tool/debug.h"
-#include "tool/random.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
 
-Body::Body(const xmlNode* xml, const Profile* res):
+Body::Body(const xmlNode* xml, const std::string& main_folder):
   members_lst(),
   clothes_lst(),
   mvt_lst(),
   current_clothe(NULL),
   current_mvt(NULL),
-  play_once_mvt_sauv(NULL),
-  play_once_clothe_sauv(NULL),
-  play_once_frame_sauv(0),
+  current_loop(0),
+  current_frame(0),
+  previous_clothe(NULL),
+  previous_mvt(NULL),
   weapon_member(new WeaponMember()),
   weapon_pos(0,0),
   last_refresh(0),
-  current_frame(0),
   walk_events(0),
   main_rotation_rad(0),
   skel_lst(),
@@ -59,28 +59,36 @@ Body::Body(const xmlNode* xml, const Profile* res):
   need_rebuild(false),
   owner(NULL)
 {
-  xmlNodeArray nodes = XmlReader::GetNamedChildren(xml, "sprite");
+  const xmlNode *skeletons = XmlReader::GetMarker(xml, "skeletons");
+  ASSERT(skeletons);
+
+  xmlNodeArray nodes = XmlReader::GetNamedChildren(skeletons, "sprite");
   xmlNodeArray::const_iterator it;
 
   // Load members
-  MSG_DEBUG("body", "Found %i sprites\n", nodes.size());
+  MSG_DEBUG("body", "Found %i sprites", nodes.size());
   for (it = nodes.begin(); it != nodes.end(); ++it)
   {
     std::string name;
     XmlReader::ReadStringAttr(*it, "name", name);
 
-    Member* member = new Member(*it, res);
-    if (members_lst.find(name) != members_lst.end())
+    MSG_DEBUG("body", "Loading member %s", name.c_str());
+    Member* member = new Member(*it, main_folder);
+    if (members_lst.find(name) != members_lst.end()) {
       std::cerr << "Warning !! The member \""<< name << "\" is defined twice in the xml file" << std::endl;
-    else
+      ASSERT(false);
+    } else
       members_lst[name] = member;
   }
 
   members_lst["weapon"] = weapon_member;
 
   // Load clothes
-  nodes = XmlReader::GetNamedChildren(xml, "clothe");
-  MSG_DEBUG("body", "Found %i clothes\n", nodes.size());
+  const xmlNode *clothes = XmlReader::GetMarker(xml, "clothes");
+  ASSERT(clothes);
+
+  nodes = XmlReader::GetNamedChildren(clothes, "clothe");
+  MSG_DEBUG("body", "Found %i clothes", nodes.size());
   for (it = nodes.begin(); it != nodes.end(); ++it)
   {
     std::string name;
@@ -94,9 +102,12 @@ Body::Body(const xmlNode* xml, const Profile* res):
   }
 
   // Load movements alias
+  const xmlNode *aliases = XmlReader::GetMarker(xml, "aliases");
+  ASSERT(aliases);
+
   std::map<std::string, std::string> mvt_alias;
-  nodes = XmlReader::GetNamedChildren(xml, "alias");
-  MSG_DEBUG("body", "Found %i aliases\n", nodes.size());
+  nodes = XmlReader::GetNamedChildren(aliases, "alias");
+  MSG_DEBUG("body", "Found %i aliases", nodes.size());
   for (it = nodes.begin(); it != nodes.end(); ++it)
   {
     std::string mvt, corresp;
@@ -107,8 +118,11 @@ Body::Body(const xmlNode* xml, const Profile* res):
   }
 
   // Load movements
-  nodes = XmlReader::GetNamedChildren(xml, "movement");
-  MSG_DEBUG("body", "Found %i movements\n", nodes.size());
+  const xmlNode *movements = XmlReader::GetMarker(xml, "movements");
+  ASSERT(movements);
+
+  nodes = XmlReader::GetNamedChildren(movements, "movement");
+  MSG_DEBUG("body", "Found %i movements", nodes.size());
   for (it = nodes.begin(); it != nodes.end(); ++it)
   {
     std::string name;
@@ -127,7 +141,7 @@ Body::Body(const xmlNode* xml, const Profile* res):
       if (iter->second == name)
       {
         Movement* mvt = new Movement(*it);
-        mvt->type = iter->first;
+        mvt->SetType(iter->first);
         mvt_lst[iter->first] = mvt;
       }
   }
@@ -138,7 +152,6 @@ Body::Body(const xmlNode* xml, const Profile* res):
     std::cerr << "Error: The movement \"black\" or the clothe \"black\" is not defined!" << std::endl;
     exit(EXIT_FAILURE);
   }
-
 }
 
 Body::Body(const Body& _body):
@@ -146,13 +159,13 @@ Body::Body(const Body& _body):
   mvt_lst(),
   current_clothe(NULL),
   current_mvt(NULL),
-  play_once_mvt_sauv(NULL),
-  play_once_clothe_sauv(NULL),
-  play_once_frame_sauv(0),
+  current_loop(0),
+  current_frame(0),
+  previous_clothe(NULL),
+  previous_mvt(NULL),
   weapon_member(new WeaponMember()),
   weapon_pos(0,0),
   last_refresh(0),
-  current_frame(0),
   walk_events(0),
   main_rotation_rad(0),
   skel_lst(),
@@ -168,7 +181,7 @@ Body::Body(const Body& _body):
   std::map<std::string, Member*>::const_iterator it1 = _body.members_lst.begin();
   while (it1 != _body.members_lst.end())
     {
-      if(it1->second->name != "weapon")
+      if (it1->second->GetName() != "weapon")
 	{
 	  std::pair<std::string,Member*> p;
 	  p.first = it1->first;
@@ -182,7 +195,7 @@ Body::Body(const Body& _body):
 
   // Make a copy of clothes
   std::map<std::string, Clothe*>::const_iterator it2 = _body.clothes_lst.begin();
-  while(it2 != _body.clothes_lst.end())
+  while (it2 != _body.clothes_lst.end())
   {
     std::pair<std::string,Clothe*> p;
     p.first = it2->first;
@@ -191,13 +204,14 @@ Body::Body(const Body& _body):
     it2++;
   }
 
-  // Movement are shared
+  // Movements are shared
   std::map<std::string, Movement*>::const_iterator it3 = _body.mvt_lst.begin();
-  while(it3 != _body.mvt_lst.end())
+  while (it3 != _body.mvt_lst.end())
   {
     std::pair<std::string,Movement*> p;
     p.first = it3->first;
     p.second = it3->second;
+    Movement::ShareMovement(p.second);
     mvt_lst.insert(p);
     it3++;
   }
@@ -222,6 +236,14 @@ Body::~Body()
     it2++;
   }
 
+  // Unshare the movements
+  std::map<std::string, Movement*>::iterator it3 = mvt_lst.begin();
+  while(it3 != mvt_lst.end())
+  {
+    Movement::UnshareMovement(it3->second);
+    it3++;
+  }
+
   members_lst.clear();
   clothes_lst.clear();
   mvt_lst.clear();
@@ -229,18 +251,18 @@ Body::~Body()
 
 void Body::ResetMovement() const
 {
-  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
-    current_clothe->layers[layer]->ResetMovement();
+  for (size_t layer=0; layer < current_clothe->GetLayers().size(); layer++)
+    current_clothe->GetLayers()[layer]->ResetMovement();
 }
 
 void Body::ApplyMovement(Movement* mvt, uint frame)
 {
 #ifdef DEBUG
-  if (mvt->type != "breathe")
+  if (mvt->GetType() != "breathe")
     MSG_DEBUG("body_anim", " %s uses %s-%s:%u",
 	      owner->GetName().c_str(),
-	      current_clothe->name.c_str(),
-	      mvt->type.c_str(),
+	      current_clothe->GetName().c_str(),
+	      mvt->GetType().c_str(),
 	      frame);
 #endif
 
@@ -251,11 +273,11 @@ void Body::ApplyMovement(Movement* mvt, uint frame)
   for (;member != skel_lst.end();
        member++)
   {
-    ASSERT( frame < mvt->frames.size() );
-    if(mvt->frames[frame].find(member->member->type) != mvt->frames[frame].end())
+    ASSERT( frame < mvt->GetFrames().size() );
+    if (mvt->GetFrames()[frame].find(member->member->GetType()) != mvt->GetFrames()[frame].end())
     {
       // This member needs to be moved :
-      member_mvt mb_mvt = mvt->frames[frame].find(member->member->type)->second;
+      member_mvt mb_mvt = mvt->GetFrames()[frame].find(member->member->GetType())->second;
       if(mb_mvt.follow_crosshair && ActiveCharacter().body == this && ActiveTeam().AccessWeapon().UseCrossHair())
       {
         // Use the movement of the crosshair
@@ -321,7 +343,7 @@ void Body::ApplyMovement(Movement* mvt, uint frame)
 	if( owner->GetDirection() == DIRECTION_LEFT)
 	{
 		v.x = 2 * (int)owner->GetPosition().x + GetSize().x/2 - v.x;
-		//v.x -= member->member->spr->GetWidth();
+		//v.x -= member->member->GetSprite().GetWidth();
 	}
 	v = Mouse::GetInstance()->GetWorldPosition() - v;
 
@@ -344,11 +366,11 @@ void Body::ApplySqueleton()
   // Move each member following the skeleton
   std::vector<junction>::iterator member = skel_lst.begin();
   // The first member is the body, we set it to pos:
-  member->member->pos = Point2f(0.0, 0.0);
+  member->member->SetPos(Point2f(0.0, 0.0));
   member->member->SetAngle(0.0);
   member++;
 
-  for(;member != skel_lst.end();
+  for (;member != skel_lst.end();
        member++)
   {
     // Place the other members depending on the parent member:
@@ -360,38 +382,41 @@ void Body::Build()
 {
   // Increase frame number if needed
   unsigned int last_frame = current_frame;
+  unsigned int last_loop = current_loop;
 
-  if (walk_events > 0 || current_mvt->type != "walk")
-    {
-      if(Time::GetInstance()->Read() > last_refresh + current_mvt->speed)
-	{
-	  // Compute the new frame number
-	  current_frame += (Time::GetInstance()->Read()-last_refresh) / current_mvt->speed;
-	  last_refresh += ((Time::GetInstance()->Read()-last_refresh) / current_mvt->speed) * current_mvt->speed;
+  if (walk_events > 0 || current_mvt->GetType() != "walk") {
 
-	  // Depending on playmode loop if we have exceeded the nbr of frames of this movement
-	  if(current_frame >= current_mvt->frames.size())
-	    {
-	      if(current_mvt->play_mode == Movement::LOOP)
-		{
-		  current_frame %= current_mvt->frames.size();
-		}
-	      else if(current_mvt->play_mode == Movement::PLAY_ONCE)
-		{
-		  current_frame = current_mvt->frames.size() - 1;
-		  if (play_once_clothe_sauv)
-		    SetClothe(play_once_clothe_sauv->name);
-		  if (play_once_mvt_sauv)
-		    {
-		      SetMovement(play_once_mvt_sauv->type);
-		      current_frame = play_once_frame_sauv;
-		    }
-		}
-	    }
+    if (Time::GetInstance()->Read() > last_refresh + current_mvt->GetFrameDuration()) {
+
+      // Compute the new frame number
+      current_frame += (Time::GetInstance()->Read()-last_refresh) / current_mvt->GetFrameDuration();
+      last_refresh += (current_frame-last_frame) * current_mvt->GetFrameDuration();
+
+      // This is the end of the animation
+      if (current_frame >= current_mvt->GetFrames().size()) {
+
+	current_frame = 0;
+	current_loop++;
+
+	// Number of loops
+	if (current_mvt->GetNbLoops() != 0
+	    && current_loop >= current_mvt->GetNbLoops()) {
+
+	  // animation is finished - set it to the very last frame
+	  current_loop = current_mvt->GetNbLoops() -1;
+	  current_frame = current_mvt->GetFrames().size() -1;
+
+	  if (previous_clothe)
+	    SetClothe(previous_clothe->GetName());
+	  if (previous_mvt)
+	    SetMovement(previous_mvt->GetType());
 	}
+      }
     }
+  }
   need_rebuild |= (last_frame != current_frame);
-  need_rebuild |= current_mvt->always_moving;
+  need_rebuild |= (last_loop != current_loop);
+  need_rebuild |= current_mvt->IsAlwaysMoving();
 
   if (!need_rebuild)
     return;
@@ -402,39 +427,48 @@ void Body::Build()
 
   // Rotate each sprite, because the next part need to know the height
   // of the sprite once it is rotated
-  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++) {
-    if (current_clothe->layers[layer]->name != "weapon")
-      current_clothe->layers[layer]->RotateSprite();
+  for (int layer=0;layer < (int)current_clothe->GetLayers().size() ;layer++) {
+    if (current_clothe->GetLayers()[layer]->GetName() != "weapon")
+      current_clothe->GetLayers()[layer]->RotateSprite();
   }
 
   // Move the members to get the lowest member at the bottom of the skin rectangle
   member_mvt body_mvt;
   float y_max = 0;
 
-  for (int lay=0;lay < (int)current_clothe->layers.size() ;lay++) {
-    if (current_clothe->layers[lay]->name != "weapon")
+  for (int lay=0;lay < (int)current_clothe->GetLayers().size() ;lay++) {
+    if (current_clothe->GetLayers()[lay]->GetName() != "weapon")
       {
-	Member* member = current_clothe->layers[lay];
-	if(member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y > y_max
-	   && !member->go_through_ground)
-	  y_max = member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y;
+	Member* member = current_clothe->GetLayers()[lay];
+	if (member->GetPosFloat().y + member->GetSprite().GetHeightMax() + member->GetSprite().GetRotationPoint().y > y_max
+	   && !member->IsGoingThroughGround())
+	  y_max = member->GetPosFloat().y + member->GetSprite().GetHeightMax() + member->GetSprite().GetRotationPoint().y;
       }
   }
-  body_mvt.pos.y = (float)GetSize().y - y_max + current_mvt->test_bottom;
-  body_mvt.pos.x = GetSize().x / 2.0 - skel_lst.front().member->spr->GetWidth() / 2.0;
+  body_mvt.pos.y = (float)GetSize().y - y_max + current_mvt->GetTestBottom();
+  body_mvt.pos.x = GetSize().x / 2.0 - skel_lst.front().member->GetSprite().GetWidth() / 2.0;
   body_mvt.SetAngle(main_rotation_rad);
   skel_lst.front().member->ApplyMovement(body_mvt, skel_lst);
 
   need_rebuild = false;
 }
 
+std::string Body::GetFrameLoop() const
+{
+  char str[32];
+  snprintf(str, 32, "%u/%u-%u/%zu", current_loop+1, current_mvt->GetNbLoops(),
+	   current_frame+1, current_mvt->GetFrames().size());
+
+  return std::string(str);
+}
+
 void Body::UpdateWeaponPosition(const Point2i& _pos)
 {
   // update the weapon position
   if (direction == DIRECTION_RIGHT)
-    weapon_pos = Point2i((int)weapon_member->pos.x,(int)weapon_member->pos.y);
+    weapon_pos = weapon_member->GetPos();
   else
-    weapon_pos = Point2i(GetSize().x - (int)weapon_member->pos.x,(int)weapon_member->pos.y);
+    weapon_pos = Point2i(GetSize().x - weapon_member->GetPos().x,weapon_member->GetPos().y);
   weapon_pos += _pos;
 }
 
@@ -452,18 +486,18 @@ void Body::Draw(const Point2i& _pos)
   int draw_weapon_member = 0;
 
   // Finally draw each layer one by one
-  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++) {
+  for (int layer=0;layer < (int)current_clothe->GetLayers().size() ;layer++) {
 
-    if (current_clothe->layers[layer]->name == "weapon") {
+    if (current_clothe->GetLayers()[layer]->GetName() == "weapon") {
       // We draw the weapon member only if currently drawing the active character
       if (owner->IsActiveCharacter()) {
 	ASSERT(draw_weapon_member == 0);
-	ASSERT(current_clothe->layers[layer] == weapon_member);
+	ASSERT(current_clothe->GetLayers()[layer] == weapon_member);
 	DrawWeaponMember(_pos);
 	draw_weapon_member++;
       }
     } else {
-      current_clothe->layers[layer]->Draw(_pos, _pos.x + GetSize().x/2, int(direction));
+      current_clothe->GetLayers()[layer]->Draw(_pos, _pos.x + GetSize().x/2, int(direction));
     }
   }
 
@@ -478,23 +512,23 @@ void Body::AddChildMembers(Member* parent)
 {
   // Add child members of the parent member to the skeleton
   // and continue recursively with child members
-  for(std::map<std::string, v_attached>::iterator child = parent->attached_members.begin();
-      child != parent->attached_members.end();
-      child++)
+  for (std::map<std::string, v_attached>::const_iterator child = parent->GetAttachedMembers().begin();
+       child != parent->GetAttachedMembers().end();
+       child++)
   {
     // Find if the current clothe uses this member:
-    for(uint lay = 0; lay < current_clothe->layers.size(); lay++)
+    for (uint lay = 0; lay < current_clothe->GetLayers().size(); lay++)
     {
-      if(current_clothe->layers[lay]->type == child->first)
+      if (current_clothe->GetLayers()[lay]->GetType() == child->first)
       {
         // This child member is attached to his parent
         junction body;
-        body.member = current_clothe->layers[lay];
+        body.member = current_clothe->GetLayers()[lay];
         body.parent = parent;
         skel_lst.push_back(body);
 
         // continue recursively
-        AddChildMembers(current_clothe->layers[lay]);
+        AddChildMembers(current_clothe->GetLayers()[lay]);
       }
     }
   }
@@ -507,17 +541,17 @@ void Body::BuildSqueleton()
   skel_lst.clear();
 
   // Find the "body" member as it is the top of the skeleton
-  for(uint lay = 0; lay < current_clothe->layers.size(); lay++)
-    if(current_clothe->layers[lay]->type == "body")
+  for (uint lay = 0; lay < current_clothe->GetLayers().size(); lay++)
+    if (current_clothe->GetLayers()[lay]->GetType() == "body")
     {
       junction body;
-      body.member = current_clothe->layers[lay];
+      body.member = current_clothe->GetLayers()[lay];
       body.parent = NULL;
       skel_lst.push_back(body);
       break;
     }
 
-  if(skel_lst.size() == 0)
+  if (skel_lst.size() == 0)
   {
     std::cerr << "Unable to find the \"body\" member in the current clothe" << std::endl;
     ASSERT(false);
@@ -529,7 +563,7 @@ void Body::BuildSqueleton()
 void Body::SetClothe(const std::string& name)
 {
   MSG_DEBUG("body", " %s use clothe %s", owner->GetName().c_str(), name.c_str());
-  if (current_clothe && current_clothe->name == name)
+  if (current_clothe && current_clothe->GetName() == name)
     return;
 
   if (clothes_lst.find(name) != clothes_lst.end())
@@ -538,7 +572,7 @@ void Body::SetClothe(const std::string& name)
     BuildSqueleton();
     main_rotation_rad = 0;
     need_rebuild = true;
-    play_once_clothe_sauv = NULL;
+    previous_clothe = NULL;
   }
   else
     MSG_DEBUG("body", "Clothe not found");
@@ -549,19 +583,20 @@ void Body::SetClothe(const std::string& name)
 void Body::SetMovement(const std::string& name)
 {
   MSG_DEBUG("body", " %s use movement %s", owner->GetName().c_str(), name.c_str());
-  if(current_mvt && current_mvt->type == name) return;
+  if (current_mvt && current_mvt->GetType() == name) return;
 
   // Dirty trick to get the "black" movement to be played fully
-  if(current_clothe && current_clothe->name == "black") return;
+  if (current_clothe && current_clothe->GetName() == "black") return;
 
-  if(mvt_lst.find(name) != mvt_lst.end())
+  if (mvt_lst.find(name) != mvt_lst.end())
   {
     current_mvt = mvt_lst.find(name)->second;
     current_frame = 0;
+    current_loop = 0;
     last_refresh = Time::GetInstance()->Read();
     main_rotation_rad = 0;
     need_rebuild = true;
-    play_once_mvt_sauv = NULL;
+    previous_mvt = NULL;
   }
   else
     MSG_DEBUG("body", "Movement not found");
@@ -572,7 +607,8 @@ void Body::SetMovement(const std::string& name)
 void Body::PlayAnimation()
 {
   std::ostringstream name;
-  name << "animation" << RandomLocal().GetLong(0, animation_number - 1);
+  MSG_DEBUG("random.get", "Body::PlayAnimation()");
+  name << "animation" << RandomSync().GetLong(0, animation_number - 1);
   SetClotheOnce(name.str());
   SetMovementOnce(name.str());
 }
@@ -580,12 +616,12 @@ void Body::PlayAnimation()
 void Body::SetClotheOnce(const std::string& name)
 {
   MSG_DEBUG("body", " %s use clothe %s once", owner->GetName().c_str(), name.c_str());
-  if(current_clothe && current_clothe->name == name) return;
+  if (current_clothe && current_clothe->GetName() == name) return;
 
-  if(clothes_lst.find(name) != clothes_lst.end())
+  if (clothes_lst.find(name) != clothes_lst.end())
   {
-    if(!play_once_clothe_sauv)
-      play_once_clothe_sauv = current_clothe;
+    if (!previous_clothe)
+      previous_clothe = current_clothe;
     current_clothe = clothes_lst.find(name)->second;
     BuildSqueleton();
     main_rotation_rad = 0;
@@ -600,21 +636,21 @@ void Body::SetClotheOnce(const std::string& name)
 void Body::SetMovementOnce(const std::string& name)
 {
   MSG_DEBUG("body", " %s use movement %s once", owner->GetName().c_str(), name.c_str());
-  if(current_mvt && current_mvt->type == name) return;
+  if (current_mvt && current_mvt->GetType() == name) return;
 
   // Dirty trick to get the "black" movement to be played fully
-  if(current_clothe && current_clothe->name == "black"  && name != "black") return;
+  if(current_clothe && current_clothe->GetName() == "black"  && name != "black") return;
 
-  if(mvt_lst.find(name) != mvt_lst.end())
+  if (mvt_lst.find(name) != mvt_lst.end())
   {
-    if(!play_once_mvt_sauv)
+    if (!previous_mvt)
     {
-      play_once_mvt_sauv = current_mvt;
-      play_once_frame_sauv = current_frame;
+      previous_mvt = current_mvt;
     }
 
     current_mvt = mvt_lst.find(name)->second;
     current_frame = 0;
+    current_loop = 0;
     last_refresh = Time::GetInstance()->Read();
     main_rotation_rad = 0;
     need_rebuild = true;
@@ -629,16 +665,16 @@ void Body::GetTestRect(uint &l, uint&r, uint &t, uint &b) const
 {
   if(direction == DIRECTION_RIGHT)
   {
-    l = current_mvt->test_left;
-    r = current_mvt->test_right;
+    l = current_mvt->GetTestLeft();
+    r = current_mvt->GetTestRight();
   }
   else
   {
-    r = current_mvt->test_left;
-    l = current_mvt->test_right;
+    r = current_mvt->GetTestLeft();
+    l = current_mvt->GetTestRight();
   }
-  t = current_mvt->test_top;
-  b = current_mvt->test_bottom;
+  t = current_mvt->GetTestTop();
+  b = current_mvt->GetTestBottom();
 }
 
 void Body::StartWalk()
@@ -656,7 +692,7 @@ void Body::StopWalk()
 {
   if(walk_events > 0)
     walk_events--;
-  if(current_mvt->type == "walk")
+  if(current_mvt->GetType() == "walk")
   {
     SetMovement("breathe");
     SetFrame(0);
@@ -670,18 +706,27 @@ bool Body::IsWalking() const
 
 uint Body::GetMovementDuration() const
 {
-  return current_mvt->frames.size() * current_mvt->speed;
+  return current_mvt->GetFrames().size() * current_mvt->GetFrameDuration();
 }
 
 uint Body::GetFrameCount() const
 {
-  return current_mvt->frames.size();
+  return current_mvt->GetFrames().size();
 }
 
 void Body::SetFrame(uint no)
 {
-  ASSERT(no < current_mvt->frames.size());
+#ifdef DEBUG
+  if (no >= current_mvt->GetFrames().size()) {
+    fprintf(stderr, "%s:%d Clothe: %s\n", __PRETTY_FUNCTION__, __LINE__, current_clothe->GetName().c_str());
+    fprintf(stderr, "%s:%d Movement: %s\n", __PRETTY_FUNCTION__, __LINE__, current_mvt->GetType().c_str());
+    fprintf(stderr, "%s:%d Frame requested: %d - Max nb frames: %d\n", __PRETTY_FUNCTION__, __LINE__,
+	    no,(int) current_mvt->GetFrames().size());
+  }
+#endif
+  ASSERT(no < current_mvt->GetFrames().size());
   current_frame = no;
+  current_loop = 0;
   need_rebuild = true;
 }
 
@@ -689,23 +734,23 @@ void Body::MakeParticles(const Point2i& pos)
 {
   Build();
 
-  for(int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
-  if(current_clothe->layers[layer]->type != "weapon")
-    ParticleEngine::AddNow(new BodyMemberParticle(current_clothe->layers[layer]->spr,
-                                                  current_clothe->layers[layer]->GetPos()+pos));
+  for (int layer=0;layer < (int)current_clothe->GetLayers().size() ;layer++) {
+    if (current_clothe->GetLayers()[layer]->GetType() != "weapon")
+      ParticleEngine::AddNow(new BodyMemberParticle(current_clothe->GetLayers()[layer]->GetSprite(),
+						    current_clothe->GetLayers()[layer]->GetPos()+pos));
+  }
 }
 
 void Body::MakeTeleportParticles(const Point2i& pos, const Point2i& dst)
 {
   Build();
 
-  for(int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
-  if(current_clothe->layers[layer]->type != "weapon")
-  {
-    ParticleEngine::AddNow(new TeleportMemberParticle(current_clothe->layers[layer]->spr,
-                                                      current_clothe->layers[layer]->GetPos()+pos,
-                                                      current_clothe->layers[layer]->GetPos()+dst,
-                                                      int(direction)));
+  for (int layer=0;layer < (int)current_clothe->GetLayers().size() ;layer++) {
+    if (current_clothe->GetLayers()[layer]->GetType() != "weapon")
+      ParticleEngine::AddNow(new TeleportMemberParticle(current_clothe->GetLayers()[layer]->GetSprite(),
+							current_clothe->GetLayers()[layer]->GetPos()+pos,
+							current_clothe->GetLayers()[layer]->GetPos()+dst,
+							int(direction)));
   }
 }
 
@@ -716,15 +761,22 @@ void Body::SetRotation(double angle)
   need_rebuild = true;
 }
 
-const std::string& Body::GetMovement() const { return current_mvt->type; }
-const std::string& Body::GetClothe() const { return current_clothe->name; }
+const std::string& Body::GetMovement() const
+{
+  return current_mvt->GetType();
+}
+
+const std::string& Body::GetClothe() const
+{
+  return current_clothe->GetName();
+}
 
 void Body::DebugState() const
 {
-  MSG_DEBUG("body.state", "clothe: %s\tmovement: %s\t%i", current_clothe->name.c_str(),current_mvt->type.c_str(), current_frame);
+  MSG_DEBUG("body.state", "clothe: %s\tmovement: %s\t%i", current_clothe->GetName().c_str(),
+	    current_mvt->GetType().c_str(), current_frame);
   MSG_DEBUG("body.state", "(played once)clothe: %s\tmovement: %s",
-            (play_once_clothe_sauv?play_once_clothe_sauv->name.c_str():"(NULL)"),
-            (play_once_mvt_sauv?play_once_mvt_sauv->type.c_str():"(NULL)"),
-            play_once_frame_sauv);
+            (previous_clothe?previous_clothe->GetName().c_str():"(NULL)"),
+            (previous_mvt?previous_mvt->GetType().c_str():"(NULL)"));
   MSG_DEBUG("body.state", "need rebuild = %i",need_rebuild);
 }
