@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 #include <vector>
 #include "include/base.h"
-#include "tool/point.h"
+#include <WORMUX_point.h>
 
 // Forward declarations
 class Character;
@@ -64,32 +64,33 @@ class Body
   /**********************************************/
 
   friend class BodyList;
+  friend class SkinMenu;
   std::map<std::string, Member*> members_lst;
   std::map<std::string, Clothe*> clothes_lst;
   std::map<std::string, Movement*> mvt_lst;
 
   const Clothe* current_clothe;
   Movement* current_mvt;
+  uint current_loop;
+  uint current_frame;
 
-  // When a movement/clothe is played once, those variable saves the previous state;
-  Movement* play_once_mvt_sauv;
-  const Clothe* play_once_clothe_sauv;
-  uint play_once_frame_sauv;
+  // When a movement/clothe is played once, those variables save the previous state
+  const Clothe* previous_clothe;
+  Movement* previous_mvt;
 
   // For weapon position handling
   Member* weapon_member;
   Point2i weapon_pos;
 
   uint last_refresh; // Time elapsed since last refresh
-  uint current_frame;
   int walk_events;
 
   double main_rotation_rad;
 
-  std::vector<junction> squel_lst; // Squeleton of the body:
-                                        // Order to use to build the body
-                                        // First element: member to build
-                                        // Secnd element: parent member
+  std::vector<junction> skel_lst; // Body skeleton:
+                                  // Order to use to build the body
+                                  // First element: member to build
+                                  // Secnd element: parent member
   BodyDirection_t direction;
 
   int animation_number;
@@ -103,13 +104,15 @@ class Body
   void AddChildMembers(Member* parent);
   const Character* owner;
 
+  void DrawWeaponMember(const Point2i& _pos);
+
 public:
 
-  Body(xmlNode* xml, const Profile* res);
+  Body(const xmlNode* xml, const std::string& main_folder);
   Body(const Body&);
   ~Body();
 
-  Point2i GetSize() {return Point2i(30,45);};
+  static Point2i GetSize() {return Point2i(30,45);};
 
   void Draw(const Point2i& pos);
   void SetClothe(const std::string& name);
@@ -126,6 +129,7 @@ public:
 
   const std::string& GetMovement() const;
   const std::string& GetClothe() const;
+  std::string GetFrameLoop() const;
   void GetTestRect(uint &l, uint &r, uint &t, uint &b) const;
   const BodyDirection_t &GetDirection() const { return direction; };
   const Point2i &GetHandPosition() const { return weapon_pos; };
