@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,24 +22,26 @@
 #define BODY_LIST_H
 //-----------------------------------------------------------------------------
 #include "include/base.h"
+#include <WORMUX_singleton.h>
 #include <map>
 #include <string>
 //-----------------------------------------------------------------------------
 class Body;
 
-class BodyList
+class BodyList : public Singleton<BodyList>
 {
+private:
   std::map<std::string, Body*> list;
 
   void Load (const std::string &name);
 
-public:
   BodyList();
+  friend class Singleton<BodyList>;
+
+public:
   void FreeMem();
   Body* GetBody(const std::string &body);
 };
 
-extern BodyList body_list;
-
 //-----------------------------------------------------------------------------
 #endif
