@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,13 +19,13 @@
  *****************************************************************************/
 
 #include "tool/xml_document.h"
-#include "tool/debug.h"
+#include <WORMUX_debug.h>
 #include "character/clothe.h"
 #include "character/member.h"
 #include <map>
 #include <iostream>
 
-Clothe::Clothe(xmlNode* xml, std::map<std::string, Member*>& members_lst):
+Clothe::Clothe(const xmlNode* xml, std::map<std::string, Member*>& members_lst):
   name(),
   layers()
 {
@@ -33,7 +33,9 @@ Clothe::Clothe(xmlNode* xml, std::map<std::string, Member*>& members_lst):
 
   xmlNodeArray nodes = XmlReader::GetNamedChildren(xml, "c_member");
   xmlNodeArray::const_iterator it;
-  MSG_DEBUG("body.clothe", "   Found %i clothe members\n", nodes.size());
+  MSG_DEBUG("body.clothe", "   Found %i clothe members in %s", nodes.size(), name.c_str());
+
+  ASSERT(nodes.size());
 
   for (it = nodes.begin(); it != nodes.end(); ++it)
   {
@@ -55,7 +57,7 @@ Clothe::Clothe(xmlNode* xml, std::map<std::string, Member*>& members_lst):
     }
 
     layers.push_back( member );
-  } 
+  }
 
   std::vector<Member*>::iterator i = layers.begin();
   while( i != layers.end())
@@ -73,7 +75,7 @@ Clothe::Clothe(Clothe* c, std::map<std::string, Member*>& members_lst):
       it != c->layers.end();
       ++it)
   {
-    layers.push_back(members_lst.find((*it)->name)->second);
+    layers.push_back(members_lst.find((*it)->GetName())->second);
   }
 }
 
@@ -81,3 +83,13 @@ Clothe::~Clothe()
 {
   layers.clear();
 }
+
+const std::string & Clothe::GetName() const
+{
+  return name;
+}
+
+const std::vector<Member*>& Clothe::GetLayers() const
+{
+  return layers;
+}
