@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,13 +28,18 @@ typedef struct _xmlNode xmlNode;
 
 class Clothe
 {
-public:
+private:
   std::string name;
   std::vector<Member*> layers;
 
+public:
   ~Clothe();
   Clothe(const xmlNode* xml, std::map<std::string, Member*>& members_lst);
   Clothe(Clothe* c, std::map<std::string, Member*>& members_lst);
+
+  const std::string & GetName() const;
+
+  const std::vector<Member*>& GetLayers() const;
 };
 
 #endif //CLOTHE_H
