@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,18 +32,18 @@
 #include "tool/string_tools.h"
 #include "tool/xml_document.h"
 
-Member::Member(xmlNode* xml, const Profile* res):
+Member::Member(const xmlNode* xml, const std::string& main_folder):
   parent(NULL),
   angle_rad(0),
-  anchor(0,0),
-  spr(NULL),
-  name(""),
+  alpha(0),
+  go_through_ground(false),
   attached_members(),
   pos(0,0),
   scale(0,0),
-  alpha(0),
+  spr(NULL),
+  name(""),
   type(""),
-  go_through_ground(false)
+  anchor(0,0)
 {
   if (xml == NULL)
     return;
@@ -51,7 +51,7 @@ Member::Member(xmlNode* xml, const Profile* res):
   ASSERT(name!="");
 
   // Load the sprite
-  spr = resource_manager.LoadSprite( res, name);
+  spr = GetResourceManager().LoadSprite(xml, name, main_folder);
   //spr->EnableRotationCache(32);
   //spr->EnableFlippingCache();
   spr->cache.EnableLastFrameCache();
@@ -60,8 +60,8 @@ Member::Member(xmlNode* xml, const Profile* res):
   XmlReader::ReadStringAttr(xml, "type", type);
   ASSERT(type!="");
 
-  xmlNode* el = XmlReader::GetMarker(xml, "anchor");
-  if(el != 0)
+  const xmlNode* el = XmlReader::GetMarker(xml, "anchor");
+  if (el != NULL)
   {
     int dx = 0, dy = 0;
     XmlReader::ReadIntAttr(el, "dx", dx);
@@ -117,7 +117,7 @@ Member::Member(xmlNode* xml, const Profile* res):
       }
       (attached_members.find(att_type)->second)[frame] = d;
     }
-  } 
+  }
 
   ResetMovement();
 }
@@ -125,15 +125,15 @@ Member::Member(xmlNode* xml, const Profile* res):
 Member::Member(const Member& m):
   parent(NULL),
   angle_rad(m.angle_rad),
-  anchor(m.anchor),
-  spr(new Sprite(*m.spr)),
-  name(m.name),
+  alpha(m.alpha),
+  go_through_ground(m.go_through_ground),
   attached_members(),
   pos(m.pos),
   scale(m.scale),
-  alpha(m.alpha),
+  spr(new Sprite(*m.spr)),
+  name(m.name),
   type(m.type),
-  go_through_ground(m.go_through_ground)
+  anchor(m.anchor)
 {
   Point2i rot = Point2i((int)anchor.x, (int)anchor.y);
   spr->SetRotation_HotSpot(rot);
@@ -192,7 +192,7 @@ void Member::Draw(const Point2i & _pos, int flip_center, int direction)
 
 void Member::ApplySqueleton(Member* parent_member)
 {
-  // Place the member to shape the squeleton
+  // Place the member to shape the skeleton
   if(parent_member == NULL)
   {
     std::cerr << "Member " << name << " have no parent member!" << std::endl;
@@ -210,7 +210,7 @@ void Member::ApplySqueleton(Member* parent_member)
     pos = pos + parent->attached_members.find(type)->second[parent->spr->GetCurrentFrame()];
 }
 
-void Member::ApplyMovement(const member_mvt &mvt, std::vector<junction>& squel_lst)
+void Member::ApplyMovement(const member_mvt &mvt, std::vector<junction>& skel_lst)
 {
   // Apply the movment to the member,
   // And apply the movement accordingly to the child members
@@ -226,9 +226,9 @@ void Member::ApplyMovement(const member_mvt &mvt, std::vector<junction>& squel_l
       child != attached_members.end();
       child++ )
   {
-    // Find this member in the squeleton:
-    for(std::vector<junction>::iterator member = squel_lst.begin();
-        member != squel_lst.end();
+    // Find this member in the skeleton:
+    for(std::vector<junction>::iterator member = skel_lst.begin();
+        member != skel_lst.end();
         member++)
     {
       if(member->member->type == child->first)
@@ -261,8 +261,8 @@ void Member::ApplyMovement(const member_mvt &mvt, std::vector<junction>& squel_l
           child_mvt.pos.x += radius * (cos(angle_init + angle_rad + mvt.GetAngle()) - cos(angle_init + angle_rad));
           child_mvt.pos.y += radius * (sin(angle_init + angle_rad + mvt.GetAngle()) - sin(angle_init + angle_rad));
         }
-        // Apply recursively to childrens:
-        member->member->ApplyMovement(child_mvt, squel_lst);
+        // Apply recursively to children:
+        member->member->ApplyMovement(child_mvt, skel_lst);
       }
     }
   }
@@ -274,7 +274,68 @@ void Member::ApplyMovement(const member_mvt &mvt, std::vector<junction>& squel_l
   scale = scale * mvt.scale;
 }
 
-WeaponMember::WeaponMember() : Member(NULL, NULL)
+void Member::ResetMovement()
+{
+  pos.x = 0;
+  pos.y = 0;
+  angle_rad = 0;
+  alpha = 1.0;
+  scale.x = 1.0;
+  scale.y = 1.0;
+}
+
+void Member::SetAngle(const double &angle)
+{
+  angle_rad = angle;
+}
+
+const Sprite& Member::GetSprite() const
+{
+  return *spr;
+}
+
+void Member::SetPos(const Point2f &_pos)
+{
+  pos = _pos;
+}
+
+const Point2f& Member::GetPosFloat() const
+{
+  return pos;
+}
+
+const Point2i Member::GetPos() const
+{
+  return Point2i((int)pos.x, (int)pos.y);
+}
+
+const Point2i Member::GetAnchorPos() const
+{
+  return Point2i((int)anchor.x, (int)anchor.y);
+}
+
+const std::string& Member::GetName() const
+{
+  return name;
+}
+
+const std::string& Member::GetType() const
+{
+  return type;
+}
+
+bool Member::IsGoingThroughGround() const
+{
+  return go_through_ground;
+}
+
+const std::map<std::string, v_attached> & Member::GetAttachedMembers() const
+{
+  return attached_members;
+}
+
+
+WeaponMember::WeaponMember() : Member(NULL, "")
 {
   name = "weapon";
   type = "weapon";
@@ -289,8 +350,8 @@ WeaponMember::~WeaponMember()
 void WeaponMember::Draw(const Point2i & /*_pos*/, int /*flip_center*/, int /*direction*/)
 {
   if (!ActiveCharacter().IsDead() && Game::GetInstance()->ReadState() != Game::END_TURN)
-  {
-        ActiveTeam().crosshair.Draw();
-        ActiveTeam().AccessWeapon().Draw();
-  }
+    {
+      ActiveTeam().crosshair.Draw();
+      ActiveTeam().AccessWeapon().Draw();
+    }
 }
