@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,8 +33,4 @@ bool ComputeHeightMovement (Character &character, int &height,
 
 void MoveCharacter (Character &character, bool slowly = false);
 
-// Move the active character to the left/right
-void MoveActiveCharacterRight(bool shift);
-void MoveActiveCharacterLeft(bool shift);
-
 #endif
