@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,9 +39,8 @@
 #include "sound/jukebox.h"
 #include "team/macro.h"
 #include "team/team.h"
-#include "tool/debug.h"
-#include "tool/i18n.h"
-#include "tool/random.h"
+#include <WORMUX_debug.h>
+#include <WORMUX_random.h>
 
 GameClassic::GameClassic()
   : Game()
@@ -74,12 +73,17 @@ void GameClassic::RefreshClock()
 
       case PLAYING:
         if (duration <= 1) {
-	  JukeBox::GetInstance()->Play("share", "end_turn");
+
+	  /* let the user release the key to shoot */
+	  if (ActiveTeam().GetWeapon().IsLoading())
+	    break;
+
+	  JukeBox::GetInstance()->Play("default", "end_turn");
 	  SetState(END_TURN);
         } else {
           duration--;
 	  if (duration == 12) {
-	    countdown_sample.Play("share", "countdown-end_turn");
+	    countdown_sample.Play("default", "countdown-end_turn");
 	  }
 	  if (duration > 10) {
 	    Interface::GetInstance()->UpdateTimer(duration, black_color);
@@ -113,7 +117,7 @@ void GameClassic::RefreshClock()
             break;
           }
 
-          if (Network::GetInstance()->IsTurnMaster() && give_objbox && world.IsOpen()) {
+          if (Network::GetInstance()->IsTurnMaster() && give_objbox && GetWorld().IsOpen()) {
             NewBox();
             give_objbox = false;
             break;
@@ -147,9 +151,9 @@ void GameClassic::__SetState_PLAYING()
   pause_seconde = Time::GetInstance()->Read();
 
   if (Network::GetInstance()->IsTurnMaster() || Network::GetInstance()->IsLocal())
-    wind.ChooseRandomVal();
+    Wind::GetRef().ChooseRandomVal();
 
-  character_already_chosen = false;
+  SetCharacterChosen(false);
 
   // Prepare each character for a new turn
   FOR_ALL_LIVING_CHARACTERS(team,character)
@@ -158,37 +162,16 @@ void GameClassic::__SetState_PLAYING()
   // Select the next team
   ASSERT (!IsGameFinished());
 
-  if (Network::GetInstance()->IsTurnMaster() || Network::GetInstance()->IsLocal())
-    {
-      GetTeamsList().NextTeam();
+  if (Network::GetInstance()->IsTurnMaster() || Network::GetInstance()->IsLocal()) {
 
-      if ( GameMode::GetInstance()->auto_change_character)
-        {
-          ActiveTeam().NextCharacter();
-        }
+    GetTeamsList().NextTeam();
 
-      Camera::GetInstance()->FollowObject (&ActiveCharacter(), true);
-
-      if ( Network::GetInstance()->IsTurnMaster() )
-        {
-          // Tell clients which character in the team is now playing
-          Action playing_char(Action::ACTION_GAMELOOP_CHANGE_CHARACTER);
-          playing_char.StoreActiveCharacter();
-          Network::GetInstance()->SendAction(playing_char);
-
-          printf("Action_ChangeCharacter:\n");
-          printf("char_index = %i\n",ActiveCharacter().GetCharacterIndex());
-          printf("Playing character : %i %s\n", ActiveCharacter().GetCharacterIndex(), ActiveCharacter().GetName().c_str());
-          printf("Playing team : %i %s\n", ActiveCharacter().GetTeamIndex(), ActiveTeam().GetName().c_str());
-          printf("Alive characters: %i / %i\n\n",ActiveTeam().NbAliveCharacter(),ActiveTeam().GetNbCharacters());
-        }
-
-      // Are we turn master for next turn ?
-      if (ActiveTeam().IsLocal() || ActiveTeam().IsLocalAI())
-        Network::GetInstance()->SetTurnMaster(true);
-      else
-        Network::GetInstance()->SetTurnMaster(false);
-    }
+    // Are we turn master for next turn ?
+    if (ActiveTeam().IsLocal() || ActiveTeam().IsLocalAI())
+      Network::GetInstance()->SetTurnMaster(true);
+    else
+      Network::GetInstance()->SetTurnMaster(false);
+  }
 
   give_objbox = true; //hack: make it so that there is no more than one objbox per turn
 }
@@ -224,7 +207,7 @@ void GameClassic::ApplyDeathMode () const
 {
   if (IsGameFinished()) return;
 
-  if(Time::GetInstance()->Read() > GameMode::GetInstance()->duration_before_death_mode * 1000)
+  if (Time::GetInstance()->Read() > GameMode::GetInstance()->duration_before_death_mode * 1000)
   {
     GameMessages::GetInstance()->Add (_("Hurry up, you are too slow !!"));
     FOR_ALL_LIVING_CHARACTERS(team, character)
