@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ public:
 private:
   LoadingScreen loading_sreen;
   // Initialization
-  void InitGameData_NetServer();
-  void EndInitGameData_NetServer();
+  void InitGameData_NetGameMaster();
+  void EndInitGameData_NetGameMaster();
   void EndInitGameData_NetClient();
 
   void InitMap();
