@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,13 +19,16 @@
  * Polygon class. Store point of a polygon and handle affine transformation
  *****************************************************************************/
 
+#include <WORMUX_types.h>
 #include "graphic/polygon.h"
 #include "graphic/sprite.h"
 #include "graphic/video.h"
 #include "include/app.h"
 #include "map/map.h"
 #include "network/randomsync.h"
+#include "tool/resource_manager.h"
 #include "tool/affine_transform.h"
+#include "tool/math_tools.h"
 
 
 //=========== POLYGON BUFFER ============ //
@@ -471,6 +474,7 @@ Point2d Polygon::GetRandomUpperPoint()
   std::vector<Point2d>::iterator point = transformed_shape.begin();
   Point2d tmp, previous;
   tmp = *point;
+  MSG_DEBUG("random.get", "Polygon::GetRandomUpperPoint()");
   int start = RandomSync().GetInt(0, GetNbOfPoint());
   int i;
   for(i = 0; i < start; i++)
@@ -523,8 +527,11 @@ void Polygon::AddRandomCurve(const Point2d& start, const Point2d& end,
   if(add_first_point)
     AddPoint(start);
   for (int i = 1; i < num_steps - 1; i++) {
-    AddPoint(start + (step * i) + Point2d(RandomSync().GetDouble(-x_random_offset, x_random_offset),
-                                          RandomSync().GetDouble(-y_random_offset, y_random_offset)));
+    MSG_DEBUG("random.get", "Polygon::AddRandomCurve(...)");
+    double x = RandomSync().GetDouble(-x_random_offset, x_random_offset);
+    MSG_DEBUG("random.get", "Polygon::AddRandomCurve(...)");
+    double y = RandomSync().GetDouble(-y_random_offset, y_random_offset);
+    AddPoint(start + (step * i) + Point2d(x,y));
   }
   if(add_last_point)
     AddPoint(end);
@@ -559,8 +566,10 @@ Polygon * Polygon::GetBezierInterpolation(double smooth_value, int num_steps, do
 
     // Randomization
     if(rand != 0.0) {
+      MSG_DEBUG("random.get", "Polygon::GetBezierInterpolation(...)");
       trans.SetRotation(RandomSync().GetDouble(-rand, rand));
       v1 = trans * v1;
+      MSG_DEBUG("random.get", "Polygon::GetBezierInterpolation(...)");
       trans.SetRotation(RandomSync().GetDouble(-rand, rand));
       v2 = trans * v2;
     }
@@ -696,5 +705,228 @@ void Polygon::Draw(Surface * dest)
 void Polygon::DrawOnScreen()
 {
   Draw(&GetMainWindow());
-  world.ToRedrawOnScreen(GetRectangleToRefresh());
+  GetWorld().ToRedrawOnScreen(GetRectangleToRefresh());
+}
+
+////////////////////////////
+// DecoratedBox
+
+DecoratedBox::DecoratedBox(double width, double height):Polygon(),
+m_border(NULL),
+m_style(DecoratedBox::STYLE_ROUNDED)
+{
+  min =  Point2d(0.0, 0.0);
+  max = Point2d(width, height);
+  original_min = min;
+  original_max = max;
+
+
+}
+
+DecoratedBox::~DecoratedBox()
+{
+  delete m_border;
+}
+
+void DecoratedBox::Draw(Surface * dest)
+{
+  if(!m_border){
+    m_border = new Surface(Point2i(GetSize().x,GetSize().y),SDL_SWSURFACE, true);
+    GenerateBorder(*m_border);
+  }
+  dest->Blit(*m_border, min);
+
+
+  // Draw Item
+  for(std::vector<PolygonItem *>::iterator item = items.begin();
+      item != items.end(); item++) {
+    (*item)->Draw(dest);
+  }
+}
+
+void DecoratedBox::SetStyle(DecoratedBox::Style style)
+{
+  m_style = style;
+}
+
+void DecoratedBox::SetPosition(double x, double y)
+{
+    for(std::vector<PolygonItem *>::iterator item = items.begin();
+      item != items.end(); item++) {
+      Point2d old_pos = (*item)->GetPosition();
+      old_pos.x += x - min.x;
+      old_pos.y += y - min.y;
+      (*item)->SetPosition(old_pos);
+    }
+    max.x = x - min.x +max.x ;
+    max.y = y - min.y +max.y;
+    min.x = x;
+    min.y = y;
+    original_min = min;
+    original_max = max;
+}
+
+void DecoratedBox::GenerateBorder(Surface & source)
+{
+
+  Surface rounding_style [3][3];
+  Surface rounding_style_mask [3][3];
+
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
+
+  std::string style;
+
+  switch(m_style)
+  {
+      case STYLE_ROUNDED:
+      style = "rounding";
+      break;
+      case STYLE_SQUARE:
+      style = "square";
+      break;
+  }
+
+  // styled box
+  rounding_style[1][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_bottom");
+  rounding_style[0][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_bottom_left");
+  rounding_style[2][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_bottom_right");
+  rounding_style[1][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_top");
+  rounding_style[0][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_top_left");
+  rounding_style[2][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_top_right");
+  rounding_style[0][1] = GetResourceManager().LoadImage( res, "interface/"+style+"_left");
+  rounding_style[2][1] = GetResourceManager().LoadImage( res, "interface/"+style+"_right");
+  rounding_style[1][1] = GetResourceManager().LoadImage( res, "interface/"+style+"_center");
+
+  rounding_style_mask[1][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_bottom");
+  rounding_style_mask[0][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_bottom_left");
+  rounding_style_mask[2][2] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_bottom_right");
+  rounding_style_mask[1][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_top");
+  rounding_style_mask[0][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_top_left");
+  rounding_style_mask[2][0] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_top_right");
+  rounding_style_mask[0][1] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_left");
+  rounding_style_mask[2][1] = GetResourceManager().LoadImage( res, "interface/"+style+"_mask_right");
+
+  Surface save_surf(source.GetSize(),SDL_SWSURFACE, true);
+  save_surf.MergeSurface(source, Point2i(0,0));
+  Rectanglei temp_rect;
+
+  source = Surface(Surface(source.GetSize(),SDL_SWSURFACE, true));
+
+  temp_rect.SetPosition(Point2i(0,0));
+  temp_rect.SetSize(source.GetSize());
+
+  Point2i temp_position;
+
+  temp_position = temp_rect.GetPosition();
+  source.MergeSurface(rounding_style[0][0], temp_position);
+
+  temp_position = temp_rect.GetPosition();
+  temp_position.x += temp_rect.GetSize().x - rounding_style[2][0].GetSize().x;
+  source.MergeSurface(rounding_style[2][0],temp_position);
+
+  temp_position = temp_rect.GetPosition();
+  temp_position.y += temp_rect.GetSize().y - rounding_style[0][2].GetSize().y;
+  source.MergeSurface(rounding_style[0][2],temp_position);
+
+  temp_position = temp_rect.GetPosition();
+  temp_position.x += temp_rect.GetSize().x - rounding_style[2][2].GetSize().x;
+  temp_position.y += temp_rect.GetSize().y - rounding_style[2][2].GetSize().y;
+  source.MergeSurface(rounding_style[2][2],temp_position);
+
+
+  for(int i = rounding_style[0][0].GetSize().x; i< (temp_rect.GetSize().x - rounding_style[2][0].GetSize().x);i++){
+    temp_position = temp_rect.GetPosition();
+    temp_position.x += i;
+    source.MergeSurface(rounding_style[1][0],temp_position);
+
+    temp_position.y += temp_rect.GetSize().y - rounding_style[1][2].GetSize().y;
+    source.MergeSurface(rounding_style[1][2],temp_position);
+
+  }
+
+  for(int i = rounding_style[0][0].GetSize().y; i< (temp_rect.GetSize().y - rounding_style[0][2].GetSize().y);i++){
+    temp_position = temp_rect.GetPosition();
+    temp_position.y += i;
+    source.MergeSurface(rounding_style[0][1],temp_position);
+
+    temp_position.x += temp_rect.GetSize().x - rounding_style[2][1].GetSize().x;
+    source.MergeSurface(rounding_style[2][1],temp_position);
+
+  }
+
+  for(int i = rounding_style[0][0].GetSize().x; i< (temp_rect.GetSize().x - rounding_style[2][0].GetSize().x);i++){
+
+    for(int j = rounding_style[0][0].GetSize().y; j< (temp_rect.GetSize().y - rounding_style[0][2].GetSize().y);j++){
+      temp_position = temp_rect.GetPosition() + Point2i(i,j);
+      source.MergeSurface(rounding_style[1][1],temp_position);
+    }
+  }
+
+  //Corner
+  save_surf.MergeAlphaSurface(rounding_style_mask[0][0],Point2i(0,0));
+  save_surf.MergeAlphaSurface(rounding_style_mask[2][0],Point2i(temp_rect.GetSize().x - rounding_style_mask[2][0].GetSize().x,0));
+  save_surf.MergeAlphaSurface(rounding_style_mask[0][2],Point2i(0,temp_rect.GetSize().y - rounding_style_mask[0][2].GetSize().y));
+  save_surf.MergeAlphaSurface(rounding_style_mask[2][2],Point2i(temp_rect.GetSize().x - rounding_style_mask[2][0].GetSize().x,temp_rect.GetSize().y - rounding_style_mask[0][2].GetSize().y));
+
+  //Top
+  save_surf.MergeAlphaSurface(rounding_style_mask[1][0],Point2i(rounding_style_mask[0][0].GetSize().x,0));
+  //Bottom
+  save_surf.MergeAlphaSurface(rounding_style_mask[1][2],Point2i(rounding_style_mask[0][0].GetSize().x,temp_rect.GetSize().y - rounding_style_mask[0][2].GetSize().y));
+  //Left
+  save_surf.MergeAlphaSurface(rounding_style_mask[0][1],Point2i(0,rounding_style_mask[0][0].GetSize().y));
+  //Right
+  save_surf.MergeAlphaSurface(rounding_style_mask[2][1],Point2i(temp_rect.GetSize().x - rounding_style_mask[2][0].GetSize().x,rounding_style_mask[0][0].GetSize().y));
+
+
+   source.MergeSurface(save_surf, Point2i(0,0));
+}
+
+
+void DecoratedBox::ApplyTransformation(const AffineTransform2D & trans, bool save_transformation)
+{
+  Point2d new_min =  trans * original_min;
+  Point2d new_max = trans * original_max;
+
+  if((round(max.x - min.x +0.5)!=round( new_max.x -new_min.x+0.5)) || (round(max.y - min.y )!=round( new_max.y -new_min.y)))
+  {
+      delete m_border;
+      m_border = NULL;
+  }
+
+  min = new_min;
+  max = new_max;
+
+  if(save_transformation)
+  {
+
+   original_min = min;
+   original_max = max;
+  }
+
+  for(std::vector<PolygonItem *>::iterator item = items.begin();
+      item != items.end(); item++) {
+    (*item)->ApplyTransformation(trans);
+  }
+}
+
+void DecoratedBox::ResetTransformation()
+{
+  if((round(max.x - min.x )!=round( original_max.x -original_min.x)) || (round(max.y - min.y )!=round( original_max.y -original_min.y)))
+   {
+      delete m_border;
+      m_border = NULL;
+   }
+
+   min = original_min;
+   max = original_max;
+
+}
+
+void DecoratedBox::AddItem(PolygonItem * item)
+{
+  Point2d old_pos = item->GetPosition();
+  old_pos.x += min.x;
+  old_pos.y += min.y;
+  item->SetPosition(old_pos);
+  Polygon::AddItem(item);
 }
