@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@
 #include "include/app.h"
 #include "map/camera.h"
 #include "map/map.h"
-#include "tool/rectangle.h"
-#include "tool/debug.h"
+#include <WORMUX_rectangle.h>
+#include <WORMUX_debug.h>
 #include "graphic/spriteframe.h"
 
 Sprite::Sprite(bool _smooth) :
@@ -376,7 +376,7 @@ void Sprite::Blit( Surface &dest, int pos_x, int pos_y, int src_x, int src_y, ui
   }
 
   // For the cache mechanism
-  world.ToRedrawOnScreen(dstRect);
+  GetWorld().ToRedrawOnScreen(dstRect);
 }
 
 void Sprite::Finish()
