@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,14 +19,14 @@
  * Handle a SDL Surface
  *****************************************************************************/
 
-#include "graphic/surface.h"
 #include <SDL.h>
 #include <SDL_gfxPrimitives.h>
 #include <SDL_image.h>
 #include <SDL_rotozoom.h>
 #include <iostream>
 #include <png.h>
-#include "tool/i18n.h"
+
+#include "graphic/surface.h"
 #include "tool/math_tools.h"
 
 /* texturedPolygon import from SDL_gfx v2.0.15 */
@@ -305,7 +305,7 @@ int Surface::Blit(const Surface& src, const Rectanglei &srcRect, const Point2i &
  * @param spr
  * @param position
  */
-void Surface::MergeSurface(Surface &spr, const Point2i &pos)
+void Surface::MergeSurface( Surface &spr, const Point2i &pos)
 {
   Uint32 spr_pix, cur_pix;
   Uint8 r, g, b, a, p_r, p_g, p_b, p_a;
@@ -435,7 +435,7 @@ void Surface::Flip()
   SDL_Flip( surface );
 }
 
-int Surface::BoxColor(const Rectanglei &rect, const Color &color)
+  int Surface::BoxColor(const Rectanglei &rect, const Color &color)
 {
   if( rect.IsSizeZero() )
     return 0;
@@ -863,3 +863,97 @@ SDL_Rect Surface::GetSDLRect(const Point2i &pt) const
 
   return sdlRect;
 }
+
+Uint32 Surface::ComputeCRC()
+{
+  Uint32 crc = 0;
+  Uint32 current_pix;
+  SDL_PixelFormat * current_fmt = surface->format;
+  Uint8 r, g, b, a;
+
+  Point2i offset;
+  int current_offset;
+
+  Lock();
+  // for each pixel of the image
+  for (offset.x = 0; offset.x < GetWidth(); offset.x++) {
+    for (offset.y = 0; offset.y < GetHeight(); offset.y++) {
+
+      current_offset = offset.y * surface->w + offset.x;
+
+      // Retrieving a pixel of sprite to merge
+      current_pix = ((Uint32*)surface->pixels)[current_offset];
+
+      // Retreiving each chanel of the pixel using pixel format
+      r = (Uint8)(((current_pix & current_fmt->Rmask) >> current_fmt->Rshift) << current_fmt->Rloss);
+      g = (Uint8)(((current_pix & current_fmt->Gmask) >> current_fmt->Gshift) << current_fmt->Gloss);
+      b = (Uint8)(((current_pix & current_fmt->Bmask) >> current_fmt->Bshift) << current_fmt->Bloss);
+      a = (Uint8)(((current_pix & current_fmt->Amask) >> current_fmt->Ashift) << current_fmt->Aloss);
+
+      // Computing CRC - each time, we had at most 255*4, the biggest storable value
+      // on a Uint32 is 4294967296
+      // avoid integer overflow with a stupid modulo
+      crc += (r + g + b + a); // each time, we had at most 255*4
+      crc = crc % 429496000;
+    }
+  }
+
+  Unlock();
+  return crc;
+}
+
+
+/**
+ * Set an alpha . This's alpha is set to red value off mask
+ *
+ * @param mask
+ * @param position
+ */
+void Surface::MergeAlphaSurface(const Surface &mask, const Point2i &pos)
+{
+  int dest_x = pos.x;
+  int dest_y = pos.y;
+  int size_x = mask.GetWidth();
+  int size_y = mask.GetHeight();
+  int mask_x = 0;
+  int mask_y = 0;
+
+  if(dest_x<0){
+    dest_x = 0;
+    mask_x = -pos.x;
+	}
+  if(dest_y<0){
+    dest_y = 0;
+    mask_y = -pos.y;
+  }
+
+  if((size_x + dest_x) > GetWidth()){
+    size_x = GetWidth()- dest_x;
+  }
+
+  if((size_y + dest_y) > GetHeight()){
+    size_y = GetHeight() - dest_y;
+  }
+  Uint32 temp_pix;
+
+  Uint32 mask_color, this_color;
+  Uint8 mask_r, mask_g, mask_b, mask_a;
+  Uint8 this_r, this_g, this_b, this_a;
+
+  for(int i = 0; i<size_x;i++){
+    for(int j = 0;j<size_y;j++){
+      //Copy red pixel of mask in alpha pixel of this
+      mask_color  = mask.GetPixel(i + mask_x, j + mask_y);
+      this_color = GetPixel(i + dest_x, j + dest_y) ;
+
+      GetRGBA(this_color, this_r, this_g, this_b, this_a);
+      mask.GetRGBA(mask_color,mask_r,mask_g,mask_b,mask_a);
+
+      if(mask_r < this_a){
+        temp_pix = MapRGBA(this_r, this_g, this_b, mask_r);
+        PutPixel(i+ dest_x, j + dest_y, temp_pix);
+      }
+
+    }
+  }
+}
