@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,14 +40,14 @@ ComboBox::ComboBox (const std::string &label,
   position = Point2i(-1, -1);
   size = _size;
 
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
-  m_image = resource_manager.LoadImage(res, resource_id);
-  m_annulus_background = resource_manager.LoadImage(res, "menu/annulus_background");
-  m_annulus_foreground = resource_manager.LoadImage(res, "menu/annulus_foreground");
-  m_progress_color = resource_manager.LoadColor(res, "menu/annulus_progress_color");
-  resource_manager.UnLoadXMLProfile( res);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
+  m_image = GetResourceManager().LoadImage(res, resource_id);
+  m_annulus_background = GetResourceManager().LoadImage(res, "menu/annulus_background");
+  m_annulus_foreground = GetResourceManager().LoadImage(res, "menu/annulus_foreground");
+  m_progress_color = GetResourceManager().LoadColor(res, "menu/annulus_progress_color");
+  GetResourceManager().UnLoadXMLProfile( res);
 
-  txt_label = new Text(label, dark_gray_color, Font::FONT_MEDIUM, Font::FONT_BOLD, false);
+  txt_label = new Text(label, dark_gray_color, Font::FONT_SMALL, Font::FONT_BOLD, false);
   txt_label->SetMaxWidth(GetSizeX());
 
   txt_value_black = new Text("", black_color, Font::FONT_MEDIUM, Font::FONT_BOLD, false);
@@ -135,12 +135,12 @@ Widget* ComboBox::ClickUp(const Point2i &mousePosition, uint button)
 {
   NeedRedrawing();
 
-  if (button == SDL_BUTTON_LEFT && Contains(mousePosition)) {
+  if (button == Mouse::BUTTON_LEFT() && Contains(mousePosition)) {
 
     SetChoice(m_index + 1);
     return this;
 
-  } else if (button == SDL_BUTTON_RIGHT && Contains(mousePosition)) {
+  } else if (button == Mouse::BUTTON_RIGHT() && Contains(mousePosition)) {
 
     SetChoice(m_index - 1);
     return this;
