@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 #include "include/base.h"
 #include "graphic/font.h"
-#include "tool/rectangle.h"
+#include <WORMUX_rectangle.h>
 #include "widget.h"
 #include <list>
 
@@ -44,6 +44,8 @@ class MsgBox : public Widget
 
   void NewMessage(const std::string& msg, const Color& color = white_color);
 
+  void Clear();
+
   virtual void Draw (const Point2i &mousePosition) const;
   virtual void Pack();
 };
