@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class Surface;
 class NullWidget : public Widget
 {
  public:
-  NullWidget(const Rectanglei&) {};
+  NullWidget(const Point2i& size) : Widget(size) {};
   virtual ~NullWidget() {};
   virtual void Draw(const Point2i&) const {};
   virtual void Pack() {};
