@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,15 +31,15 @@
 PictureTextCBox::PictureTextCBox(const std::string &label,
                                  const std::string &resource_id,
                                  const Point2i &_size, bool value):
-  CheckBox(new Text(label, dark_gray_color, Font::FONT_MEDIUM, Font::FONT_BOLD, false),
+  CheckBox(new Text(label, dark_gray_color, Font::FONT_SMALL, Font::FONT_BOLD, false),
 	   _size.x, value)
 {
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
-  m_image = resource_manager.LoadImage(res, resource_id);
-  m_enabled = resource_manager.LoadImage(res, "menu/enabled");
-  m_disabled_front = resource_manager.LoadImage(res, "menu/disabled_front");
-  m_disabled_back = resource_manager.LoadImage(res, "menu/disabled_back");
-  resource_manager.UnLoadXMLProfile( res);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
+  m_image = GetResourceManager().LoadImage(res, resource_id);
+  m_enabled = GetResourceManager().LoadImage(res, "menu/enabled");
+  m_disabled_front = GetResourceManager().LoadImage(res, "menu/disabled_front");
+  m_disabled_back = GetResourceManager().LoadImage(res, "menu/disabled_back");
+  GetResourceManager().UnLoadXMLProfile( res);
   m_value = value;
 
   txt_label->SetMaxWidth(size.x);
@@ -47,7 +47,7 @@ PictureTextCBox::PictureTextCBox(const std::string &label,
 
 void PictureTextCBox::Draw(const Point2i &/*mousePosition*/) const
 {
-  Surface& video_window = AppWormux::GetInstance()->video->window;
+  Surface& video_window = GetMainWindow();
 
   if (m_value)
     {
