@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,9 +39,9 @@ PictureWidget::PictureWidget (const Point2i& _size, const std::string& resource_
   spr = NULL;
   disabled = false;
 
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
-  SetSurface(resource_manager.LoadImage(res, resource_id), scale, scale);
-  resource_manager.UnLoadXMLProfile( res);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
+  SetSurface(GetResourceManager().LoadImage(res, resource_id), scale, scale);
+  GetResourceManager().UnLoadXMLProfile( res);
 }
 
 PictureWidget::~PictureWidget()
@@ -78,7 +78,7 @@ void PictureWidget::SetNoSurface()
 
 void PictureWidget::Draw(const Point2i &/*mousePosition*/) const
 {
-  Surface& surf = AppWormux::GetInstance()->video->window;
+  Surface& surf = GetMainWindow();
 
   if (spr != NULL) {
     int x = GetPositionX() + ( GetSizeX()/2 ) - (spr->GetWidth()/2);
