@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,16 +33,16 @@ Question::Question(type _type)
   background = NULL;
   text = NULL;
 
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
   switch (_type) {
   case WARNING:
-    icon = new Sprite(resource_manager.LoadImage(res,"menu/ico_warning"));
+    icon = new Sprite(GetResourceManager().LoadImage(res,"menu/ico_warning"));
     break;
   case NO_TYPE:
     icon = NULL;
     break;
   }
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
 }
 
 Question::~Question()
@@ -173,14 +173,14 @@ void Question::Set (const std::string &pmessage,
 
   if(bg_sprite != "")
   {
-    Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
-    background = new Sprite(resource_manager.LoadImage(res,bg_sprite), true);
+    Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml", false);
+    background = new Sprite(GetResourceManager().LoadImage(res,bg_sprite), true);
     background->cache.EnableLastFrameCache();
-    background->ScaleSize(AppWormux::GetInstance()->video->window.GetSize());
-    resource_manager.UnLoadXMLProfile( res);
+    background->ScaleSize(GetMainWindow().GetSize());
+    GetResourceManager().UnLoadXMLProfile( res);
   }
   else
   {
-    text->SetMaxWidth(AppWormux::GetInstance()->video->window.GetWidth()/2);
+    text->SetMaxWidth(GetMainWindow().GetWidth()/2);
   }
 }
