@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,14 +37,16 @@ const int Constants::MAP_MAX_SIZE = 6000*6000;
 Constants::Constants()
 {
   AUTHORS.push_back ("Lawrence AZZOUG");
-  AUTHORS.push_back ("Anthony CARRE");
+  AUTHORS.push_back ("Frédéric BERTOLUS");
+  AUTHORS.push_back ("Anthony CARRÉ");
   AUTHORS.push_back ("Laurent DEFERT SIMONNEAU");
   AUTHORS.push_back ("Jean-Christophe DUBERGA");
-  AUTHORS.push_back ("Matthieu FERTRE");
+  AUTHORS.push_back ("Matthieu FERTRÉ");
+  AUTHORS.push_back ("Christophe GISQUET");
   AUTHORS.push_back ("Sebastien GONZALVE");
   AUTHORS.push_back ("Reiner HERRMANN");
   AUTHORS.push_back ("Renaud LOTTIAUX");
-  AUTHORS.push_back ("Yannig PERRE");
+  AUTHORS.push_back ("Yannig PERRÉ");
   AUTHORS.push_back ("Olivie SERRES");
   AUTHORS.push_back ("Victor STINNER");
 }
