@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 #include "base.h"
 #include <string>
 #include <vector>
-#include "include/singleton.h"
-#include "tool/point.h"
+#include <WORMUX_singleton.h>
+#include <WORMUX_point.h>
 
 class Constants : public Singleton<Constants>
 {
@@ -38,9 +38,6 @@ public:
   static const std::string ENV_LOCALEDIR;
   static const std::string ENV_FONT_PATH;
 
-  // Maximum number of loops for the test ...
-  static const uint NBR_BCL_MAX_EST_VIDE; // Is an object in vacuum ?
-
   // Authors list
   std::vector<std::string> AUTHORS;
 
@@ -52,9 +49,6 @@ public:
   static const Point2i MAP_MIN_SIZE;
   static const int MAP_MAX_SIZE;
 
-  // Minimal free heigth (in pixel) for the playground to be said "open"
-  static const uint HAUT_MIN_TERRAIN_OUVERT;
-
 protected:
   friend class Singleton<Constants>;
   Constants();
