@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ void GameMessages::Draw(){
   uint msgy = 50;
 
   for( iterator i=liste.begin(); i != liste.end(); ++i ){
-    (*i)->DrawCenterTop(Point2i(AppWormux::GetInstance()->video->window.GetWidth()/2, msgy));
+    (*i)->DrawCenterTop(Point2i(GetMainWindow().GetWidth()/2, msgy));
     msgy += HAUT_POLICE_MINI + INTERLIGNE_MINI;
   }
 }
