@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,27 +22,26 @@
 #ifndef LOADING_SCREEN_H
 #define LOADING_SCREEN_H
 
+#include "include/base.h"
 #include <string>
-#include "../graphic/sprite.h"
-#include "../tool/resource_manager.h"
+
+// Forwar declarations
+class Profile;
+class Sprite;
 
 class LoadingScreen
 {
  private:
-  static LoadingScreen * singleton;
-
   Profile * res;
   Sprite * loading_bg;
 
-  LoadingScreen();
  public:
+  LoadingScreen();
   ~LoadingScreen();
 
-  static LoadingScreen* GetInstance();
-
   void DrawBackground();
-  void StartLoading(uint nb, std::string resource, 
-		    std::string label);
+  void StartLoading(uint nb, const std::string& resource,
+                    const std::string& label) const;
 };
 
 #endif
