@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include "map/map.h"
 #include "team/macro.h"
 #include "team/team.h"
-#include "tool/point.h"
+#include <WORMUX_point.h>
 #include "tool/resource_manager.h"
 #include "weapon/weapon.h"
 #include "game/time.h"
@@ -65,16 +65,16 @@ Mouse::Mouse():
   visible = MOUSE_VISIBLE;
 
   // Load the different pointers
-  Profile *res = resource_manager.LoadXMLProfile("cursors.xml", false);
+  Profile *res = GetResourceManager().LoadXMLProfile("cursors.xml", false);
 
   for (int i=POINTER_SELECT; i < POINTER_FIRE; i++) {
     cursors.insert(std::make_pair(Mouse::pointer_t(i),
-				  resource_manager.LoadMouseCursor(res, __pointers[i],
+				  GetResourceManager().LoadMouseCursor(res, __pointers[i],
 								   Mouse::pointer_t(i))));
   }
 
   current_pointer = POINTER_STANDARD;
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
 }
 
 bool Mouse::HasFocus() const
@@ -118,13 +118,13 @@ void Mouse::ActionLeftClic(bool) const
     }
 
     if (character_found) {
-      Action * next_character = new Action(Action::ACTION_PLAYER_NEXT_CHARACTER);
-      next_character->StoreActiveCharacter();
+      Action * next_character = new Action(Action::ACTION_PLAYER_CHANGE_CHARACTER);
+      Character::StoreActiveCharacter(next_character);
 
       while ( &(*it) != &ActiveCharacter() )
         ActiveTeam().NextCharacter ();
 
-      next_character->StoreActiveCharacter();
+      Character::StoreActiveCharacter(next_character);
       ActionHandler::GetInstance()->NewAction(next_character);
 
       return;
@@ -161,6 +161,22 @@ void Mouse::ActionWheelDown(bool shift) const
   ActiveTeam().AccessWeapon().HandleMouseWheelDown(shift);
 }
 
+Uint8 Mouse::BUTTON_RIGHT() // static method
+{
+  if (Config::GetRef().GetLeftHandedMouse())
+    return SDL_BUTTON_LEFT;
+
+  return SDL_BUTTON_RIGHT;
+}
+
+Uint8 Mouse::BUTTON_LEFT() // static method
+{
+  if (Config::GetRef().GetLeftHandedMouse())
+    return SDL_BUTTON_RIGHT;
+
+  return SDL_BUTTON_LEFT;
+}
+
 bool Mouse::HandleClic (const SDL_Event& event) const
 {
   if (!HasFocus()) {
@@ -180,22 +196,15 @@ bool Mouse::HandleClic (const SDL_Event& event) const
 
   if( event.type == SDL_MOUSEBUTTONDOWN ){
     bool shift = !!(SDL_GetModState() & KMOD_SHIFT);
-    switch (event.button.button) {
-    case SDL_BUTTON_RIGHT:
+
+    if (event.button.button == Mouse::BUTTON_RIGHT())
       ActionRightClic(shift);
-      break;
-    case SDL_BUTTON_LEFT:
+    else if (event.button.button == Mouse::BUTTON_LEFT())
       ActionLeftClic(shift);
-      break;
-    case SDL_BUTTON_WHEELDOWN:
+    else if (event.button.button == SDL_BUTTON_WHEELDOWN)
       ActionWheelDown(shift);
-      break;
-    case SDL_BUTTON_WHEELUP:
+    else if (event.button.button == SDL_BUTTON_WHEELUP)
       ActionWheelUp(shift);
-      break;
-    default:
-      break;
-    }
   }
   return true;
 }
@@ -311,7 +320,7 @@ void Mouse::Draw() const
   const MouseCursor& cursor = GetCursor(current_pointer);
   const Surface& surf = cursor.GetSurface();
   GetMainWindow().Blit(surf, GetPosition() - cursor.GetClicPos());
-  world.ToRedrawOnScreen(Rectanglei(GetPosition().x - cursor.GetClicPos().x,
+  GetWorld().ToRedrawOnScreen(Rectanglei(GetPosition().x - cursor.GetClicPos().x,
                                     GetPosition().y - cursor.GetClicPos().y,
 				    surf.GetWidth(), surf.GetHeight()));
 }
@@ -334,7 +343,7 @@ void Mouse::Hide()
 {
   if(visible == MOUSE_VISIBLE)
   {
-  last_hide_time = Time::GetInstance()->Read();
+    last_hide_time = Time::GetInstance()->Read();
   }
   visible = MOUSE_HIDDEN;
   SDL_ShowCursor(false); // be sure cursor is invisible
