@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@
 #include <map>
 #include "graphic/surface.h"
 #include "include/base.h"
-#include "include/singleton.h"
-#include "tool/point.h"
+#include <WORMUX_singleton.h>
+#include <WORMUX_point.h>
 
 // Forward declarations
 struct SDL_event;
@@ -65,6 +65,7 @@ private:
 
   visibility_t visible;
   pointer_t current_pointer;
+  uint last_hide_time;
 
   void GetDesignatedCharacter() const;
 
@@ -79,12 +80,19 @@ protected:
   Mouse();
 
 public:
+
+  // to compare with SDL_Event.button.button
+  // and manage left-handed mouse option "transparently"
+  static Uint8 BUTTON_RIGHT();
+  static Uint8 BUTTON_LEFT();
+
   bool HandleClic (const SDL_Event& event) const;
   void Refresh();
 
   Point2i GetPosition() const;
   Point2i GetWorldPosition() const;
   void CenterPointer();
+  void SetPosition(Point2i pos);
 
   // Choose the pointer
   pointer_t GetPointer() const;
@@ -95,6 +103,8 @@ public:
   void Show();
   void Hide();
 
+  bool HasFocus() const;
+
   visibility_t GetVisibility() const { return visible; };
 };
 #endif
