@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,26 +19,27 @@
  * Interface showing various informations about the game.
  *****************************************************************************/
 
-#include "interface/weapon_menu.h"
 #include <sstream>
-#include "interface/interface.h"
+
+#include "game/config.h"
 #include "game/time.h"
+#include "game/game.h"
 #include "graphic/font.h"
 #include "graphic/polygon_generator.h"
 #include "graphic/sprite.h"
 #include "graphic/video.h"
 #include "include/action_handler.h"
 #include "include/app.h"
+#include "interface/interface.h"
 #include "interface/mouse.h"
+#include "interface/weapon_menu.h"
 #include "map/maps_list.h"
 #include "team/team.h"
 #include "team/teams_list.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "sound/jukebox.h"
 #include "weapon/weapon.h"
 #include "weapon/weapons_list.h"
-#include "game/config.h"
 
 // Weapon menu
 const uint ICONS_DRAW_TIME = 400;       // Time to display all icons (in ms)
@@ -113,23 +114,48 @@ void WeaponMenuItem::Draw(Surface * dest)
       scale = (scale > DEFAULT_ICON_SCALE ? scale : DEFAULT_ICON_SCALE);
     }
   }
+  item->SetAlpha(1);
   item->Scale((float)scale, (float)scale);
-  PolygonItem::Draw(dest);
+
   int nb_bullets = ActiveTeam().ReadNbAmmos(weapon->GetType());
   Point2i tmp = GetOffsetAlignment() + Point2i(0, item->GetWidth() - 10);
+
   if(nb_bullets ==  INFINITE_AMMO) {
+    PolygonItem::Draw(dest);
     (*Font::GetInstance(Font::FONT_MEDIUM, Font::FONT_BOLD)).WriteLeft(tmp, "∞", dark_gray_color);
   } else if(nb_bullets == 0) {
-    tmp += Point2i(0, -(int)Interface::GetInstance()->GetWeaponsMenu().GetCrossSymbol()->GetHeight() / 2);
-    Interface::GetInstance()->GetWeaponsMenu().GetCrossSymbol()->Blit(*dest, tmp);
+      if (weapon->AvailableAfterTurn() > (int)Game::GetInstance()->GetCurrentTurn()-1){
+        PolygonItem::Draw(dest);
+        tmp.y -= 4;
+        m_parent->m_not_yet_available->Blit(*dest, tmp);
+
+
+        tmp.x += m_parent->m_not_yet_available->GetWidth()-5;
+        tmp.y += 10;
+        std::ostringstream txt;
+        txt << weapon->AvailableAfterTurn()-Game::GetInstance()->GetCurrentTurn();
+        txt << " ";
+        (*Font::GetInstance(Font::FONT_SMALL, Font::FONT_BOLD)).WriteLeft(tmp, txt.str(), dark_red_color);
+      }  else{
+        item->SetAlpha(0.3);
+        PolygonItem::Draw(dest);
+      }
   } else {
+    PolygonItem::Draw(dest);
     std::ostringstream txt;
     txt << nb_bullets;
     (*Font::GetInstance(Font::FONT_MEDIUM, Font::FONT_BOLD)).WriteLeft(tmp, txt.str(), dark_gray_color);
   }
 }
 
+void WeaponMenuItem::SetParent(WeaponsMenu *parent)
+{
+  m_parent = parent;
+}
+
+
 WeaponsMenu::WeaponsMenu():
+  m_not_yet_available(NULL),
   weapons_menu(NULL),
   tools_menu(NULL),
   current_overfly_item(NULL),
@@ -137,7 +163,7 @@ WeaponsMenu::WeaponsMenu():
   shear(),
   rotation(),
   zoom(),
-  cross(NULL),
+
   show(false),
   motion_start_time(0),
   icons_draw_time(ICONS_DRAW_TIME),
@@ -148,29 +174,26 @@ WeaponsMenu::WeaponsMenu():
   old_pointer(Mouse::POINTER_SELECT)
 {
   // Loading value from XML
-  Profile *res = resource_manager.LoadXMLProfile("graphism.xml", false);
-  cross = new Sprite(resource_manager.LoadImage(res, "interface/cross"));
+  Profile *res = GetResourceManager().LoadXMLProfile("graphism.xml", false);
+  m_not_yet_available = GetResourceManager().LoadSprite( res, "interface/hourglass");
+
+
   // Polygon Size
-  Point2i size = resource_manager.LoadPoint2i(res, "interface/weapons_interface_size");
-  weapons_menu = PolygonGenerator::GenerateRoundedRectangle(size.x, size.y, 20);
-  size = resource_manager.LoadPoint2i(res, "interface/tools_interface_size");
-  tools_menu = PolygonGenerator::GenerateRoundedRectangle(size.x, size.y, 20);
+  Point2i size = GetResourceManager().LoadPoint2i(res, "interface/weapons_interface_size");
+  weapons_menu = PolygonGenerator::GenerateDecoratedBox(size.x, size.y);
+  size = GetResourceManager().LoadPoint2i(res, "interface/tools_interface_size");
+  tools_menu = PolygonGenerator::GenerateDecoratedBox(size.x, size.y);
   help = NULL;
   // Setting colors
-  Color plane_color = resource_manager.LoadColor(res, "interface/background_color");
-  Color border_color = resource_manager.LoadColor(res, "interface/border_color");
+  Color plane_color = GetResourceManager().LoadColor(res, "interface/background_color");
+  Color border_color = GetResourceManager().LoadColor(res, "interface/border_color");
   weapons_menu->SetPlaneColor(plane_color);
   weapons_menu->SetBorderColor(border_color);
   tools_menu->SetPlaneColor(plane_color);
   tools_menu->SetBorderColor(border_color);
 
-  // Adding label
-  weapons_menu->AddItem(new Sprite(Font::GenerateSurface(_("Weapons"), dark_gray_color, Font::FONT_BIG)),
-                        weapons_menu->GetMin() + Point2d(20, 20), PolygonItem::LEFT, PolygonItem::TOP);
-  tools_menu->AddItem(new Sprite(Font::GenerateSurface(_("Tools"), dark_gray_color, Font::FONT_BIG)),
-                      tools_menu->GetMin() + Point2d(20, 20), PolygonItem::LEFT, PolygonItem::TOP);
 
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
 }
 
 WeaponsMenu::~WeaponsMenu()
@@ -181,8 +204,8 @@ WeaponsMenu::~WeaponsMenu()
     delete tools_menu;
   if(help)
     delete help;
-  if (cross)
-    delete cross;
+  if (m_not_yet_available)
+    delete m_not_yet_available;
   if (nb_weapon_type)
     delete[] nb_weapon_type;
 }
@@ -196,12 +219,14 @@ void WeaponsMenu::AddWeapon(Weapon* new_item)
   Point2d position;
   Weapon::category_t num_sort = new_item->Category();
   if(num_sort < 6) {
-    position = weapons_menu->GetMin() + Point2d(50 + nb_weapon_type[num_sort - 1] * 50, 80 + (num_sort - 1) * 50);
+    position = weapons_menu->GetMin() + Point2d(30 + nb_weapon_type[num_sort - 1] * 45, 25 + (num_sort - 1) * 45);
     WeaponMenuItem * item = new WeaponMenuItem(new_item, position);
+    item->SetParent(this);
     weapons_menu->AddItem(item);
   } else {
-    position = tools_menu->GetMin() + Point2d(50 + (num_sort - 6) * 50, 80 + nb_weapon_type[num_sort - 1] * 50);
+    position = tools_menu->GetMin() + Point2d(30 + nb_weapon_type[num_sort - 1] * 45, 25 + (num_sort - 6) * 45);
     WeaponMenuItem * item = new WeaponMenuItem(new_item, position);
+    item->SetParent(this);
     tools_menu->AddItem(item);
   }
 
@@ -219,7 +244,7 @@ void WeaponsMenu::Show()
       motion_start_time = Time::GetInstance()->Read() - (GetIconsDrawTime() - (Time::GetInstance()->Read() - motion_start_time));
     show = true;
 
-    JukeBox::GetInstance()->Play("share", "menu/weapon_menu_show");
+    JukeBox::GetInstance()->Play("default", "menu/weapon_menu_show");
 
     old_pointer = Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
   }
@@ -236,7 +261,7 @@ void WeaponsMenu::Hide(bool play_sound)
     show = false;
 
     if (play_sound)
-      JukeBox::GetInstance()->Play("share", "menu/weapon_menu_hide");
+      JukeBox::GetInstance()->Play("default", "menu/weapon_menu_hide");
 
     Mouse::GetInstance()->SetPointer(old_pointer);
   }
@@ -267,23 +292,21 @@ void WeaponsMenu::RefreshWeaponList()
   weapons_menu->ResetTransformation();
   tools_menu->ResetTransformation();
   // Refreshing Weapons menu
+
   std::vector<PolygonItem *> items = weapons_menu->GetItem();
   std::vector<PolygonItem *>::iterator item = items.begin();
-  PolygonItem * tmp = (*item); item++;
   for(; item != items.end(); item++) {
     delete (*item);
   }
   weapons_menu->ClearItem(false);
-  weapons_menu->AddItem(tmp);
+
   // Tools menu
   items = tools_menu->GetItem();
   item = items.begin();
-  tmp = (*item); item++;
   for(; item != items.end(); item++) {
     delete (*item);
   }
   tools_menu->ClearItem(false);
-  tools_menu->AddItem(tmp);
   // Reinserting weapon
   WeaponsList *weapons_list = WeaponsList::GetInstance();
   for (WeaponsList::weapons_list_it it=weapons_list->GetList().begin();
@@ -294,42 +317,63 @@ void WeaponsMenu::RefreshWeaponList()
 
 AffineTransform2D WeaponsMenu::ComputeToolTransformation()
 {
+  uint scroll_border = 0;
+  if (Config::GetInstance()->GetScrollOnBorder()) {
+    scroll_border = Config::GetInstance()->GetScrollBorderSize();
+  }
+
   // Init animation parameter
-  Point2d start(GetMainWindow().GetWidth(), 0);
-  Point2i pos(GetMainWindow().GetSize() / 2 + Point2i((int)(tools_menu->GetWidth() / 2) + 10, 0));
+  Point2d start(GetMainWindow().GetWidth() - tools_menu->GetWidth() - 5 - scroll_border,
+                GetMainWindow().GetHeight() + weapons_menu->GetHeight() + 50);
+  Point2i pos(GetMainWindow().GetWidth() - tools_menu->GetWidth() - 5 - scroll_border,
+              GetMainWindow().GetHeight()- tools_menu->GetHeight() - 5 );
+
+  if (Interface::GetRef().GetMenuPosition().GetX() + Interface::GetRef().GetWidth() > start.GetX()) {
+    start.y -= Interface::GetRef().GetHeight();
+    pos.y -= Interface::GetRef().GetHeight();
+  }
+
   Point2d end(POINT2I_2_POINT2D(pos));
-  double zoom_start = 0.2, zoom_end = 1.0;
-  double angle_start = M_PI * GetRotationTime(), angle_end = 0.0;
+
   // Define the animation
   position.SetTranslationAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show, start, end);
-  zoom.SetShrinkAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show,
-                          zoom_start, zoom_start, zoom_end, zoom_end);
-  rotation.SetRotationAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show, angle_start, angle_end);
-  shear.SetShearAnimation(motion_start_time + GetIconsDrawTime(), GetJellyTime(), Time::GetInstance()->Read(), !show, 2.0, 0.2, 0.0);
-  return position * shear * zoom * rotation;
+
+  return position ;
 }
 
 AffineTransform2D WeaponsMenu::ComputeWeaponTransformation()
 {
+  uint scroll_border = 0;
+  if (Config::GetInstance()->GetScrollOnBorder()) {
+    scroll_border = Config::GetInstance()->GetScrollBorderSize();
+  }
+
   // Init animation parameter
-  Point2d start(0, 0);
-  Point2i pos(GetMainWindow().GetSize() / 2 - Point2i((int)(weapons_menu->GetWidth() / 2) + 10, 0));
+  Point2d start(GetMainWindow().GetWidth() - weapons_menu->GetWidth() - 5 - scroll_border,
+                GetMainWindow().GetHeight());
+  Point2i pos(GetMainWindow().GetWidth() - weapons_menu->GetWidth() - 5 - scroll_border,
+              GetMainWindow().GetHeight()- weapons_menu->GetHeight() - tools_menu->GetHeight() - 10 );
+
+  if (Interface::GetRef().GetMenuPosition().GetX() + Interface::GetRef().GetWidth() > start.GetX()) {
+    start.y -= Interface::GetRef().GetHeight();
+    pos.y -= Interface::GetRef().GetHeight();
+  }
+
   Point2d end(POINT2I_2_POINT2D(pos));
-  double zoom_start = 0.2, zoom_end = 1.0;
-  double angle_start = -M_PI * GetRotationTime(), angle_end = 0.0;
+
  // Define the animation
   position.SetTranslationAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show, start, end);
-  zoom.SetShrinkAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show,
-                          zoom_start, zoom_start, zoom_end, zoom_end);
-  rotation.SetRotationAnimation(motion_start_time, GetIconsDrawTime(), Time::GetInstance()->Read(), !show, angle_start, angle_end);
-  shear.SetShearAnimation(motion_start_time + GetIconsDrawTime(), GetJellyTime(), Time::GetInstance()->Read(), !show, 2.0, 0.2, 0.0);
-  return position * shear * zoom * rotation;
+
+  return position ;
 }
 
 void WeaponsMenu::Draw()
 {
   if(!show && (motion_start_time == 0 || Time::GetInstance()->Read() >= motion_start_time + GetIconsDrawTime()))
     return;
+
+  // Update animation
+  m_not_yet_available->Update();
   // Draw weapons menu
   weapons_menu->ApplyTransformation(ComputeWeaponTransformation());
   weapons_menu->DrawOnScreen();
@@ -347,7 +391,6 @@ Weapon * WeaponsMenu::UpdateCurrentOverflyItem(const Polygon * poly)
   WeaponMenuItem * tmp;
   Interface::GetInstance()->SetCurrentOverflyWeapon(NULL);
   std::vector<PolygonItem *>::iterator item = items.begin();
-  ++item; // Skeeping first item which is a text label
   for(; item != items.end(); item++) {
     tmp = (WeaponMenuItem *)(*item);
     if(tmp->IsMouseOver()) {
