@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,11 +31,14 @@
 
 // Forward declaration
 class Weapon;
+class WeaponsMenu;
 
 class WeaponMenuItem : public PolygonItem {
   WeaponMenuItem(const WeaponMenuItem&);
   const WeaponMenuItem& operator=(const WeaponMenuItem&);
   bool zoom;
+private:
+  WeaponsMenu *m_parent;
 
  public:
   Weapon* weapon;
@@ -51,12 +54,14 @@ class WeaponMenuItem : public PolygonItem {
   uint GetZoomTime() const { return zoom_time; };
   void SetZoomTime(uint time) { zoom_time = time; };
   Weapon * GetWeapon() const { return weapon; };
+  void SetParent(WeaponsMenu *);
 };
 
 class WeaponsMenu
 {
  public:
   static const int MAX_NUMBER_OF_WEAPON;
+  Sprite * m_not_yet_available;
 
  private:
   Polygon * weapons_menu;
@@ -67,7 +72,6 @@ class WeaponsMenu
   AffineTransform2D shear;
   AffineTransform2D rotation;
   AffineTransform2D zoom;
-  Sprite * cross;
   bool show;
   uint motion_start_time;
   uint select_start_time;
@@ -96,7 +100,6 @@ class WeaponsMenu
   bool IsDisplayed() const { return show; };
   bool ActionClic(const Point2i &mouse_pos);
   Sprite * GetInfiniteSymbol() const;
-  Sprite * GetCrossSymbol() const { return cross; };
   Weapon * UpdateCurrentOverflyItem(const Polygon * poly);
   uint GetJellyTime() const { return jelly_time; };
   uint GetIconsDrawTime() const { return icons_draw_time; };
