@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
  *  Starting file. (the 'main' function is here.)
  *****************************************************************************/
 
-#include "include/app.h"
 #include <algorithm>
 #include <exception>
 #include <sstream>
@@ -30,9 +29,11 @@
 #ifndef WIN32
 #include <signal.h>
 #endif
-using namespace std;
-
 #include <SDL.h>
+#include <WORMUX_debug.h>
+#include <WORMUX_index_server.h>
+#include <WORMUX_random.h>
+#include <WORMUX_singleton.h>
 #include "game/config.h"
 #include "game/game.h"
 #include "game/time.h"
@@ -41,8 +42,9 @@ using namespace std;
 #include "graphic/text.h"
 #include "graphic/video.h"
 #include "include/action_handler.h"
+#include "include/app.h"
+#include "include/base.h"
 #include "include/constant.h"
-#include "include/singleton.h"
 #include "map/map.h"
 #include "menu/credits_menu.h"
 #include "menu/game_menu.h"
@@ -50,15 +52,17 @@ using namespace std;
 #include "menu/main_menu.h"
 #include "menu/network_connection_menu.h"
 #include "menu/options_menu.h"
-#include "network/index_server.h"
+#include "menu/skin_menu.h"
 #include "particles/particle.h"
 #include "sound/jukebox.h"
-#include "tool/debug.h"
-#include "tool/i18n.h"
+#ifdef DEBUG
+#include "include/debugmasks.h"
+#endif
 
 static MainMenu::menu_item choice = MainMenu::NONE;
 static bool skip_menu = false;
-//static NetworkConnectionMenu::network_menu_action_t net_action = NetworkConnectionMenu::NET_BROWSE_INTERNET;
+static const char* skin = NULL;
+static NetworkConnectionMenu::network_menu_action_t net_action = NetworkConnectionMenu::NET_NOTHING;
 
 AppWormux *AppWormux::singleton = NULL;
 
@@ -76,8 +80,8 @@ AppWormux::AppWormux():
   menu(NULL)
 {
   JukeBox::GetInstance()->Init();
-
-  cout << "[ " << _("Run game") << " ]" << endl;
+  RandomLocal().InitRandom();
+  std::cout << "[ " << _("Run game") << " ]" << std::endl;
 }
 
 AppWormux::~AppWormux()
@@ -93,19 +97,23 @@ int AppWormux::Main(void)
 {
   bool quit = false;
 
+#ifndef DEBUG
   try
+#endif
   {
     DisplayLoadingPicture();
 
     OptionMenu::CheckUpdates();
 
+    Action_Handler_Init();
+
     do
     {
 
       if (choice == MainMenu::NONE)
       {
         MainMenu main_menu;
-        menu = &main_menu;
+        SetCurrentMenu(&main_menu);
         choice = main_menu.Run();
       }
 
@@ -116,66 +124,76 @@ int AppWormux::Main(void)
         case MainMenu::PLAY:
         {
           GameMenu game_menu;
-          menu = &game_menu;
+          SetCurrentMenu(&game_menu);
           game_menu.Run(skip_menu);
           break;
         }
         case MainMenu::NETWORK:
         {
-          NetworkConnectionMenu network_connection_menu;
-          menu = &network_connection_menu;
-          //network_connection_menu.SetAction(net_action);
+          NetworkConnectionMenu network_connection_menu(net_action);
+          SetCurrentMenu(&network_connection_menu);
           network_connection_menu.Run(skip_menu);
           break;
         }
         case MainMenu::HELP:
         {
           HelpMenu help_menu;
-          menu = &help_menu;
+          SetCurrentMenu(&help_menu);
           help_menu.Run();
           break;
         }
         case MainMenu::OPTIONS:
         {
           OptionMenu options_menu;
-          menu = &options_menu;
+          SetCurrentMenu(&options_menu);
           options_menu.Run();
           break;
         }
         case MainMenu::CREDITS:
         {
           CreditsMenu credits_menu;
-          menu = &credits_menu;
+          SetCurrentMenu(&credits_menu);
           credits_menu.Run();
           break;
         }
         case MainMenu::QUIT:
           quit = true;
+          break;
+        case MainMenu::SKIN_VIEWER:
+        {
+          SkinMenu skin_menu(skin);
+          SetCurrentMenu(&skin_menu);
+          skin_menu.Run();
+          break;
+        }
         default:
           break;
       }
-      menu = NULL;
+      SetCurrentMenu(NULL);
       choice = MainMenu::NONE;
       skip_menu = false;
-      //net_action = NetworkConnectionMenu::NET_BROWSE_INTERNET;
+      net_action = NetworkConnectionMenu::NET_NOTHING;
     }
     while (!quit);
 
     End();
   }
-  catch(const exception & e)
+#ifndef DEBUG
+  catch(const std::exception & e)
   {
-    cerr << endl
-      << "C++ exception caught:" << endl
-      << e.what() << endl << endl;
+    std::cerr << std::endl
+	 << "C++ exception caught:" << std::endl
+	 << e.what() << std::endl << std::endl;
+    AppWormux::DisplayError(e.what());
     WakeUpDebugger();
   }
   catch(...)
   {
-    cerr << endl
-      << "Unexpected exception caught..." << endl << endl;
+    std::cerr << std::endl
+      << "Unexpected exception caught..." << std::endl << std::endl;
     WakeUpDebugger();
   }
+#endif
 
   return 0;
 }
@@ -184,9 +202,9 @@ void AppWormux::DisplayLoadingPicture()
 {
   Config *config = Config::GetInstance();
 
-  string txt_version =
-    _("Version") + string(" ") + Constants::WORMUX_VERSION;
-  string filename = config->GetDataDir() + "menu" PATH_SEPARATOR "loading.png";
+  std::string txt_version =
+    _("Version") + std::string(" ") + Constants::WORMUX_VERSION;
+  std::string filename = config->GetDataDir() + "menu" PATH_SEPARATOR "loading.png";
 
   Surface surfaceLoading(filename.c_str());
   Sprite loading_image(surfaceLoading, true);
@@ -216,20 +234,46 @@ void AppWormux::SetCurrentMenu(Menu* _menu)
   menu = _menu;
 }
 
+Menu* AppWormux::GetCurrentMenu() const
+{
+  return menu;
+}
+
 void AppWormux::RefreshDisplay()
 {
-  if (Game::GetInstance()->IsGameLaunched()) {
-    world.DrawSky(true);
-    world.Draw(true);
+  if (Game::IsRunning()) {
+    GetWorld().DrawSky(true);
+    GetWorld().Draw(true);
   }
-  else if (menu) {
-    menu->RedrawMenu();
+  else if (GetCurrentMenu()) {
+    GetCurrentMenu()->RedrawMenu();
+  }
+}
+
+void AppWormux::DisplayError(const std::string &msg)
+{
+  std::cerr << msg << std::endl;
+
+  if (Game::IsRunning()) {
+    // nothing to do
+  } else if (singleton->GetCurrentMenu()) {
+    singleton->GetCurrentMenu()->DisplayError(msg);
+  }
+}
+
+void AppWormux::ReceiveMsgCallback(const std::string& msg)
+{
+  if (Game::IsRunning()) {
+    //Add message to chat session in Game
+    Game::GetInstance()->chatsession.NewMessage(msg);
+  } else if (GetCurrentMenu()) {
+    GetCurrentMenu()->ReceiveMsgCallback(msg);
   }
 }
 
 void AppWormux::End() const
 {
-  cout << endl << "[ " << _("Quit Wormux") << " ]" << endl;
+  std::cout << std::endl << "[ " << _("Quit Wormux") << " ]" << std::endl;
 
   /* FIXME calling Config->Save here sucks: it nothing was ever done, it loads
    * the whole stuff just before exiting... This should be moved, but where? */
@@ -240,37 +284,63 @@ void AppWormux::End() const
 #ifdef ENABLE_STATS
   SaveStatToXML("stats.xml");
 #endif
-  cout << "o " << _("If you found a bug or have a feature request "
-                    "send us a email (in english, please):")
-    << " " << Constants::EMAIL << endl;
+  std::cout << "o " << _("If you found a bug or have a feature request "
+                    "send us an email (in english, please):")
+    << " " << Constants::EMAIL << std::endl;
+}
+
+void AppWormux::EmergencyExit()
+{
+  delete AppWormux::GetInstance();
+  exit(EXIT_SUCCESS);
 }
 
 void DisplayWelcomeMessage()
 {
-  cout << "=== " << _("Wormux version ") << Constants::WORMUX_VERSION << endl;
-  cout << "=== " << _("Authors:") << ' ';
-  for (vector < string >::iterator it = Constants::GetInstance()->AUTHORS.begin(),
+  std::cout << "=== " << _("Wormux version ") << Constants::WORMUX_VERSION << std::endl;
+  std::cout << "=== " << _("Authors:") << ' ';
+  for (std::vector < std::string >::iterator it = Constants::GetInstance()->AUTHORS.begin(),
        fin = Constants::GetInstance()->AUTHORS.end(); it != fin; ++it)
     {
       if (it != Constants::GetInstance()->AUTHORS.begin())
-        cout << ", ";
-      cout << *it;
+        std::cout << ", ";
+      std::cout << *it;
     }
-  cout << endl
-    << "=== " << _("Website: ") << Constants::WEB_SITE << endl
-    << endl;
+  std::cout << std::endl
+    << "=== " << _("Website: ") << Constants::WEB_SITE << std::endl
+    << std::endl;
 
   // print the disclaimer
-  cout << "Wormux version " << Constants::WORMUX_VERSION
-    << ", Copyright (C) 2001-2008 Wormux Team" << endl
-    << "Wormux comes with ABSOLUTELY NO WARRANTY." << endl
-    << "This is free software and you are welcome to redistribute it" << endl
-    << "under certain conditions." << endl << endl
-    << "Read the file COPYING for details." << endl << endl;
+  std::cout << "Wormux version " << Constants::WORMUX_VERSION
+    << ", Copyright (C) 2001-2009 Wormux Team" << std::endl
+    << "Wormux comes with ABSOLUTELY NO WARRANTY." << std::endl
+    << "This is free software and you are welcome to redistribute it" << std::endl
+    << "under certain conditions." << std::endl << std::endl
+    << "Read the file COPYING for details." << std::endl << std::endl;
 
 #ifdef DEBUG
-  cout << "This program was compiled in DEBUG mode (development version)"
-       << endl << endl;
+  std::cout << "This program was compiled in DEBUG mode (development version)"
+       << std::endl << std::endl;
+#endif
+}
+
+void PrintUsage(const char* cmd_name)
+{
+  printf("usage: \n");
+  printf("%s -h|--help : show this help\n", cmd_name);
+  printf("%s -v|--version : show the version\n", cmd_name);
+  printf("%s -r|--reset-config : reset the configuration to default\n", cmd_name);
+  printf("%s -y|--skin-viewer [team] : start the skin viewer (for development only)\n", cmd_name);
+  printf("%s [-p|--play] [-g|--game-mode <game_mode>]"
+	 " [-s|--server] [-c|--client [ip]]\n"
+	 " [-l [ip/hostname of index server]]\n"
+#ifdef DEBUG
+	 " [-d|--debug <debug_masks>|all]\n"
+#endif
+	 , cmd_name);
+#ifdef DEBUG
+  printf("\nWith :\n");
+  printf(" <debug_masks> ::= { %s }\n", used_debug_masks.c_str());
 #endif
 }
 
@@ -284,39 +354,27 @@ void ParseArgs(int argc, char * argv[])
       {"blitz",      no_argument,       NULL, 'b'},
       {"version",    no_argument,       NULL, 'v'},
       {"play",       no_argument,       NULL, 'p'},
-      {"internet",   no_argument,       NULL, 'i'},
       {"client",     optional_argument, NULL, 'c'},
       {"server",     no_argument,       NULL, 's'},
+      {"skin-viewer",optional_argument, NULL, 'y'},
       {"game-mode",  required_argument, NULL, 'g'},
       {"debug",      required_argument, NULL, 'd'},
+      {"reset-config", no_argument,     NULL, 'r'},
       {NULL,         no_argument,       NULL,  0 }
     };
 
-  while ((c = getopt_long (argc, argv, "hbvpic::l::sg:d:",
+  while ((c = getopt_long (argc, argv, "hbvpc::l::sy::g:d:",
                            long_options, &option_index)) != -1)
     {
       switch (c)
         {
         case 'h':
-          printf("usage: %s [-h|--help] [-v|--version] [-p|--play]"
-                 " [-i|--internet] [-s|--server] [-c|--client [ip]]\n"
-		 " [-g|--game-mode <game_mode>]"
-#ifdef DEBUG
-                 " [-d|--debug <debug_masks>|all]\n"
-#endif
-                 " [-l [ip/hostname]]\n", argv[0]);
-#ifdef DEBUG
-          printf("\nWith :\n");
-          printf(" <debug_masks> ::= { action | action_handler | action_handler.menu | ai | ai.move | body | body_anim | body.state | bonus | box | camera.follow | camera.shake | camera.tracking | character | character.collision | character.energy | damage | downloader | explosion | game | game.endofturn | game_mode | game.statechange | ghost | grapple.break | grapple.hook | grapple.node | ground_generator.element | index_server | jukebox | jukebox.cache | jukebox.play | lst_objects | map | map.collision | map.load | map.random | menu | mine | mouse | network | network.crc | network.crc_bad | network.traffic | network.turn_master | physical | physical.mem | physic.compute | physic.fall | physic.move | physic.overlapping | physic.pendulum | physic.physic | physic.position | physic.state | physic.sync | random | random.get | singleton | socket | sprite | team | test_rectangle | weapon | weapon.change | weapon.handposition | weapon.projectile | weapon.shoot | widget.border | wind }\n");
-#endif
-          exit(0);
-          break;
-        case 'b':
-          Game::SetMode(Game::BLITZ);
+	  PrintUsage(argv[0]);
+          exit(EXIT_SUCCESS);
           break;
         case 'v':
           DisplayWelcomeMessage();
-          exit(0);
+          exit(EXIT_SUCCESS);
           break;
         case 'p':
           choice = MainMenu::PLAY;
@@ -324,10 +382,10 @@ void ParseArgs(int argc, char * argv[])
           break;
         case 'c':
           choice = MainMenu::NETWORK;
-          //net_action = NetworkConnectionMenu::NET_CONNECT_LOCAL;
+          net_action = NetworkConnectionMenu::NET_CONNECT;
           if (optarg)
             {
-              Config::GetInstance()->SetNetworkHost(optarg);
+              Config::GetInstance()->SetNetworkClientHost(optarg);
             }
           skip_menu = true;
           break;
@@ -341,22 +399,35 @@ void ParseArgs(int argc, char * argv[])
           break;
         case 's':
           choice = MainMenu::NETWORK;
-          //net_action = NetworkConnectionMenu::NET_HOST;
-          skip_menu = true;
-          break;
-        case 'i':
-          choice = MainMenu::NETWORK;
-          //net_action = NetworkConnectionMenu::NET_BROWSE_INTERNET;
+          net_action = NetworkConnectionMenu::NET_HOST;
           skip_menu = true;
           break;
         case 'l':
-          if (optarg) IndexServer::GetInstance()->SetLocal(optarg);
-          else        IndexServer::GetInstance()->SetLocal();
+          if (optarg) IndexServer::GetInstance()->SetAddress(optarg);
+          else        IndexServer::GetInstance()->SetAddress("127.0.0.1");
+          break;
+        case 'y':
+          choice = MainMenu::SKIN_VIEWER;
+          skin = optarg;
+          skip_menu = true;
           break;
 	case 'g':
 	  printf("Game-mode: %s\n", optarg);
 	  Config::GetInstance()->SetGameMode(optarg);
 	  break;
+	case 'r':
+	  {
+	    bool r;
+	    r = Config::GetInstance()->RemovePersonalConfigFile();
+	    if (!r)
+	      exit(EXIT_FAILURE);
+	    exit(EXIT_SUCCESS);
+	  }
+	  break;
+	default:
+	  fprintf(stderr, "Unknow option %c", c);
+	  PrintUsage(argv[0]);
+	  exit(EXIT_FAILURE);
         }
     }
 }
