@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include "map/wind.h"
 #include "game/time.h"
 #include "object/objbox.h"
-#include "tool/i18n.h"
 #include "tool/math_tools.h"
 
 const double MINIMUM_DISTANCE_BETWEEN_CHARACTERS = 50.0;
@@ -39,9 +38,12 @@ const uint AUTHOR_INFO_TIME = 5000; // ms
 const uint AUTHOR_INFO_X = 100;
 const uint AUTHOR_INFO_Y = 50;
 
-Map world;
+Map& GetWorld()
+{
+  return Map::GetRef();
+}
 
-Map::Map()
+Map::Map() : author_info1(NULL), author_info2(NULL)
 {
   min_distance_between_characters = MINIMUM_DISTANCE_BETWEEN_CHARACTERS;
 
@@ -57,8 +59,10 @@ Map::~Map()
   delete to_redraw_now;
   delete to_redraw_particles;
   delete to_redraw_particles_now;
-  if (author_info1) delete author_info1;
-  if (author_info2) delete author_info2;
+  if (author_info1)
+    delete author_info1;
+  if (author_info2)
+    delete author_info2;
 }
 
 void Map::Reset()
@@ -66,10 +70,14 @@ void Map::Reset()
   sky.Reset();
   ground.Reset();
   water.Reset();
-  wind.Reset();
+  Wind::GetRef().Reset();
 
-  delete author_info1; author_info1 = NULL;
-  delete author_info2; author_info2 = NULL;
+  if (author_info1)
+    delete author_info1;
+  author_info1 = NULL;
+  if (author_info2)
+    delete author_info2;
+  author_info2 = NULL;
 
   to_redraw->clear();
   to_redraw_now->clear();
@@ -80,7 +88,7 @@ void Map::Reset()
 void Map::Refresh()
 {
   water.Refresh();
-  wind.Refresh();
+  Wind::GetRef().Refresh();
 }
 
 void Map::FreeMem()
@@ -154,7 +162,9 @@ void Map::DrawSky(bool redraw_all)
 }
 
 void Map::DrawWater()
-{ water.Draw(); }
+{
+  water.Draw();
+}
 
 void Map::Draw(bool redraw_all)
 {
@@ -162,7 +172,7 @@ void Map::Draw(bool redraw_all)
   to_redraw_particles->clear();
   to_redraw = to_redraw_particles;
 
-  wind.DrawParticles();
+  Wind::GetRef().DrawParticles();
   to_redraw = tmp;
 
 //  Done from DrawSky
@@ -374,7 +384,7 @@ bool Map::TraceRay(const Point2i &start, const Point2i & end, TraceResult & tr,
   Point2d iterated_point = ( Point2d )( start );
   while( !IsOutsideWorld( new_point ) && ( length >= 0 ) )
   {
-    if (!world.IsInVacuum( new_point ))
+    if (!IsInVacuum( new_point ))
     {
       if ( trace_flags & COMPUTE_HIT )
       {
@@ -409,4 +419,4 @@ bool Map::TraceRay(const Point2i &start, const Point2i & end, TraceResult & tr,
   }
 
   return false;
-};
+}
