@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,18 +19,20 @@
  * Maps list
  *****************************************************************************/
 
+
+#include <algorithm>
 #include "include/action.h"
 #include "map/maps_list.h"
+#include "map/water.h"
 #include "game/config.h"
 #include "graphic/surface.h"
 #include "tool/resource_manager.h"
-#include "tool/debug.h"
-#include "tool/file_tools.h"
-#include "tool/i18n.h"
-#include "tool/random.h"
+#include <WORMUX_debug.h>
+#include <WORMUX_file_tools.h>
+#include <WORMUX_random.h>
+#include "tool/string_tools.h"
 #include "tool/xml_document.h"
-#include <iostream>
-#include <algorithm>
+#include <sstream>
 
 extern const uint MAX_WIND_OBJECTS;
 
@@ -51,7 +53,7 @@ InfoMap::InfoMap(const std::string &map_name,
   is_data_loaded(false),
   random_generated(false),
   island_type(RANDOM_GENERATED),
-  water_type(Water::NO_WATER),
+  water_type("no"),
   res_profile(NULL)
 {
   wind.nb_sprite = 0;
@@ -70,25 +72,30 @@ void InfoMap::LoadBasicInfo()
   if (!DoesFileExist(nomfich))
     throw _("no configuration file!");
   // FIXME: not freed
-  res_profile = resource_manager.LoadXMLProfile(nomfich, true);
+  res_profile = GetResourceManager().LoadXMLProfile(nomfich, true);
   if (!res_profile)
     throw _("couldn't load config");
   // Load preview
-  preview = resource_manager.LoadImage(res_profile, "preview");
+  preview = GetResourceManager().LoadImage(res_profile, "preview");
   is_basic_info_loaded = true;
   // Load other informations
-  XmlReader doc;
   if (!doc.Load(nomfich) || !ProcessXmlData(doc.GetRoot()))
     throw _("error parsing the config file");
 
   MSG_DEBUG("map.load", "Map loaded: %s", m_map_name.c_str());
 }
 
-bool InfoMap::ProcessXmlData(xmlNode *xml)
+bool InfoMap::ProcessXmlData(const xmlNode *xml)
 {
+  uint tmpisle = (uint) island_type;
+
   XmlReader::ReadBool(xml, "random", random_generated);
+
+  XmlReader::ReadUint(xml, "generator", tmpisle);
+  island_type = (Island_type) tmpisle;
+
   // Read author informations
-  xmlNode *author = XmlReader::GetMarker(xml, "author");
+  const xmlNode *author = XmlReader::GetMarker(xml, "author");
   if (author != NULL) {
     std::string
       a_name,
@@ -124,21 +131,29 @@ bool InfoMap::ProcessXmlData(xmlNode *xml)
   XmlReader::ReadBool(xml, "is_open", is_opened);
 
   // reading water type
-  water_type = Water::NO_WATER;
-  uint wtype;
-  XmlReader::ReadUint(xml, "water", wtype);
-  if (wtype < uint(Water::MAX_WATER_TYPE))
-    water_type = Water::Water_type(wtype);
+  water_type = "no";
+  XmlReader::ReadString(xml, "water", water_type);
+
+  // check this water type is valid
+  if (water_type != "no") {
+    std::string path = Config::GetInstance()->GetDataDir() + PATH_SEPARATOR +
+      "water" + PATH_SEPARATOR + water_type;
+    if (!DoesFileExist(path)) {
+      fprintf(stderr, "Map %s (%s) uses invalid water type %s\n",
+	      GetRawName().c_str(), ReadFullMapName().c_str(), water_type.c_str());
+      water_type = "no";
+    }
+  }
 
   // Load padding value
   bool add_pad = false;
   XmlReader::ReadBool(xml, "add_pad", add_pad);
   if(is_opened && add_pad) {
-    upper_left_pad = resource_manager.LoadPoint2i(res_profile, "upper_left_pad");
-    lower_right_pad = resource_manager.LoadPoint2i(res_profile, "lower_right_pad");
+    upper_left_pad = GetResourceManager().LoadPoint2i(res_profile, "upper_left_pad");
+    lower_right_pad = GetResourceManager().LoadPoint2i(res_profile, "lower_right_pad");
   }
 
-  xmlNode* xmlwind = XmlReader::GetMarker(xml, "wind");
+  const xmlNode* xmlwind = XmlReader::GetMarker(xml, "wind");
   if (xmlwind != NULL)
   {
     double rot_speed=0.0;
@@ -173,17 +188,37 @@ void InfoMap::LoadData()
 
   MSG_DEBUG("map.load", "Map data loaded: %s", name.c_str());
 
-  img_sky = resource_manager.LoadImage(res_profile,"sky");
-  if(!random_generated) {
-    img_ground = resource_manager.LoadImage(res_profile, "map");
+  img_sky = GetResourceManager().LoadImage(res_profile, "sky");
+
+  if (Config::GetInstance()->GetDisplayMultiLayerSky()) {
+
+    uint layer = 0;
+    XmlReader::ReadUint(doc.GetRoot(), "sky_layer", layer);
+
+    for (uint i = 0; i < layer; i++) {
+      std::ostringstream ss;
+      ss << "sky_layer_" << i;
+      sky_layer.push_back(GetResourceManager().LoadImage(res_profile, ss.str()));
+    }
+  }
+
+  if (!random_generated) {
+    img_ground = GetResourceManager().LoadImage(res_profile, "map");
   } else {
-    img_ground = resource_manager.GenerateMap(res_profile, island_type, img_sky.GetWidth(), img_sky.GetHeight());
+    img_ground = GetResourceManager().GenerateMap(res_profile, island_type, img_sky.GetWidth(), img_sky.GetHeight());
   }
 }
 
 void InfoMap::FreeData()
 {
   img_sky.Free();
+
+  std::vector<Surface>::iterator it = sky_layer.begin();
+  while (it != sky_layer.end()) {
+    it->Free();
+    sky_layer.erase(it);
+  }
+
   img_ground.Free();
   is_data_loaded = false;
 }
@@ -202,6 +237,13 @@ Surface& InfoMap::ReadImgSky()
   return img_sky;
 }
 
+std::vector<Surface>& InfoMap::ReadSkyLayer()
+{
+  LoadBasicInfo();
+  LoadData();
+  return sky_layer;
+}
+
 std::string InfoMap::GetConfigFilepath() const
 {
   return m_directory + PATH_SEPARATOR + "config.xml";
@@ -229,7 +271,7 @@ MapsList::MapsList()
     while ((name = FolderSearchNext(f)) != NULL) LoadOneMap(dirname, name);
     CloseFolder(f);
   } else {
-    Error (Format(_("Unable to open maps directory (%s)!"), dirname.c_str()));
+    Error (Format(_("Unable to open the maps directory (%s)!"), dirname.c_str()));
   }
 
   // Load personal maps
@@ -241,7 +283,7 @@ MapsList::MapsList()
     CloseFolder(f);
   } else {
         std::cerr << std::endl
-          << Format(_("Unable to open personal maps directory (%s)!"),
+          << Format(_("Unable to open the personal maps directory (%s)!"),
                       dirname.c_str())
           << std::endl;
   }
@@ -250,7 +292,7 @@ MapsList::MapsList()
 
   // On a au moins une carte ?
   if (lst.size() < 1)
-    Error(_("You need at least one valid map !"));
+    Error(_("You need at least one valid map!"));
 
   /* Get the full set of map ordered */
   std::sort(lst.begin(), lst.end(), compareMaps);
@@ -272,7 +314,7 @@ void MapsList::LoadOneMap (const std::string &dir, const std::string &map_name)
   if (map_name[0] == '.') return;
 
   std::string fullname = dir + map_name;
-  if (!IsFolderExist(fullname))
+  if (!DoesFolderExist(fullname))
     return;
 
   InfoMap *nv_terrain = new InfoMap(map_name, fullname + PATH_SEPARATOR);
@@ -304,7 +346,7 @@ void MapsList::SelectMapByName (const std::string &name)
 {
   // Random map!!
   if (name == "random") {
-    active_map_index = Random::GetLong(0, lst.size()-1);
+    active_map_index = RandomLocal().GetLong(0, lst.size()-1);
 
     MSG_DEBUG("map.random", "select %u", active_map_index);
     random_map = true;
@@ -362,3 +404,4 @@ InfoMap* ActiveMap()
 {
   return MapsList::GetInstance()->ActiveMap();
 }
+
