@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,14 @@
 #define _TILE_H
 
 #include <vector>
-#include "tool/point.h"
-#include "tool/rectangle.h"
+#include <WORMUX_point.h>
+#include <WORMUX_rectangle.h>
 
 // Forward declarations
 class Surface;
 class Sprite;
 class TileItem;
+class TileItem_Empty;
 
 const uint EXPLOSION_BORDER_SIZE = 10;
 
@@ -68,6 +69,8 @@ public:
   void  CheckPreview();
   const Point2i& GetPreviewSize() const { return m_preview_size; };
   const Rectanglei& GetPreviewRect() const { return m_preview_rect; };
+  uint GetLastPreviewRedrawTime() const { return m_last_preview_redraw; };
+
   // Translate world coordinates into a preview ones
   // @warning assumes CELL_SIZE is 64x64
   Point2i PreviewCoordinates(const Point2i& pos) { return (pos-m_upper_left_offset)>>m_shift; };
@@ -82,10 +85,10 @@ protected:
 
   // Ground dimensions
   Point2i nbCells;
-  unsigned int nbr_cell;
 
   void InitPreview();
   Surface*   m_preview;
+  uint       m_last_preview_redraw;
   uint       m_shift;
   Point2i    m_last_video_size;
   Point2i    m_preview_size;
