@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,22 +26,20 @@
 #include "graphic/video.h"
 #include "include/app.h"
 #include "map/camera.h"
-#include "tool/error.h"
 #include "tool/math_tools.h"
-#include "tool/point.h"
-//#include "tool/stats.h"
+#include <WORMUX_point.h>
 #ifdef DBG_TILE
 #include "graphic/colors.h"
 #endif
 
-static const uint TRANSPARENT_WHITE = 0x40FFFFFF;
+static const uint TRANSPARENT = 0x00FFFFFF;
 
 void TileItem::ScalePreview(uint8_t *odata, uint opitch, uint shift)
 {
   for (int j=0; j<CELL_SIZE.y>>shift; j++)
   {
     for (int i=0; i<(CELL_SIZE.x>>shift)>>2; i++)
-      memcpy(odata+(i<<2), &TRANSPARENT_WHITE, 4);
+      memcpy(odata+(i<<2), &TRANSPARENT, 4);
     odata += opitch;
   }
 }
@@ -198,7 +196,7 @@ void TileItem_AlphaSoftware::ScalePreview(uint8_t *odata, uint opitch, uint shif
       p3 = (p3 + (1<<(2*shift-1)))>>(2*shift);
       if (p3 < 160)
       {
-        memcpy(odata+4*i, &TRANSPARENT_WHITE, 4);
+        memcpy(odata+4*i, &TRANSPARENT, 4);
       }
       else
       {
@@ -211,7 +209,7 @@ void TileItem_AlphaSoftware::ScalePreview(uint8_t *odata, uint opitch, uint shif
       p0 = (p0 + (1<<(2*shift-1)))>>(2*shift);
       if (p0 < 160)
       {
-        memcpy(odata+4*i, &TRANSPARENT_WHITE, 4);
+        memcpy(odata+4*i, &TRANSPARENT, 4);
       }
       else
       {
