@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #ifndef TILEITEM_H
 #define TILEITEM_H
 
-#include "tool/point.h"
+#include <WORMUX_point.h>
 #include "graphic/surface.h"
 
 const Point2i CELL_SIZE(64, 64);
