@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,14 +19,15 @@
  * Refresh water that may be placed in bottom of the ground.
  *****************************************************************************/
 
-#include "map/water.h"
 #include <assert.h>
 #include <SDL.h>
+#include "game/game_mode.h"
+#include "game/time.h"
+#include "interface/interface.h"
 #include "map/camera.h"
 #include "map/map.h"
 #include "map/maps_list.h"
-#include "game/time.h"
-#include "interface/interface.h"
+#include "map/water.h"
 #include "particles/particle.h"
 #include "tool/math_tools.h"
 #include "tool/resource_manager.h"
@@ -42,6 +43,20 @@ const float b = 1.0;
 
 int Water::pattern_height = 0;
 
+Water::Water() :
+  type_color(NULL),
+  height_mvt(0),
+  shift1(0),
+  water_height(0),
+  time_raise(0),
+  water_type("no"),
+  m_last_preview_redraw(0)
+{
+  for (uint i = 0; i < pattern_width; i++) {
+    height[i] = 0;
+  }
+}
+
 Water::~Water()
 {
   if (type_color)
@@ -62,21 +77,20 @@ Water::~Water()
  */
 void Water::Init()
 {
+  ASSERT(water_type != "no");
+
   std::string image = "gfx/";
-  image += water_name;
+  image += water_type;
 
-  Profile *res = resource_manager.LoadXMLProfile("graphism.xml", false);
+  Profile *res = GetResourceManager().LoadXMLProfile("graphism.xml", false);
 
-  surface = resource_manager.LoadImage(res, image);
+  surface = GetResourceManager().LoadImage(res, image);
   surface.SetAlpha(0, 0);
 
   image += "_bottom";
 
-  if (water_type != NO_WATER)
-    type_color = new Color(resource_manager.LoadColor(res, "water_colors/" + water_name));
-  else
-    type_color = NULL;
-  bottom = resource_manager.LoadImage(res, image);
+  type_color = new Color(GetResourceManager().LoadColor(res, "water_colors/" + water_type));
+  bottom = GetResourceManager().LoadImage(res, image);
   bottom.SetAlpha(0, 0);
 
   pattern_height = bottom.GetHeight();
@@ -100,30 +114,13 @@ void Water::Init()
 
 
   shift1 = 0;
-  resource_manager.UnLoadXMLProfile(res);
-}
-
-Water::Water_type Water::GetWaterType(std::string & water)
-{
-  if(water == "water") {
-    return WATER;
-  } else if(water == "lava") {
-    return LAVA;
-  } else if(water == "radioactive") {
-    return RADIOACTIVE;
-  } else { // Old water definition (aka 0 = no water, 1 = water, 2 = lava etc)
-    int water_t;
-    if(str2int(water, water_t) && water_t < MAX_WATER_TYPE) {
-      return (Water_type)water_t;
-    }
-  }
-  return NO_WATER;
+  GetResourceManager().UnLoadXMLProfile(res);
 }
 
 void Water::Reset()
 {
-  water_name = ActiveMap()->GetWaterName();
-  water_type = GetWaterType(water_name);
+  water_type = ActiveMap()->GetWaterType();
+
   if (type_color)
     delete type_color;
   type_color = NULL;
@@ -133,7 +130,8 @@ void Water::Reset()
 
   Init();
   water_height = WATER_INITIAL_HEIGHT;
-  temps_montee = GO_UP_TIME * 60 * 1000;
+  time_raise = 1000 * GameMode::GetInstance()->duration_before_death_mode;
+
   Refresh(); // Calculate first height position
 }
 
@@ -157,10 +155,11 @@ void Water::Refresh()
 
   // Height Calculation:
   Time * global_time = Time::GetInstance();
-  if (temps_montee < global_time->Read())
+  if (time_raise < global_time->Read())
   {
-    if(temps_montee + GO_UP_OSCILLATION_TIME * 1000 > global_time->Read()){
-      uint dt=global_time->Read()- temps_montee;
+    m_last_preview_redraw = global_time->Read();
+    if (time_raise + GO_UP_OSCILLATION_TIME * 1000 > global_time->Read()) {
+      uint dt = global_time->Read() - time_raise;
       height_mvt = GO_UP_STEP +
         (uint)(((float)GO_UP_STEP *
                sin(((float)(dt*(GO_UP_OSCILLATION_NBR-0.25))
@@ -168,7 +167,7 @@ void Water::Refresh()
                )/(a*dt+b));
     }
     else{
-      temps_montee += GO_UP_TIME * 60 * 1000;
+      time_raise += GO_UP_TIME * 60 * 1000;
       water_height += GO_UP_STEP;
     }
   }
@@ -181,7 +180,7 @@ void Water::Draw()
     return;
 
   int screen_bottom = (int)Camera::GetInstance()->GetPosition().y + (int)Camera::GetInstance()->GetSize().y;
-  int water_top = world.GetHeight() - (water_height + height_mvt) - 20;
+  int water_top = GetWorld().GetHeight() - (water_height + height_mvt) - 20;
 
   if ( screen_bottom < water_top )
     return; // save precious CPU time
@@ -273,35 +272,40 @@ void Water::Draw()
   }
 }
 
+bool Water::IsActive() const
+{
+  return water_type != "no";
+}
+
 int Water::GetHeight(int x) const
 {
   if (IsActive())
     return height[x % pattern_width]
-           + world.GetHeight()
+           + GetWorld().GetHeight()
            - (water_height + height_mvt);
   else
-    return world.GetHeight();
+    return GetWorld().GetHeight();
+}
+
+uint Water::GetSelfHeight() const
+{
+  return water_height+(pattern_height/2);
+}
+
+const Color* Water::GetColor() const
+{
+  return type_color;
 }
 
 void Water::Splash(const Point2i& pos) const
 {
-  switch (water_type) {
-  case WATER:
-    ParticleEngine::AddNow(Point2i(pos.x, pos.y-5), 5, particle_WATER, true, -1, 20);
-    break;
-  case LAVA:
-    ParticleEngine::AddNow(Point2i(pos.x, pos.y-5), 5, particle_LAVA, true, -1, 20);
-    break;
-  case RADIOACTIVE:
-    ParticleEngine::AddNow(Point2i(pos.x, pos.y-5), 5, particle_RADIOACTIVE, true, -1, 20);
-    break;
-  default:
-    break;
-  }
+  if (water_type == "no")
+    return;
+
+  ParticleEngine::AddNow(Point2i(pos.x, pos.y-5), 5, particle_WATER, true, -1, 20);
 }
 
 void Water::Smoke(const Point2i& pos) const
 {
   ParticleEngine::AddNow(Point2i(pos.x, pos.y-5), 2, particle_SMOKE, true, 0, 1);
 }
-
