@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 
 #include <list>
 #include "include/base.h"
+#include <WORMUX_singleton.h>
 #include "object/physical_obj.h"
 
 // Forward declarations
@@ -35,11 +36,11 @@ typedef struct _xmlNode xmlNode;
 
 class WindParticle : public PhysicalObj
 {
+private:
   /* You should not need this */
   WindParticle(const WindParticle&);
   const WindParticle& operator=(const WindParticle&);
 
-public:
   Sprite *sprite;
   Sprite *flipped;
 
@@ -50,29 +51,31 @@ public:
   void Refresh();
 };
 
-class Wind
+class Wind : public Singleton<Wind>
 {
+private:
   long m_val, m_nv_val;
   uint m_last_move;
   uint m_last_part_mvt;
 
-private:
   std::list<WindParticle *> particles;
   typedef std::list<WindParticle *>::iterator iterator;
   void RemoveAllParticles();
   void RandomizeParticlesPos(); // Put particles randomly on the screen
 
+  Wind();
+  ~Wind();
+  friend class Singleton<Wind>;
+
 public:
-  Wind() { m_val = m_nv_val = 0; };
-  ~Wind() { RemoveAllParticles(); };
-  double GetStrength() const { return m_nv_val * WIND_STRENGTH / 100.0; };
+  double GetStrength() const;
   void ChooseRandomVal() const;
-  void SetVal (long val) { m_nv_val = val; };
+
+  void SetVal(long val);
   void Refresh();
   void Reset();
   void DrawParticles();
 };
 
-extern Wind wind;
 #endif
 
