@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include "graphic/video.h"
 #include "gui/list_box.h"
 #include "include/app.h"
-#include "tool/i18n.h"
 #include "tool/xml_document.h"
 //-----------------------------------------------------------------------------
 
@@ -42,13 +41,13 @@ public:
   std::string country;
   std::string description;
 
-  bool Feed (xmlNode* node);
+  bool Feed (const xmlNode* node);
   std::string PrettyString(bool with_email) const;
 };
 
 //-----------------------------------------------------------------------------
 
-bool Author::Feed (xmlNode* node)
+bool Author::Feed (const xmlNode* node)
 {
   if (!XmlReader::ReadString(node, "name", name))
     return false;
@@ -88,8 +87,8 @@ std::string Author::PrettyString(bool with_email) const
 CreditsMenu::CreditsMenu()  :
   Menu("credit/background", vOk)
 {
-  ListBox * lbox_authors = new ListBox(Point2i(AppWormux::GetInstance()->video->window.GetWidth()-60,
-					       AppWormux::GetInstance()->video->window.GetHeight()-60-30),
+  ListBox * lbox_authors = new ListBox(Point2i(GetMainWindow().GetWidth()-60,
+					       GetMainWindow().GetHeight()-60-30),
 				       false);
   lbox_authors->SetBackgroundColor(Color(0,0,0,200));
   lbox_authors->SetPosition(30, 30);
@@ -129,7 +128,7 @@ void CreditsMenu::PrepareAuthorsList(ListBox * lbox_authors) const
 
   for(uint i = 0; i < (sizeof teams / sizeof* teams); ++i)
   {
-    xmlNodeArray team = XmlReader::GetNamedNeighbours(doc.GetRoot(), teams[i]);
+    xmlNodeArray team = XmlReader::GetNamedChildren(doc.GetRoot(), teams[i]);
 
     if (team.empty())
       continue;
