@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include "gui/tabs.h"
 #include "gui/combo_box.h"
 #include "include/app.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 
 const uint MARGIN_TOP    = 5;
@@ -47,7 +46,7 @@ const uint OPTIONS_BOX_H = 150;
 GameMenu::GameMenu() :
   Menu("menu/bg_play")
 {
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml",false);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml",false);
   Point2i stdSize(130, W_UNDEF);
 
   Surface& window = GetMainWindow();
@@ -90,7 +89,7 @@ GameMenu::GameMenu() :
   widgets.AddWidget(tabs);
   widgets.Pack();
 
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
 }
 
 GameMenu::~GameMenu()
@@ -129,7 +128,7 @@ bool GameMenu::signal_ok()
 {
   SaveOptions();
   play_ok_sound();
-  Game::UpdateGameMode()->Start();
+  Game::UpdateGameRules()->Start();
   return true;
 }
 
