@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,14 +26,18 @@
 
 // Forward declarations
 class ListBox;
+class Sprite;
 
 class HelpMenu : public Menu
 {
  private:
+  Sprite* img_keyboard;
+
   bool signal_ok();
   bool signal_cancel();
 
   void Draw(const Point2i &mousePosition);
+  void DrawBackground();
 
   void OnClick(const Point2i &mousePosition, int button);
   void OnClickUp(const Point2i &mousePosition, int button);
