@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include "include/app.h"
 #include "include/constant.h"
 #include "sound/jukebox.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "tool/stats.h"
 
@@ -100,7 +99,7 @@ MainMenu::MainMenu() :
 
 void MainMenu::button_click() const
 {
-  JukeBox::GetInstance()->Play("share", "menu/clic");
+  JukeBox::GetInstance()->Play("default", "menu/clic");
 }
 
 void MainMenu::SelectAction(const Widget *w)
