@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,17 +29,18 @@
 #include "gui/button.h"
 #include "gui/box.h"
 #include "gui/check_box.h"
-#include "gui/msg_box.h"
 #include "gui/list_box.h"
+#include "gui/msg_box.h"
+#include "gui/null_widget.h"
 #include "gui/picture_widget.h"
 #include "gui/tabs.h"
 #include "gui/text_box.h"
 #include "include/app.h"
+#include "include/constant.h"
 #include "network/net_error_msg.h"
-#include "network/index_server.h"
 #include "team/teams_list.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
+#include "tool/string_tools.h"
 
 class GameInfoBox : public HBox
 {
@@ -53,20 +54,17 @@ public:
     , port(p)
     , ip_address(ip)
   {
-    AddWidget(new PictureWidget(Point2i(16, 16),
-                                (pwd) ? "menu/disabled_back" : "menu/enabled", true));
+    if (pwd) {
+      AddWidget(new PictureWidget(Point2i(16, 16), "menu/password_lock", true));
+    } else {
+      AddWidget(new NullWidget(Point2i(16, 16)));
+    }
     AddWidget(new Label(ip, 100));
     AddWidget(new Label(p, 40));
     AddWidget(new Label(dns, 340));
     AddWidget(new Label(name, 200));
     Pack();
   }
-  void Draw(const Point2i &mousePosition) const
-  {
-    HBox::Draw(mousePosition);
-    for (std::list<Widget*>::const_iterator it = widget_list.begin(); it != widget_list.end(); ++it)
-      (*it)->Draw(mousePosition);
-  }
 };
 
 class GameListBox : public BaseListBox
@@ -83,19 +81,139 @@ public:
   const std::string& GetPort() { return ((GameInfoBox*)m_items[selected_item])->port; }
 };
 
-NetworkConnectionMenu::NetworkConnectionMenu() :
+struct shared_net_info {
+  SDL_Thread* thread_refresh;
+  SDL_sem* lock;
+  std::list<GameServerInfo> lst_games;
+  connection_state_t index_conn_state;
+  bool todisplay;
+};
+
+struct shared_net_info net_info;
+
+void InitNetInfo()
+{
+  net_info.thread_refresh = NULL;
+  net_info.lst_games.clear();
+  net_info.index_conn_state = CONNECTED;
+  net_info.lock = SDL_CreateSemaphore(1);
+  net_info.todisplay = false;
+}
+
+int RefreshNetInfo(void *)
+{
+  MSG_DEBUG("network.refresh_games_list", "Begin");
+
+  // Connect to the index server
+  connection_state_t conn = IndexServer::GetInstance()->Connect(Constants::WORMUX_VERSION);
+  if (conn != CONNECTED) {
+    SDL_SemWait(net_info.lock);
+    net_info.index_conn_state = conn;
+    net_info.thread_refresh = NULL;
+    SDL_SemPost(net_info.lock);
+    return -1;
+  }
+
+  std::list<GameServerInfo> lst = IndexServer::GetInstance()->GetHostList();
+  IndexServer::GetInstance()->Disconnect();
+
+  SDL_SemWait(net_info.lock);
+  net_info.lst_games = lst;
+  net_info.todisplay = true;
+  net_info.thread_refresh = NULL;
+  SDL_SemPost(net_info.lock);
+
+  // make sure the list will be updated right now
+  Menu::WakeUpOnCallback();
+
+  MSG_DEBUG("network.refresh_games_list", "End");
+  return 0;
+}
+
+NetworkConnectionMenu::NetworkConnectionMenu(network_menu_action_t action) :
   Menu("menu/bg_network", vOkCancel)
 {
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml",false);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml",false);
   Point2i def_size(300, 20);
 
-  uint max_width = AppWormux::GetInstance()->video->window.GetWidth()-50;
+  uint max_width = GetMainWindow().GetWidth()-50;
 
   /* Tabs */
   tabs = new MultiTabs(Point2i(max_width,
-			       AppWormux::GetInstance()->video->window.GetHeight()-180));
+                               GetMainWindow().GetHeight()-180));
   tabs->SetPosition(25, 25);
 
+  // #############################
+  /* client connection related widgets */
+  Box * cl_connection_box = new VBox(W_UNDEF, false, false);
+  cl_connection_box->SetBorder(Point2i(0,0));
+
+  // Public battles
+  Box * cl_tmp_box = new HBox(W_UNDEF, false, false);
+  cl_tmp_box->SetMargin(0);
+  cl_tmp_box->SetBorder(Point2i(0,0));
+
+  cl_refresh_net_games = new Button(res, "menu/refresh_small", false);
+  cl_tmp_box->AddWidget(cl_refresh_net_games);
+  refresh_net_games_label = new Label(_("Public battles"), def_size.x,
+                                  Font::FONT_MEDIUM, Font::FONT_BOLD, c_red);
+  cl_tmp_box->AddWidget(refresh_net_games_label);
+  cl_connection_box->AddWidget(cl_tmp_box);
+
+  cl_net_games_lst = new GameListBox( Point2i(def_size.x, 30), false);
+  cl_connection_box->AddWidget(cl_net_games_lst);
+
+  // Server password
+  cl_tmp_box = new HBox(W_UNDEF, false, false);
+  cl_tmp_box->SetMargin(0);
+  cl_tmp_box->SetBorder(Point2i(0,0));
+
+  cl_tmp_box->AddWidget(new Label(_("Password:"), def_size.x/2));
+  cl_net_server_pwd = new PasswordBox("", def_size.x/2);
+  cl_tmp_box->AddWidget(cl_net_server_pwd);
+
+  cl_connection_box->AddWidget(cl_tmp_box);
+
+  // #############################
+  // Manual connection
+  cl_connection_box->AddWidget(new Label(_("Manual connection"), def_size.x,
+                                         Font::FONT_MEDIUM, Font::FONT_BOLD, c_red));
+
+  // Server address
+  cl_tmp_box = new HBox(W_UNDEF, false, false);
+  cl_tmp_box->SetMargin(0);
+  cl_tmp_box->SetBorder(Point2i(0,0));
+
+  cl_tmp_box->AddWidget(new Label(_("Server address:"), def_size.x/2));
+  cl_server_address = new TextBox(Config::GetInstance()->GetNetworkClientHost(), def_size.x/2);
+  cl_tmp_box->AddWidget(cl_server_address);
+
+  cl_connection_box->AddWidget(cl_tmp_box);
+
+  // Server port
+  cl_tmp_box = new HBox(W_UNDEF, false, false);
+  cl_tmp_box->SetMargin(0);
+  cl_tmp_box->SetBorder(Point2i(0,0));
+
+  cl_tmp_box->AddWidget(new Label(_("Port:"), def_size.x/2));
+  cl_port_number = new TextBox(Config::GetInstance()->GetNetworkClientPort(), def_size.x/2);
+  cl_tmp_box->AddWidget(cl_port_number);
+
+  cl_connection_box->AddWidget(cl_tmp_box);
+
+  // Server password
+  cl_tmp_box = new HBox(W_UNDEF, false, false);
+  cl_tmp_box->SetMargin(0);
+  cl_tmp_box->SetBorder(Point2i(0,0));
+
+  cl_tmp_box->AddWidget(new Label(_("Password:"), def_size.x/2));
+  cl_server_pwd = new PasswordBox("", def_size.x/2);
+  cl_tmp_box->AddWidget(cl_server_pwd);
+
+  cl_connection_box->AddWidget(cl_tmp_box);
+  tabs->AddNewTab("TAB_client", _("Connect to game"), cl_connection_box);
+
+  // #############################
   /* server connection related widgets */
   Box * srv_connection_box = new VBox(W_UNDEF, false, false);
   srv_connection_box->SetBorder(Point2i(0,0));
@@ -106,7 +224,7 @@ NetworkConnectionMenu::NetworkConnectionMenu() :
   srv_tmp_box->SetBorder(Point2i(0,0));
 
   srv_tmp_box->AddWidget(new Label(_("Port:"), def_size.x/2));
-  srv_port_number = new TextBox(Config::GetInstance()->GetNetworkPort(), def_size.x/2);
+  srv_port_number = new TextBox(Config::GetInstance()->GetNetworkServerPort(), def_size.x/2);
   srv_tmp_box->AddWidget(srv_port_number);
 
   srv_connection_box->AddWidget(srv_tmp_box);
@@ -117,7 +235,7 @@ NetworkConnectionMenu::NetworkConnectionMenu() :
   srv_tmp_box->SetBorder(Point2i(0,0));
 
   srv_tmp_box->AddWidget(new Label(_("Game name:"), def_size.x/2));
-  srv_game_name = new TextBox("Wormux party", def_size.x/2);
+  srv_game_name = new TextBox(Config::GetInstance()->GetNetworkServerGameName(), def_size.x/2);
   srv_game_name->SetMaxNbChars(15);
   srv_tmp_box->AddWidget(srv_game_name);
 
@@ -136,89 +254,27 @@ NetworkConnectionMenu::NetworkConnectionMenu() :
   srv_connection_box->AddWidget(srv_tmp_box);
 
   // Available on internet ?
-  srv_internet_server = new CheckBox(_("Server available on Internet"), def_size.x, true);
+  srv_internet_server = new CheckBox(_("Server available on Internet"), def_size.x,
+				     Config::GetInstance()->GetNetworkServerPublic());
   srv_connection_box->AddWidget(srv_internet_server);
 
   tabs->AddNewTab("TAB_server", _("Host a game"), srv_connection_box);
 
-  /* client connection related widgets */
-  Box * cl_connection_box = new VBox(W_UNDEF, false, false);
-  cl_connection_box->SetBorder(Point2i(0,0));
-
-  // Public battles
-  Box * cl_tmp_box = new HBox(W_UNDEF, false, false);
-  cl_tmp_box->SetMargin(0);
-  cl_tmp_box->SetBorder(Point2i(0,0));
-
-  cl_refresh_net_games = new Button(res, "menu/refresh_small", false);
-  cl_tmp_box->AddWidget(cl_refresh_net_games);
-  cl_tmp_box->AddWidget(new Label(_("Public battles"), def_size.x, Font::FONT_MEDIUM, Font::FONT_BOLD, c_red));
-  cl_connection_box->AddWidget(cl_tmp_box);
-
-  cl_net_games_lst = new GameListBox( Point2i(def_size.x, 30), false);
-  cl_connection_box->AddWidget(cl_net_games_lst);
-
-  // Server password
-  cl_tmp_box = new HBox(W_UNDEF, false, false);
-  cl_tmp_box->SetMargin(0);
-  cl_tmp_box->SetBorder(Point2i(0,0));
-
-  cl_tmp_box->AddWidget(new Label(_("Password:"), def_size.x/2));
-  cl_net_server_pwd = new PasswordBox("", def_size.x/2);
-  cl_tmp_box->AddWidget(cl_net_server_pwd);
-  cl_connection_box->AddWidget(cl_tmp_box);
-
-  // #####################################
-  // Manual connection
-  cl_connection_box->AddWidget(new Label(_("Manual connection"), def_size.x, Font::FONT_MEDIUM, Font::FONT_BOLD, c_red));
-
-  // Server address
-  cl_tmp_box = new HBox(W_UNDEF, false, false);
-  cl_tmp_box->SetMargin(0);
-  cl_tmp_box->SetBorder(Point2i(0,0));
-
-  cl_tmp_box->AddWidget(new Label(_("Server address:"), def_size.x/2));
-  cl_server_address = new TextBox(Config::GetInstance()->GetNetworkHost(), def_size.x/2);
-  cl_tmp_box->AddWidget(cl_server_address);
-
-  cl_connection_box->AddWidget(cl_tmp_box);
-
-  // Server port
-  cl_tmp_box = new HBox(W_UNDEF, false, false);
-  cl_tmp_box->SetMargin(0);
-  cl_tmp_box->SetBorder(Point2i(0,0));
-
-  cl_tmp_box->AddWidget(new Label(_("Port:"), def_size.x/2));
-  cl_port_number = new TextBox(Config::GetInstance()->GetNetworkPort(), def_size.x/2);
-  cl_tmp_box->AddWidget(cl_port_number);
-
-  cl_connection_box->AddWidget(cl_tmp_box);
-
-  // Server password
-  cl_tmp_box = new HBox(W_UNDEF, false, false);
-  cl_tmp_box->SetMargin(0);
-  cl_tmp_box->SetBorder(Point2i(0,0));
-
-  cl_tmp_box->AddWidget(new Label(_("Password:"), def_size.x/2));
-  cl_server_pwd = new PasswordBox("", def_size.x/2);
-  cl_tmp_box->AddWidget(cl_server_pwd);
-
-  cl_connection_box->AddWidget(cl_tmp_box);
-  tabs->AddNewTab("TAB_client", _("Connect to game"), cl_connection_box);
-
+  // #############################
   widgets.AddWidget(tabs);
   widgets.Pack();
 
   // Optimize height of public net games table
   uint net_games_lst_width = tabs->GetSizeX() - 2*(cl_connection_box->GetPositionX()-tabs->GetPositionX());
   uint net_games_lst_height = cl_net_games_lst->GetSizeY() +
-    (tabs->GetPositionY() + tabs->GetSizeY()) - (cl_connection_box->GetPositionY() + cl_connection_box->GetSizeY()) - 10;
+    (tabs->GetPositionY() + tabs->GetSizeY()) -
+    (cl_connection_box->GetPositionY() + cl_connection_box->GetSizeY()) - 10;
   cl_net_games_lst->SetSize(net_games_lst_width, net_games_lst_height);
 
   // Warning about experimental networking
   Point2i msg_box_pos(25, tabs->GetPositionY() + tabs->GetSizeY() + 10);
   Point2i msg_box_size(max_width,
-		       AppWormux::GetInstance()->video->window.GetHeight() - 50 - msg_box_pos.y);
+                       GetMainWindow().GetHeight() - 50 - msg_box_pos.y);
 
   msg_box = new MsgBox(msg_box_size, Font::FONT_SMALL, Font::FONT_NORMAL);
   msg_box->SetPosition(msg_box_pos);
@@ -231,21 +287,36 @@ NetworkConnectionMenu::NetworkConnectionMenu() :
   msg_box->NewMessage(_("Have a good game!"));
   msg_box->NewMessage(""); // Skip a line
 
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
+
+  // ************************************************************************
+  InitNetInfo();
+
+  switch (action) {
+  case NET_HOST:
+    tabs->SelectTab(1);
+    break;
+  case NET_CONNECT:
+    tabs->SelectTab(0);
+    break;
+  default:
+    ThreadRefreshList();
+    break;
+  }
 }
 
 NetworkConnectionMenu::~NetworkConnectionMenu()
 {
+  SDL_SemWait(net_info.lock);
+  SDL_DestroySemaphore(net_info.lock);
 }
 
 void NetworkConnectionMenu::OnClickUp(const Point2i &mousePosition, int button)
 {
   Widget* w = widgets.ClickUp(mousePosition, button);
 
-  if (w == cl_refresh_net_games)
-    RefreshList();
-  else if (w == cl_net_games_lst)
-    printf("%s\n", cl_net_games_lst->GetAddress().c_str());
+  if (w == cl_refresh_net_games || w == refresh_net_games_label)
+    ThreadRefreshList();
 }
 
 void NetworkConnectionMenu::OnClick(const Point2i &mousePosition, int button)
@@ -253,88 +324,131 @@ void NetworkConnectionMenu::OnClick(const Point2i &mousePosition, int button)
   widgets.Click(mousePosition, button);
 }
 
-void NetworkConnectionMenu::RefreshList()
+void NetworkConnectionMenu::__RefreshList()
 {
+  SDL_SemWait(net_info.lock);
+  if (!net_info.todisplay) {
+    SDL_SemPost(net_info.lock);
+    return;
+  }
+
+  net_info.todisplay = false;
 
   // Save the currently selected address
-  //int current = cl_net_games_lst->GetSelectedItem();
+  int current = cl_net_games_lst->GetSelectedItem();
+  if (current == -1) current = 0;
 
   // Empty the list:
-  while (cl_net_games_lst->Size() != 0)
-  {
+  while (cl_net_games_lst->Size() != 0) {
     cl_net_games_lst->Select(0);
     cl_net_games_lst->RemoveSelected();
   }
 
-  // Connect to the index server
-  connection_state_t conn = IndexServer::GetInstance()->Connect();
-  if (conn != CONNECTED) {
-    DisplayNetError(conn);
-    msg_box->NewMessage(_("Error: Unable to contact index server to search an internet game"), c_red);
+  if (net_info.index_conn_state != CONNECTED) {
+    DisplayNetError(net_info.index_conn_state);
+    SDL_SemPost(net_info.lock);
+    msg_box->NewMessage(_("Error: Unable to contact the index server to search for an internet game"), c_red);
     return;
   }
 
-  std::list<GameServerInfo> lst = IndexServer::GetInstance()->GetHostList();
-
-  if (lst.size() == 0) {
-    Menu::DisplayError(_("Sorry, currently, no game is waiting for players"));
-    IndexServer::GetInstance()->Disconnect();
-    return;
+  if (net_info.lst_games.empty()) {
+      Menu::DisplayError(_("Sorry, currently, no game is waiting for players"));
+      SDL_SemPost(net_info.lock);
+      return;
   }
 
-  for (std::list<GameServerInfo>::iterator it = lst.begin(); it != lst.end(); ++it) {
+  for (std::list<GameServerInfo>::iterator it = net_info.lst_games.begin();
+       it != net_info.lst_games.end(); ++it) {
     cl_net_games_lst->AddItem(false, it->passworded, it->ip_address,
                               it->port, it->dns_address, it->game_name);
   }
-  /* if (current != -1 && cl_net_games_lst->Size() != 0)
-     cl_net_games_lst->Select( current ); */
-  cl_net_games_lst->NeedRedrawing();
+  SDL_SemPost(net_info.lock);
 
-  IndexServer::GetInstance()->Disconnect();
+  if (cl_net_games_lst->Size() != 0)
+    cl_net_games_lst->Select( current );
+
+  cl_net_games_lst->NeedRedrawing();
 }
 
-void NetworkConnectionMenu::Draw(const Point2i &/*mousePosition*/){}
+void NetworkConnectionMenu::ThreadRefreshList()
+{
+  SDL_SemWait(net_info.lock);
+
+  if (net_info.thread_refresh != NULL) {
+    MSG_DEBUG("network.refresh_games_list", "A thread is already running");
+    SDL_SemPost(net_info.lock);
+    return;
+  }
+  SDL_SemPost(net_info.lock);
+
+  net_info.thread_refresh = SDL_CreateThread(RefreshNetInfo, NULL);
+}
+
+void NetworkConnectionMenu::Draw(const Point2i &/*mousePosition*/) {}
+
+void NetworkConnectionMenu::HandleEvent(const SDL_Event& event)
+{
+  __RefreshList();
+  Menu::HandleEvent(event);
+}
 
 void NetworkConnectionMenu::DisplayNetError(connection_state_t conn)
 {
-  Menu::DisplayError(NetworkErrorToString(conn));
+  std::string error_msg;
+
+  if (conn == CONN_WRONG_VERSION) {
+    error_msg = Format(_("Sorry, your version is not supported anymore. "
+			 "Supported versions are %s. "
+			 "You can download an updated version "
+			 "from http://www.wormux.org/wiki/download.php"),
+		       IndexServer::GetInstance()->GetSupportedVersions().c_str());
+  } else {
+    error_msg = NetworkErrorToString(conn);
+  }
+
+  Menu::DisplayError(error_msg);
 }
 
 bool NetworkConnectionMenu::HostingServer(const std::string& port,
-					  const std::string& game_name,
+                                          const std::string& game_name,
                                           const std::string& password,
-					  bool internet)
+                                          bool internet)
 {
   bool r = false;
+  int net_port;
 
   if (!internet)
     IndexServer::GetInstance()->SetHiddenServer();
 
-  connection_state_t conn = IndexServer::GetInstance()->Connect();
-  if (conn != CONNECTED)
-    {
-      DisplayNetError(conn);
-      msg_box->NewMessage(_("Error: Unable to contact index server to host a game"), c_red);
-      goto out;
-    }
+  connection_state_t conn = IndexServer::GetInstance()->Connect(Constants::WORMUX_VERSION);
+  if (conn != CONNECTED) {
+    DisplayNetError(conn);
+    msg_box->NewMessage(_("Error: Unable to contact the index server to host a game"), c_red);
+    goto out;
+  }
 
-  conn = Network::GetInstance()->ServerStart(port, password);
-  if( conn != CONNECTED)
-    {
-      DisplayNetError(conn);
-      goto out;
-    }
+  conn = Network::ServerStart(port, game_name, password);
+  if (conn != CONNECTED) {
+    DisplayNetError(conn);
+    goto out;
+  }
 
-  r = IndexServer::GetInstance()->SendServerStatus(game_name, password != "");
+  r = str2int(port, net_port);
   if (false == r) {
     DisplayNetError(CONN_BAD_PORT);
-    msg_box->NewMessage(_("Error: Your server is not reachable from the internet. Check your firewall configuration")
-			, c_red);
+    goto out;
+  }
+
+  r = IndexServer::GetInstance()->SendServerStatus(game_name, password != "", net_port);
+  if (false == r) {
+    DisplayNetError(CONN_BAD_PORT);
+    msg_box->NewMessage(Format(_("Error: Your server is not reachable from the internet. Check your firewall configuration: TCP Port %s must accept connections from the outside. If you are not directly connected to the internet, check your router configuration: TCP Port %s must be forwarded on your computer."), port.c_str(), port.c_str()),
+                        c_red);
     goto out;
   }
 
   if (!Network::GetInstance()->IsConnected()) {
-    msg_box->NewMessage(_("Error: Unable to start server"), c_red);
+    msg_box->NewMessage(_("Error: Unable to start the server"), c_red);
     goto out;
   }
   r = true;
@@ -344,8 +458,8 @@ bool NetworkConnectionMenu::HostingServer(const std::string& port,
 }
 
 bool NetworkConnectionMenu::ConnectToClient(const std::string& srv_address,
-					    const std::string& port,
-					    const std::string& passwd)
+                                            const std::string& port,
+                                            const std::string& passwd)
 {
   bool r = true;
 
@@ -355,8 +469,7 @@ bool NetworkConnectionMenu::ConnectToClient(const std::string& srv_address,
 
     // translators: %s:%s will expand to something like "example.org:9999"
     msg_box->NewMessage(Format(_("Error: Unable to connect to %s:%s"),
-			       srv_address.c_str(), port.c_str()),
-			c_red);
+                               srv_address.c_str(), port.c_str()), c_red);
     r = false;
   }
   return r;
@@ -365,6 +478,7 @@ bool NetworkConnectionMenu::ConnectToClient(const std::string& srv_address,
 bool NetworkConnectionMenu::signal_ok()
 {
   bool r = false;
+  std::list<GameServerInfo> lst;
 
   // Hack: force loading of teams before creating threads.
   GetTeamsList();
@@ -380,31 +494,33 @@ bool NetworkConnectionMenu::signal_ok()
 		      srv_internet_server->GetValue());
     if (!r)
       goto out;
-  } else if (id == "TAB_client") {
 
-    if (cl_net_games_lst->GetSelectedItem() != -1)
-      {
-	// Connect to an internet game!
-	r = ConnectToClient(cl_net_games_lst->GetAddress(),
-			    cl_net_games_lst->GetPort(),
-			    cl_net_server_pwd->GetPassword());
-	if (!r)
-	  goto out;
-      }
-    else if (!cl_server_address->GetText().empty())
-      {
-	// Direct connexion to a server
-	r = ConnectToClient(cl_server_address->GetText(),
-                              cl_port_number->GetText(),
-                              cl_server_pwd->GetPassword());
-	if (!r)
-	  goto out;
+    // Remember the parameters
+    Config::GetInstance()->SetNetworkServerPort(srv_port_number->GetText());
+    Config::GetInstance()->SetNetworkServerGameName(srv_game_name->GetText());
+    Config::GetInstance()->SetNetworkServerPublic(srv_internet_server->GetValue());
 
-	// Remember the parameters
-	Config::GetInstance()->SetNetworkHost(cl_server_address->GetText());
-	Config::GetInstance()->SetNetworkPort(cl_port_number->GetText());
-      }
-    else
+  } else if (id == "TAB_client") { // Direct connexion to a server
+
+    if (cl_net_games_lst->GetSelectedItem() != -1) {
+      // Connect to an internet game!
+      r = ConnectToClient(cl_net_games_lst->GetAddress(),
+			  cl_net_games_lst->GetPort(),
+			  cl_net_server_pwd->GetPassword());
+      if (!r)
+        goto out;
+
+    } else if (!cl_server_address->GetText().empty()) {
+      r = ConnectToClient(cl_server_address->GetText(),
+                          cl_port_number->GetText(),
+                          cl_server_pwd->GetPassword());
+      if (!r)
+        goto out;
+
+      // Remember the parameters
+      Config::GetInstance()->SetNetworkClientHost(cl_server_address->GetText());
+      Config::GetInstance()->SetNetworkClientPort(cl_port_number->GetText());
+    } else
       goto out;
   }
 
@@ -418,12 +534,15 @@ bool NetworkConnectionMenu::signal_ok()
     Network::GetInstance()->network_menu = NULL;
     IndexServer::GetInstance()->Disconnect();
 
-    // back to main menu after playing
     Network::Disconnect();
-    return true;
+
+    // Don't go back to main menu after playing
+    Menu::RedrawMenu();
+    ThreadRefreshList();
+
+    return false;
   }
 
-  r = true;
  out:
   Network::Disconnect();
   return r;
@@ -434,4 +553,3 @@ bool NetworkConnectionMenu::signal_cancel()
   Network::Disconnect();
   return true;
 }
-
