@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
  ******************************************************************************
  * Game menu
  *****************************************************************************/
+#include <WORMUX_index_server.h>
 
 #include "menu/network_menu.h"
 
@@ -27,19 +28,20 @@
 #include "game/game_mode.h"
 #include "graphic/video.h"
 #include "gui/button.h"
+#include "gui/check_box.h"
 #include "gui/label.h"
 #include "gui/msg_box.h"
 #include "gui/picture_widget.h"
 #include "gui/spin_button.h"
+#include "gui/talk_box.h"
 #include "gui/text_box.h"
 #include "include/action_handler.h"
 #include "include/app.h"
-#include "network/index_server.h"
+#include "include/constant.h"
 #include "network/network.h"
 #include "network/network_server.h"
 #include "team/teams_list.h"
 #include "team/team.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 
 const uint MARGIN_TOP    = 5;
@@ -57,10 +59,10 @@ NetworkMenu::NetworkMenu() :
 {
   waiting_for_server = false;
 
-  Profile *res = resource_manager.LoadXMLProfile( "graphism.xml",false);
+  Profile *res = GetResourceManager().LoadXMLProfile( "graphism.xml",false);
   Point2i pointZero(W_UNDEF, W_UNDEF);
 
-  Surface& window = AppWormux::GetInstance()->video->window;
+  Surface& window = GetMainWindow();
 
   // Calculate main box size
   uint mainBoxWidth = window.GetWidth() - 2*MARGIN_SIDE;
@@ -75,10 +77,12 @@ NetworkMenu::NetworkMenu() :
   widgets.AddWidget(team_box);
   widgets.Pack();
 
+  team_box->SetMaxNbLocalPlayers(GameMode::GetInstance()->max_teams - 1);
+
   // ################################################
   // ##  MAP SELECTION
   // ################################################
-  if(Network::GetInstance()->IsServer()) {
+  if (Network::GetInstance()->IsGameMaster()) {
     map_box = new MapSelectionBox(Point2i(mainBoxWidth, mapBoxHeight));
   } else {
     map_box = new MapSelectionBox(Point2i(mainBoxWidth, mapBoxHeight), true);
@@ -91,76 +95,71 @@ NetworkMenu::NetworkMenu() :
   // ##  GAME OPTIONS
   // ################################################
 
-  options_box = new HBox(OPTIONS_BOX_H, true);
-  options_box->AddWidget(new PictureWidget(Point2i(39, 128), "menu/mode_label"));
+  Box* bottom_box = new HBox(OPTIONS_BOX_H, false, true);
+  bottom_box->SetNoBorder();
 
-  Box* tmp_box = new VBox(200, false);
+  Box* options_box = new VBox(200, true);
 
-  mode = new Label("", 0, Font::FONT_MEDIUM, Font::FONT_NORMAL);
+  mode_label = new Label("", 0, Font::FONT_MEDIUM, Font::FONT_BOLD, primary_red_color);
+  options_box->AddWidget(mode_label);
 
-  if (Network::GetInstance()->IsClient()) {
-    // Client Mode
-    mode->SetText(_("Client mode"));
-    tmp_box->AddWidget(mode);
+  player_number = new SpinButton(_("Max number of players:"), W_UNDEF,
+				     GameMode::GetInstance()->max_teams, 1, 2,
+				     GameMode::GetInstance()->max_teams);
+  options_box->AddWidget(player_number);
 
-    player_number = NULL;
-    connected_players = NULL;
-    initialized_players = NULL;
-  } else {
+  connected_players = new Label(Format(ngettext("%i player connected", "%i players connected", 0), 0),
+				0, Font::FONT_SMALL, Font::FONT_NORMAL);
+  options_box->AddWidget(connected_players);
 
-    // Server Mode
-    mode->SetText(_("Server mode"));
-    tmp_box->AddWidget(mode);
-
-    player_number = new SpinButton(_("Max number of players:"), W_UNDEF,
-                                   GameMode::GetInstance()->max_teams, 1, 2,
-                                   GameMode::GetInstance()->max_teams);
-    team_box->SetMaxNbLocalPlayers(GameMode::GetInstance()->max_teams - 1);
-    tmp_box->AddWidget(player_number);
-
-    connected_players = new Label(Format(ngettext("%i player connected", "%i players connected", 0), 0),
+  initialized_players = new Label(Format(ngettext("%i player ready", "%i players ready", 0), 0),
 				  0, Font::FONT_SMALL, Font::FONT_NORMAL);
-    tmp_box->AddWidget(connected_players);
+  options_box->AddWidget(initialized_players);
 
-    initialized_players = new Label(Format(ngettext("%i player ready", "%i players ready", 0), 0),
-                                    0, Font::FONT_SMALL, Font::FONT_NORMAL);
-    tmp_box->AddWidget(initialized_players);
-  }
+  play_in_loop = new CheckBox(_("Play several times"), W_UNDEF, true);
+  options_box->AddWidget(play_in_loop);
 
-  options_box->AddWidget(tmp_box);
-  options_box->SetPosition(MARGIN_SIDE, map_box->GetPositionY()+map_box->GetSizeY()+ MARGIN_SIDE);
-  widgets.AddWidget(options_box);
-  widgets.Pack();
+  options_box->Pack();
+  bottom_box->AddWidget(options_box);
 
   // ################################################
   // ##  CHAT BOX
   // ################################################
-  VBox* chat_box = new VBox(mainBoxWidth - options_box->GetSizeX() - MARGIN_SIDE, false);
-  chat_box->SetBorder(Point2i(0,0));
 
-  msg_box = new MsgBox(Point2i(400, OPTIONS_BOX_H - 20), Font::FONT_SMALL, Font::FONT_NORMAL);
-  msg_box->NewMessage(_("Join #wormux on irc.freenode.net to find some opponents."));
+  msg_box = new TalkBox(Point2i(mainBoxWidth - options_box->GetSizeX() - MARGIN_SIDE, OPTIONS_BOX_H),
+                        Font::FONT_SMALL, Font::FONT_NORMAL);
+  if (Network::GetInstance()->IsGameMaster()) {
+    msg_box->NewMessage(_("Join #wormux on irc.freenode.net to find some opponents."), c_red);
+  } else {
+    // %s will be replaced with the name of the network game
+    msg_box->NewMessage(Format(_("Welcome to %s!"), Network::GetInstance()->GetGameName().c_str()), c_red);
+  }
 
-  chat_box->SetPosition(options_box->GetPositionX() + options_box->GetSizeX() + MARGIN_SIDE,
-		  options_box->GetPositionY());
-  chat_box->AddWidget(msg_box);
+  msg_box->SetPosition(options_box->GetPositionX() + options_box->GetSizeX() + MARGIN_SIDE,
+                       options_box->GetPositionY());
 
-  HBox* tmp2_box = new HBox(16, false);
-  tmp2_box->SetMargin(4);
-  tmp2_box->SetBorder(Point2i(0,0));
-  line_to_send_tbox = new TextBox(" ", chat_box->GetSizeX()-20,
-                                  Font::FONT_SMALL, Font::FONT_NORMAL);
-  tmp2_box->AddWidget(line_to_send_tbox);
+  bottom_box->AddWidget(msg_box);
+  bottom_box->SetPosition(MARGIN_SIDE, map_box->GetPositionY()+map_box->GetSizeY()+ MARGIN_SIDE);
 
-  send_txt_bt = new Button(res, "menu/send_txt", true);
-  tmp2_box->AddWidget(send_txt_bt);
-
-  chat_box->AddWidget(tmp2_box);
-
-  widgets.AddWidget(chat_box);
+  widgets.AddWidget(bottom_box);
   widgets.Pack();
 
-  resource_manager.UnLoadXMLProfile(res);
+  GetResourceManager().UnLoadXMLProfile(res);
+
+  if (!Network::GetInstance()->IsGameMaster()) {
+    // Client Mode
+    mode_label->SetText(_("Client mode"));
+    player_number->SetVisible(false);
+    connected_players->SetVisible(false);
+    initialized_players->SetVisible(false);
+  } else if (Network::GetInstance()->IsServer()) {
+    // Server Mode
+    mode_label->SetText(_("Server mode"));
+
+  } else {
+    // The first player to connect to a headless server asumes the game master role
+    SetGameMasterCallback();
+  }
 }
 
 NetworkMenu::~NetworkMenu()
@@ -176,10 +175,6 @@ void NetworkMenu::OnClickUp(const Point2i &mousePosition, int button)
     Network::GetInstanceServer()->SetMaxNumberOfPlayers(player_number->GetValue());
     team_box->SetMaxNbLocalPlayers(player_number->GetValue()-1);
   }
-  else if (w == send_txt_bt)
-  {
-    SendChatMsg();
-  }
 }
 
 void NetworkMenu::OnClick(const Point2i &mousePosition, int button)
@@ -187,13 +182,6 @@ void NetworkMenu::OnClick(const Point2i &mousePosition, int button)
   widgets.Click(mousePosition, button);
 }
 
-void NetworkMenu::SendChatMsg()
-{
-  std::string empty = "";
-  Network::GetInstance()->SendChatMessage(line_to_send_tbox->GetText());
-  line_to_send_tbox->SetText(empty);
-}
-
 void NetworkMenu::SaveOptions()
 {
   // map
@@ -206,9 +194,24 @@ void NetworkMenu::SaveOptions()
 //  Config::GetInstance()->Save();
 }
 
+void NetworkMenu::PrepareForNewGame()
+{
+  msg_box->Clear();
+  b_ok->SetVisible(true);
+
+  Network::GetInstance()->SetState(WNet::NETWORK_NEXT_GAME);
+  Network::GetInstance()->SendNetworkState();
+
+  // to choose another random map
+  if (Network::GetInstance()->IsGameMaster())
+    map_box->ChangeMapDelta(0);
+
+  RedrawMenu();
+}
+
 bool NetworkMenu::signal_ok()
 {
-  if (Network::GetInstance()->IsClient())
+  if (!Network::GetInstance()->IsGameMaster())
   {
     // Check the user have selected a team:
     bool found = false;
@@ -224,15 +227,19 @@ bool NetworkMenu::signal_ok()
     }
     if(!found)
     {
-      msg_box->NewMessage(_("You won't be able to play before selecting a team !"));
+      msg_box->NewMessage(_("You won't be able to play before selecting a team!"));
       goto error;
     }
 
-    // Wait for the server, and stay in the menu map / team can still be changed
-    WaitingForServer();
+    // Wait for the game master, and stay in the menu map / team can still be changed
+    WaitingForGameMaster();
+
+    if (Network::GetInstance()->IsGameMaster()) {
+      goto error;
+    }
 
   }
-  else if (Network::GetInstance()->IsServer())
+  else
   {
     if (GetTeamsList().playing_list.size() <= 1)
     {
@@ -242,14 +249,15 @@ bool NetworkMenu::signal_ok()
                                  GetTeamsList().playing_list.size()), c_red);
       goto error;
     }
-    if (Network::GetInstanceServer()->GetNbConnectedPlayers() <= 1)
+    if (Network::GetInstance()->GetNbHostsConnected() == 0
+	|| Network::GetInstance()->GetNbPlayersConnected() == 0)
     {
       msg_box->NewMessage(_("You are alone..."), c_red);
       goto error;
     }
-    if (Network::GetInstanceServer()->GetNbConnectedPlayers() != Network::GetInstanceServer()->GetNbInitializedPlayers()+1)
+    if (Network::GetInstance()->GetNbHostsConnected() != Network::GetInstance()->GetNbHostsInitialized())
     {
-      int nbr = Network::GetInstanceServer()->GetNbConnectedPlayers() - Network::GetInstanceServer()->GetNbInitializedPlayers() - 1;
+      int nbr = Network::GetInstance()->GetNbHostsConnected() - Network::GetInstance()->GetNbHostsInitialized();
       std::string pl = Format(ngettext("Wait! %i player is not ready yet!", "Wait! %i players are not ready yet!", nbr), nbr);
       msg_box->NewMessage(pl, c_red);
       goto error;
@@ -266,7 +274,22 @@ bool NetworkMenu::signal_ok()
     // Starting the game :-)
     SaveOptions();
     play_ok_sound();
+
+    if (Network::GetInstance()->IsServer())
+      IndexServer::GetInstance()->Disconnect();
+
+    if (Network::GetInstance()->IsGameMaster())
+      GameMode::GetInstance()->Load();
+
     Game::GetInstance()->Start();
+
+    if (Network::GetInstance()->IsConnected()
+	&& Network::GetInstance()->GetNbHostsConnected() != 0
+	&& play_in_loop->GetValue()) {
+      PrepareForNewGame();
+      return false;
+    }
+
     Network::GetInstance()->network_menu = NULL;
   }
 
@@ -281,9 +304,9 @@ bool NetworkMenu::signal_ok()
 void NetworkMenu::key_ok()
 {
   // return was pressed while chat texbox still had focus (player wants to send his msg)
-  if (line_to_send_tbox->HasFocus())
+  if (msg_box->TextHasFocus())
   {
-    SendChatMsg();
+    msg_box->SendChatMsg();
     return;
   }
 
@@ -300,35 +323,29 @@ bool NetworkMenu::signal_cancel()
 
 void NetworkMenu::Draw(const Point2i &/*mousePosition*/)
 {
-  if(Network::GetInstance()->IsConnected())
+  if (Network::GetInstance()->IsConnected())
   {
-    if (connected_players != NULL) {
-      //Refresh the number of connected players:
-      int nbr = Network::GetInstanceServer()->GetNbConnectedPlayers();
-      std::string pl = Format(ngettext("%i player connected", "%i players connected", nbr), nbr);
-      if (connected_players->GetText() != pl)
-        connected_players->SetText(pl);
-    }
+    //Refresh the number of connected players:
+    int nbr = Network::GetInstance()->GetNbHostsConnected();
+    std::string pl = Format(ngettext("%i player connected", "%i players connected", nbr), nbr);
+    if (connected_players->GetText() != pl)
+      connected_players->SetText(pl);
 
-    if (initialized_players != NULL) {
-      //Refresh the number of players ready:
-      int nbr = Network::GetInstanceServer()->GetNbInitializedPlayers();
-      std::string pl = Format(ngettext("%i player ready", "%i players ready", nbr), nbr);
-      if (initialized_players->GetText() != pl) {
-        initialized_players->SetText(pl);
-        msg_box->NewMessage(pl, c_red);
-        if (Network::GetInstanceServer()->GetNbConnectedPlayers() -
-            Network::GetInstanceServer()->GetNbInitializedPlayers() == 1
-            && Network::GetInstanceServer()->GetNbConnectedPlayers() >= 1) {
-          msg_box->NewMessage(_("The others are waiting for you! Wake up :-)"), c_red);
-        }
-        else if (Network::GetInstanceServer()->GetNbConnectedPlayers() == 1) {
-          msg_box->NewMessage(_("You are alone :-/"), c_red);
-        }
+    //Refresh the number of players ready:
+    nbr = Network::GetInstance()->GetNbHostsInitialized();
+    pl = Format(ngettext("%i player ready", "%i players ready", nbr), nbr);
+    if (initialized_players->GetText() != pl) {
+      initialized_players->SetText(pl);
+      msg_box->NewMessage(pl, c_red);
+      if (Network::GetInstance()->GetNbHostsConnected() ==
+	  Network::GetInstance()->GetNbHostsInitialized()
+	  && Network::GetInstance()->GetNbHostsInitialized() != 0) {
+	msg_box->NewMessage(_("The others are waiting for you! Wake up! :-)"), c_red);
+      }
+      else if (Network::GetInstance()->GetNbHostsConnected() == 0) {
+	msg_box->NewMessage(_("You are alone. :-/"), c_red);
       }
     }
-
-    IndexServer::GetInstance()->Refresh();
   }
   else {
     close_menu = true;
@@ -352,15 +369,14 @@ void NetworkMenu::AddTeamCallback(const std::string& team_id)
     return;
 
   team_box->AddTeamCallback(team_id);
-//  msg_box->NewMessage(team_id + " selected");
 }
 
-void NetworkMenu::UpdateTeamCallback(const std::string& team_id)
+void NetworkMenu::UpdateTeamCallback(const std::string& old_team_id, const std::string& team_id)
 {
   if ( close_menu )
     return;
 
-  team_box->UpdateTeamCallback(team_id);
+  team_box->UpdateTeamCallback(old_team_id, team_id);
 }
 
 void NetworkMenu::ChangeMapCallback()
@@ -371,14 +387,68 @@ void NetworkMenu::ChangeMapCallback()
   map_box->ChangeMapCallback();
 }
 
+void NetworkMenu::SetGameMasterCallback()
+{
+  // We are becoming game master, updating the menu...
+  AppWormux::GetInstance()->video->SetWindowCaption( std::string("Wormux ") +
+						     Constants::WORMUX_VERSION + " - " +
+						     _("Master mode"));
+  mode_label->SetText(_("Master mode"));
+  player_number->SetVisible(false);
+  connected_players->SetVisible(true);
+  initialized_players->SetVisible(true);
+  map_box->AllowSelection();
+  b_ok->SetVisible(true); // make sure OK button is available if we had already clicked it
+  waiting_for_server = false;
+  msg_box->NewMessage(_("You are the new turn master!"), c_red);
+}
+
 void NetworkMenu::ReceiveMsgCallback(const std::string& msg)
 {
   msg_box->NewMessage(msg);
 }
 
-void NetworkMenu::WaitingForServer()
+// to be call from NetworkMenu::WaitingForGameMaster()
+void NetworkMenu::HandleEvent(const SDL_Event& event)
 {
-  Network::GetInstance()->SetState(Network::NETWORK_MENU_OK);
+  if (!waiting_for_server) {
+    Menu::HandleEvent(event);
+    return;
+  }
+
+  if (event.type == SDL_QUIT) {
+    Menu::mouse_cancel();
+  } else if (event.type == SDL_KEYDOWN) {
+    switch (event.key.keysym.sym)
+      {
+      case SDLK_ESCAPE:
+	Menu::mouse_cancel();
+	break;
+      case SDLK_RETURN:
+      case SDLK_KP_ENTER:
+	msg_box->SendChatMsg();
+	break;
+      case SDLK_F10:
+	AppWormux::GetInstance()->video->ToggleFullscreen();
+	break;
+      default:
+	widgets.SendKey(event.key.keysym);
+	break;
+      }
+  } else if (event.type == SDL_MOUSEBUTTONUP) {
+
+    int x=0, y=0;
+    SDL_GetMouseState( &x, &y );
+    Point2i mousePosition(x, y);
+
+    if (b_cancel->Contains(mousePosition))
+      Menu::mouse_cancel();
+  }
+}
+
+void NetworkMenu::WaitingForGameMaster()
+{
+  Network::GetInstance()->SetState(WNet::NETWORK_MENU_OK);
 
   // warn the server that we have validated the menu
   Network::GetInstance()->SendNetworkState();
@@ -387,52 +457,23 @@ void NetworkMenu::WaitingForServer()
   b_ok->SetVisible(false);
   actions_buttons->NeedRedrawing();
 
-  msg_box->NewMessage(_("Waiting for server, all you can do is cancel or chat!"), c_red);
+  msg_box->NewMessage(_("Waiting for the server. All you can do is cancel or chat!"), c_red);
 
-  int x=0, y=0;
-  SDL_GetMouseState( &x, &y );
-  Point2i mousePosition(x, y);
+  widgets.SetFocusOn(msg_box->GetTextBox());
 
   do
   {
-    // Poll and treat events
-    SDL_Event event;
+    HandleEvents();
 
-    while (SDL_PollEvent(&event))
-    {
-      Point2i mousePosition(event.button.x, event.button.y);
-
-      if (event.type == SDL_QUIT) {
-        Menu::mouse_cancel();
-      } else if (event.type == SDL_KEYDOWN) {
-        switch (event.key.keysym.sym)
-          {
-          case SDLK_ESCAPE:
-            Menu::mouse_cancel();
-            break;
-          case SDLK_RETURN:
-          case SDLK_KP_ENTER:
-            SendChatMsg();
-            break;
-          case SDLK_F10:
-            AppWormux::GetInstance()->video->ToggleFullscreen();
-            break;
-          default:
-            widgets.SendKey(event.key.keysym);
-            break;
-          }
-      } else if (event.type == SDL_MOUSEBUTTONUP) {
-        if (b_cancel->Contains(mousePosition))
-          Menu::mouse_cancel();
-
-        if (send_txt_bt->Contains(mousePosition))
-          SendChatMsg();
-      }
-    }
+    int x=0, y=0;
+    SDL_GetMouseState( &x, &y );
+    Point2i mousePosition(x, y);
 
+    Display(mousePosition);
     Menu::Display(mousePosition);
-    widgets.SetMouseFocusOn(line_to_send_tbox);
 
-  } while (Network::GetInstance()->GetState() == Network::NETWORK_MENU_OK &&
-           Network::GetInstance()->IsConnected());
+  } while (Network::GetInstance()->IsConnected() &&
+	   Network::GetInstance()->GetState() == WNet::NETWORK_MENU_OK);
+
+  waiting_for_server = false;
 }
