@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,10 +38,12 @@ class NetworkTeamsSelectionBox : public TeamsSelectionBox
   void SetNbLocalTeams(uint nb_teams, uint previous_nb);
   void AddLocalTeam(uint i);
   void RemoveLocalTeam(uint i);
-  void SetLocalTeam(uint i, Team& team, bool remove_previous_team);
+  void SetLocalTeam(uint i, Team& team);
+
+  void SetDefaultPlayerName(Team& team);
 
   void PrevTeam(uint i);
-  void NextTeam(uint i, bool check_null_prev_team = true);
+  void NextTeam(uint i);
 
  public:
   NetworkTeamsSelectionBox(const Point2i &size);
@@ -51,7 +53,7 @@ class NetworkTeamsSelectionBox : public TeamsSelectionBox
   virtual Widget* ClickUp(const Point2i &mousePosition, uint button);
 
   void AddTeamCallback(const std::string& team_id);
-  void UpdateTeamCallback(const std::string& team_id);
+  void UpdateTeamCallback(const std::string& old_team_id, const std::string& team_id);
   void DelTeamCallback(const std::string& team_id);
 
   void SetMaxNbLocalPlayers(uint nb);
