@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,10 +53,9 @@ class OptionMenu : public Menu
    ComboBox *cbox_video_mode;
    ListBox *lbox_languages;
    CheckBox *opt_display_wind_particles;
+   CheckBox *opt_display_multisky;
    CheckBox *opt_display_energy;
    CheckBox *opt_display_name;
-   CheckBox *opt_scroll_on_border;
-   SpinButtonWithPicture * opt_scroll_border_size;
 #ifndef __APPLE__
    CheckBox *full_screen;
 #endif
@@ -74,6 +73,9 @@ class OptionMenu : public Menu
 
    /* Misc options controllers */
    CheckBox *opt_updates;
+   CheckBox *opt_lefthanded_mouse;
+   CheckBox *opt_scroll_on_border;
+   SpinButtonWithPicture * opt_scroll_border_size;
 
    void SaveOptions();
    void OnClick(const Point2i &mousePosition, int button);
@@ -85,13 +87,14 @@ class OptionMenu : public Menu
    /* Teams controllers */
 
    ListBox *lbox_teams;
-   ButtonPic *add_team;
-   ButtonPic *delete_team;
+   Button *add_team;
+   Button *delete_team;
    CustomTeam  *selected_team;
    TextBox *tbox_team_name;
    Label *team_name;
    std::vector<TextBox *> tbox_character_name_list;
 
+   bool TeamInfoValid();
    void AddTeam();
    void DeleteTeam();
    void LoadTeam();
@@ -101,7 +104,6 @@ class OptionMenu : public Menu
 
    bool signal_ok();
    bool signal_cancel();
-   void key_tab();
 };
 
 #endif
