@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "include/app.h"
 #include "menu/options_menu.h"
 #include "menu/help_menu.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
 //-----------------------------------------------------------------------------
@@ -54,7 +53,7 @@ PauseMenu::PauseMenu(bool& _exit_game)  :
   box->AddWidget(bt_options_menu);
 
   bt_help_menu = new ButtonPic(_("Help"),
- 			  "menu/ico_help", size);
+			       "menu/ico_help", size);
   box->AddWidget(bt_help_menu);
 
   bt_main_menu = new ButtonPic(_("Quit battle"),
@@ -135,7 +134,7 @@ void PauseMenu::OnClickUp(const Point2i &mousePosition, int button)
 {
   widgets.ClickUp(mousePosition, button);
 
-  if (button == SDL_BUTTON_LEFT) {
+  if (button == Mouse::BUTTON_LEFT()) {
     if (bt_main_menu->Contains(mousePosition)) {
       BackToMainMenu();
     } else if (bt_continue_play->Contains(mousePosition)) {
