@@ -21,14 +21,15 @@
  *****************************************************************************/
 
 #include <SDL_events.h>
-#include "include/app.h"
-#include "network/admin_commands.h"
-#include "network/chat.h"
-#include "graphic/text_list.h"
-#include "network/network.h"
-#include "graphic/text.h"
 #include "game/time.h"
-#include "tool/i18n.h"
+#include "graphic/text.h"
+#include "graphic/text_list.h"
+#include "include/action.h"
+#include "include/action_handler.h"
+#include "include/app.h"
+#include "network/chat.h"
+#include "network/admin_commands.h"
+#include "network/network.h"
 #include "tool/text_handling.h"
 
 const uint HEIGHT=15;
@@ -74,21 +75,28 @@ void Chat::Show()
 
 void Chat::ShowInput()
 {
-  check_input = true;
+  if (!check_input) {
+    check_input = true;
+
+    /* Enable key repeat when chatting :) */
+    SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
+  }
+
   if (input == NULL){
     input = new Text("", c_white);
     msg = new Text(_("Say: "), c_red);
   }
 
   /* FIXME where do those constants come from ?*/
-  msg->DrawTopLeft(Point2i(25, 500));
+  msg->DrawTopLeft(Point2i(25, 400));
   if (input->GetText() != "") {
-    input->DrawTopLeft(Point2i(25 + msg->GetWidth() + 5, 500));
-    input->DrawCursor(Point2i(25 + msg->GetWidth() + 5, 500), cursor_pos);
+    input->DrawTopLeft(Point2i(25 + msg->GetWidth() + 5, 400));
+    input->DrawCursor(Point2i(25 + msg->GetWidth() + 5, 400), cursor_pos);
   }
 }
 
-bool Chat::CheckInput() const {
+bool Chat::CheckInput() const
+{
   return check_input;
 }
 
@@ -102,6 +110,17 @@ void Chat::NewMessage(const std::string &msg)
   chat.AddText(msg, MAXLINES);
 }
 
+void Chat::SendMessage(const std::string &msg)
+{
+  if (msg.size() == 0)
+    return;
+
+  Action* a = new Action(Action::ACTION_CHAT_MESSAGE);
+  a->Push(Network::GetInstance()->GetPlayer().GetNickname());
+  a->Push(msg);
+  ActionHandler::GetInstance()->NewAction(a);
+}
+
 void Chat::HandleKey(const SDL_Event& event)
 {
   SDL_KeyboardEvent kbd_event = event.key;
@@ -113,16 +132,20 @@ void Chat::HandleKey(const SDL_Event& event)
   } else {
 
     switch (key.sym){
-      
+
     case SDLK_RETURN:
     case SDLK_KP_ENTER:
       check_input = false; //Hide input widget
       if ( txt[0] == '/' )
 	ProcessCommand(txt);
-      else
-	if (txt != "" )
-	  Network::GetInstance()->SendChatMessage(txt); //Send 'txt' to other players
+      else if (txt != "" )
+	SendMessage(txt);
+
       input->Set("");
+      cursor_pos = 0;
+
+      // Disable key repeat during the game!
+      SDL_EnableKeyRepeat(0, 0);
       break;
 
     default:
