@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,8 +28,9 @@
 class NetworkLocal : public Network
 {
 protected:
-  virtual void HandleAction(Action* /*a*/, DistantComputer* /*sender*/) const { ASSERT(false) };
+  virtual void HandleAction(Action* /*a*/, DistantComputer* /*sender*/) { ASSERT(false) };
   virtual void WaitActionSleep() { ASSERT(false) };
+  virtual void SendAction(const Action& a, DistantComputer* client, bool clt_as_rcver) const;
 
 public:
   NetworkLocal();
@@ -38,10 +39,7 @@ public:
   virtual bool IsConnected() const { return false; }
   virtual bool IsLocal() const { return true; }
 
-  virtual void SendAction(const Action& action) const;
-
-  virtual std::list<DistantComputer*>::iterator CloseConnection(std::list<DistantComputer*>::iterator closed);
-
+  virtual void CloseConnection(std::list<DistantComputer*>::iterator closed);
 };
 
 //-----------------------------------------------------------------------------
