@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,33 +21,23 @@
 
 #ifndef RANDOMSYNC_H
 #define RANDOMSYNC_H
-#include <list>
-#include "tool/rectangle.h"
-#include "tool/point.h"
 
-class RandomSync{
+#include <WORMUX_singleton.h>
+#include <WORMUX_random.h>
+
+class RandomSyncGen : public RandomGenerator, public Singleton<RandomSyncGen>
+{
+private:
 #ifdef DEBUG
   uint nb_get;
 #endif
-
+protected:
+  virtual uint GetRand();
+  virtual void SetRand(uint seed);
 public:
-  RandomSync();
-  void Init();
-
-  uint GetRand(); // public only to check synchronization
-
-  bool GetBool();
-  double GetDouble();
-  double GetDouble(double max);
-  double GetDouble(double min, double max);
-  long GetLong(long min, long max);
-  Point2i GetPoint(const Rectanglei &rect);
-  Point2i GetPoint(const Point2i &pt);
-
-  //to fill the pregenerated tables
-  void SetRand(uint seed);
+  virtual void InitRandom();
 };
 
-extern RandomSync randomSync;
+RandomSyncGen& RandomSync();
 
 #endif
