@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
 #define BARREL_H
 
 #include "physical_obj.h"
-#include "../graphic/sprite.h"
 
+class Sprite;
 
 class PetrolBarrel : public PhysicalObj
 {
@@ -33,7 +33,7 @@ class PetrolBarrel : public PhysicalObj
     PetrolBarrel();
     ~PetrolBarrel();
     void Draw();
-    void Refresh();
+    void Refresh() { };
   protected:
     void SignalGhostState(bool was_already_dead);
 };
