@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -62,9 +62,11 @@ class ObjBox : public PhysicalObj //it would be nice to name this "Box", but tha
     Sprite *anim;
     static int start_life_points;
     void Explode();
-    // Signal Fall ending
-    virtual void SignalCollision(const Point2d& my_speed_before);
-    virtual void SignalObjectCollision(PhysicalObj *, const Point2d& my_speed_before);
+
+    virtual void SignalGroundCollision(const Point2d& my_speed_before);
+    virtual void SignalObjectCollision(const Point2d& my_speed_before,
+				       PhysicalObj *object,
+				       const Point2d& object_speed);
     virtual void SignalDrowning();
     virtual void SignalGhostState(bool was_already_dead);
 };
