@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,15 +26,18 @@
 #include "game/config.h"
 #include "game/game_mode.h"
 #include "include/base.h"
-#include "tool/debug.h"
+#include <WORMUX_debug.h>
 #include "tool/xml_document.h"
 //-----------------------------------------------------------------------------
 
+static const double DEFAULT_WATER_RESIST_FACTOR = 40;
+
 ObjectConfig::ObjectConfig()
 {
   m_rebounding = false;
   m_rebound_factor = 0.01;
   m_air_resist_factor = 1.0;
+  m_water_resist_factor = DEFAULT_WATER_RESIST_FACTOR;
   m_wind_factor = 1.0;
   m_gravity_factor = 1.0;
   m_mass = 1.0;
@@ -68,6 +71,7 @@ void ObjectConfig::LoadXml(const std::string& obj_name, const std::string &confi
   XmlReader::ReadDouble(elem, "mass", m_mass);
   XmlReader::ReadDouble(elem, "wind_factor", m_wind_factor);
   XmlReader::ReadDouble(elem, "air_resist_factor", m_air_resist_factor);
+  XmlReader::ReadDouble(elem, "water_resist_factor", m_water_resist_factor);
   XmlReader::ReadDouble(elem, "gravity_factor", m_gravity_factor);
   XmlReader::ReadDouble(elem, "rebound_factor", m_rebound_factor);
   XmlReader::ReadBool(elem, "rebounding", m_rebounding);
