@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
 #ifndef OBJECT_CFG_H
 #define OBJECT_CFG_H
 //-----------------------------------------------------------------------------
-#include "../include/base.h"
-#include "../tool/xml_document.h"
+#include <string>
 //-----------------------------------------------------------------------------
 
 class ObjectConfig
@@ -36,10 +35,13 @@ public:
   double m_wind_factor;
 
   // Air resistance factor. 1 = normal air resistance.
-  double m_air_resist_factor ;
+  double m_air_resist_factor;
+
+  // Water resistance factor. Related to air_resist_factor.
+  double m_water_resist_factor;
 
   // Define how the object is affected by gravity.
-  double m_gravity_factor ;
+  double m_gravity_factor;
 
   // Tell if it's a rebounding object...
   bool  m_rebounding;
@@ -48,7 +50,7 @@ public:
   double m_rebound_factor;
 
   ObjectConfig();
-  ~ObjectConfig();
+  virtual ~ObjectConfig() { };
 
   void LoadXml(const std::string& obj_name, const std::string &config_file);
 };
