@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,19 +26,21 @@
 #include "map/map.h"
 #include "map/maps_list.h"
 #include "map/camera.h"
-#include "tool/debug.h"
-//#include "tool/random.h"
-#include "tool/rectangle.h"
+#include <WORMUX_debug.h>
+#include <WORMUX_rectangle.h>
 #include "game/time.h"
 #include "weapon/mine.h"
 #include <vector>
 #include <iostream>
 
-//-----------------------------------------------------------------------------
-ObjectsList lst_objects;
-//-----------------------------------------------------------------------------
+ObjectsList::ObjectsList()
+{}
+
+ObjectsList::~ObjectsList()
+{
+  FreeMem();
+}
 
-// Initialise la liste des objets standards
 void ObjectsList::PlaceMines()
 {
   MSG_DEBUG("lst_objects","Placing mines");
@@ -111,7 +113,7 @@ bool ObjectsList::AllReady() const
   {
     if (!(*object)->IsImmobile())
     {
-      MSG_DEBUG("lst_objects", "\"%s\" is not ready ( IsImmobile()==fasle )", (*object)->GetName().c_str());
+      MSG_DEBUG("lst_objects", "\"%s\" is not ready ( IsImmobile()==false )", (*object)->GetName().c_str());
       return false;
     }
   }
@@ -137,11 +139,33 @@ void ObjectsList::FreeMem()
 void ObjectsList::RemoveOverlappedObjectReference(const PhysicalObj * obj)
 {
   for(iterator it = overlapped_objects.begin(); it != overlapped_objects.end(); it ++) {
-    if((*it)->GetOverlappingObject() == obj) {
-      MSG_DEBUG("lst_objects", "removing overlapse reference of \"%s\" in \"%s\"",
-                obj->GetName().c_str(), (*it)->GetName().c_str());
+
+    if ((*it)->GetOverlappingObject() == obj) {
+      MSG_DEBUG("lst_objects", "removing overlapse reference of \"%s\" (%p) in \"%s\"",
+                obj->GetName().c_str(), obj, (*it)->GetName().c_str());
       (*it)->SetOverlappingObject(NULL);
       it = overlapped_objects.erase(it);
+
+    } else if ((*it) == obj) {
+      MSG_DEBUG("lst_objects", "removing overlapse object of \"%s\" (%p)",
+                obj->GetName().c_str(), obj);
+      it = overlapped_objects.erase(it);
     }
   }
 }
+
+void ObjectsList::AddOverlappedObject(PhysicalObj * obj)
+{
+  MSG_DEBUG("lst_objects", "adding overlapsed object \"%s\" %p",
+	    obj->GetName().c_str(), obj);
+
+  overlapped_objects.push_back(obj);
+}
+
+void ObjectsList::RemoveOverlappedObject(PhysicalObj * obj)
+{
+  MSG_DEBUG("lst_objects", "removing overlapsed object \"%s\" %p",
+	    obj->GetName().c_str(), obj);
+
+  overlapped_objects.remove(obj);
+}
