@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,14 +23,15 @@
 #define OBJECTS_LIST_H
 //-----------------------------------------------------------------------------
 #include "include/base.h"
+#include <WORMUX_singleton.h>
 #include "object/physical_obj.h"
 #include <list>
 //-----------------------------------------------------------------------------
 
 // Loop for all objects
 #define FOR_ALL_OBJECTS(object) \
-  for (ObjectsList::iterator object=lst_objects.begin(), \
-       end=lst_objects.end(); \
+  for (ObjectsList::iterator object=ObjectsList::GetRef().begin(), \
+       end=ObjectsList::GetRef().end(); \
        object != end; \
        ++object)
 
@@ -39,19 +40,24 @@
 // Loop for all objects that aren't out of the screen
 #define FOR_EACH_OBJECT(object) \
   FOR_ALL_OBJECTS(object) \
-  if (!(*object)->IsGhost())
+  	if (!(*object)->IsGhost())
 
 //-----------------------------------------------------------------------------
 
-class ObjectsList : public std::list<PhysicalObj*>
+class ObjectsList : public std::list<PhysicalObj*>, public Singleton<ObjectsList>
 {
+  private:
+    ObjectsList();
+    ~ObjectsList();
+    friend class Singleton<ObjectsList>;
+
+    void RemoveOverlappedObjectReference(const PhysicalObj * obj);
+
   public:
     typedef std::list<PhysicalObj*>::iterator iterator;
     std::list<PhysicalObj*> overlapped_objects;
-  public:
-    ~ObjectsList() { FreeMem(); };
-    inline void AddObject(PhysicalObj * obj) { push_back(obj);};
 
+  public:
     // Call the Refresh method of all the objects
     void Refresh();
     // Call the Draw method of all the objects
@@ -66,17 +72,18 @@ class ObjectsList : public std::list<PhysicalObj*>
 
     void FreeMem();
 
+    inline void AddObject(PhysicalObj * obj) { push_back(obj);};
+
     // Overlapse handling
     inline void RemoveObject(PhysicalObj * obj)
     {
       remove(obj);
       RemoveOverlappedObjectReference(obj);
     };
-    void AddOverlappedObject(PhysicalObj * obj) { overlapped_objects.push_back(obj); };
-    void RemoveOverlappedObjectReference(const PhysicalObj * obj);
-    void RemoveOverlappedObject(PhysicalObj * obj) { overlapped_objects.remove(obj); };
+
+    void AddOverlappedObject(PhysicalObj * obj);
+    void RemoveOverlappedObject(PhysicalObj * obj);
 };
 
-extern ObjectsList lst_objects;
 //-----------------------------------------------------------------------------
 #endif
