@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,17 +38,15 @@
 #include "team/macro.h"
 #include "team/team.h"
 #include "team/teams_list.h"
-#include "tool/debug.h"
+#include <WORMUX_debug.h>
 #include "tool/isnan.h"
 #include "tool/math_tools.h"
-#include "tool/point.h"
-#include "tool/random.h"
-#include "tool/rectangle.h"
+#include <WORMUX_point.h>
+#include <WORMUX_random.h>
+#include <WORMUX_rectangle.h>
 #include "weapon/weapon_launcher.h"
 
 const int Y_OBJET_MIN = -10000;
-const int WATER_RESIST_FACTOR = 40;
-
 const double PIXEL_PER_METER = 40;
 
 double MeterDistance (const Point2i &p1, const Point2i &p2)
@@ -57,10 +55,16 @@ double MeterDistance (const Point2i &p1, const Point2i &p2)
 }
 
 PhysicalObj::PhysicalObj (const std::string &name, const std::string &xml_config) :
-  m_goes_through_wall(false),
+  m_collides_with_ground(true),
   m_collides_with_characters(false),
   m_collides_with_objects(false),
   m_rebound_position(-1,-1),
+  m_test_left(0),
+  m_test_right(0),
+  m_test_top(0),
+  m_test_bottom(0),
+  m_width(0),
+  m_height(0),
   // No collision with this object until we have gone out of his collision rectangle
   m_overlapping_object(NULL),
   m_minimum_overlapse_time(0),
@@ -68,12 +72,6 @@ PhysicalObj::PhysicalObj (const std::string &name, const std::string &xml_config
   m_is_character(false),
   m_is_fire(false),
   m_name(name),
-  m_test_left(0),
-  m_test_right(0),
-  m_test_top(0),
-  m_test_bottom(0),
-  m_width(0),
-  m_height(0),
   m_rebound_sound(""),
   m_alive(ALIVE),
   m_energy(-1),
@@ -122,31 +120,35 @@ double PhysicalObj::GetYdouble() const { return round(GetPhysY() * PIXEL_PER_MET
 int PhysicalObj::GetX() const { return (int)GetXdouble(); };
 int PhysicalObj::GetY() const { return (int)GetYdouble(); };
 
-void PhysicalObj::SetSize(const Point2i &newSize){
+void PhysicalObj::SetSize(const Point2i &newSize)
+{
   if( newSize == Point2i(0, 0) )
           Error( "New size of (0, 0) !");
   m_width = newSize.x;
   m_height = newSize.y;
+
+  ASSERT(m_width >= 0);
+  ASSERT(m_height >= 0);
   SetPhysSize( (double)newSize.x / PIXEL_PER_METER, (double)newSize.y/PIXEL_PER_METER );
 }
 
 void PhysicalObj::StoreValue(Action *a)
 {
   Physics::StoreValue(a);
-  a->Push(m_goes_through_wall);
+  a->Push(m_collides_with_ground);
   a->Push(m_collides_with_characters);
   a->Push(m_collides_with_objects);
   a->Push(m_rebound_position);
   a->Push((int)m_minimum_overlapse_time);
   a->Push(m_ignore_movements);
   a->Push(m_is_character);
-  a->Push((int)m_test_left);
-  a->Push((int)m_test_right);
-  a->Push((int)m_test_top);
-  a->Push((int)m_test_bottom);
-  a->Push((int)m_width);
-  a->Push((int)m_height);
-  a->Push((int)m_alive);
+  a->Push(m_test_left);
+  a->Push(m_test_right);
+  a->Push(m_test_top);
+  a->Push(m_test_bottom);
+  a->Push(m_width);
+  a->Push(m_height);
+  a->Push(m_alive);
   a->Push(m_energy);
   a->Push(m_allow_negative_y);
 }
@@ -154,22 +156,29 @@ void PhysicalObj::StoreValue(Action *a)
 void PhysicalObj::GetValueFromAction(Action *a)
 {
   Physics::GetValueFromAction(a);
-  m_goes_through_wall        = !!a->PopInt();
+  m_collides_with_ground     = !!a->PopInt();
   m_collides_with_characters = !!a->PopInt();
   m_collides_with_objects    = !!a->PopInt();
   m_rebound_position         = a->PopPoint2i();
   m_minimum_overlapse_time   = (uint)a->PopInt();
   m_ignore_movements         = !!a->PopInt();
   m_is_character             = !!a->PopInt();
-  m_test_left                = (uint)a->PopInt();
-  m_test_right               = (uint)a->PopInt();
-  m_test_top                 = (uint)a->PopInt();
-  m_test_bottom              = (uint)a->PopInt();
-  m_width                    = (uint)a->PopInt();
-  m_height                   = (uint)a->PopInt();
+  m_test_left                = a->PopInt();
+  m_test_right               = a->PopInt();
+  m_test_top                 = a->PopInt();
+  m_test_bottom              = a->PopInt();
+  m_width                    = a->PopInt();
+  m_height                   = a->PopInt();
   m_alive                    = (alive_t)a->PopInt();
   m_energy                   = a->PopInt();
   m_allow_negative_y         = !!a->PopInt();
+
+  ASSERT(m_test_left >= 0);
+  ASSERT(m_test_right >= 0);
+  ASSERT(m_test_top >= 0);
+  ASSERT(m_test_bottom >= 0);
+  ASSERT(m_width >= 0);
+  ASSERT(m_height >= 0);
 }
 
 void PhysicalObj::SetOverlappingObject(PhysicalObj* obj, int timeout)
@@ -177,13 +186,13 @@ void PhysicalObj::SetOverlappingObject(PhysicalObj* obj, int timeout)
   m_minimum_overlapse_time = 0;
   if(obj != NULL) {
     m_overlapping_object = obj;
-    lst_objects.AddOverlappedObject(this);
+    ObjectsList::GetRef().AddOverlappedObject(this);
     MSG_DEBUG("physic.overlapping", "\"%s\" doesn't check any collision with \"%s\" anymore during %d ms",
               GetName().c_str(), obj->GetName().c_str(), timeout);
   } else {
     if(m_overlapping_object != NULL) {
       m_overlapping_object = NULL;
-      lst_objects.RemoveOverlappedObject(this);
+      ObjectsList::GetRef().RemoveOverlappedObject(this);
       MSG_DEBUG( "physic.overlapping", "clearing overlapping object in \"%s\"", GetName().c_str());
     }
     return;
@@ -221,6 +230,11 @@ void PhysicalObj::SetTestRect (uint left, uint right, uint top, uint bottom)
   m_test_right = right;
   m_test_top = top;
   m_test_bottom = bottom;
+
+  ASSERT(m_test_left >= 0);
+  ASSERT(m_test_right >= 0);
+  ASSERT(m_test_top >= 0);
+  ASSERT(m_test_bottom >= 0);
 }
 
 void PhysicalObj::SetEnergyDelta(int delta, bool /*do_report*/)
@@ -266,11 +280,11 @@ collision_t PhysicalObj::NotifyMove(Point2d oldPos, Point2d newPos)
   // First iteration position.
   pos = oldPos + offset;
 
-  if (m_goes_through_wall || IsInWater())
+  if (!m_collides_with_ground || IsInWater())
   {
-    MSG_DEBUG("physic.move", "%s moves (%f, %f) -> (%f, %f), thr_wall:%d, water:%d",
+    MSG_DEBUG("physic.move", "%s moves (%f, %f) -> (%f, %f), collides ground:%d, water:%d",
               typeid(*this).name(), oldPos.x, oldPos.y, newPos.x, newPos.y,
-              m_goes_through_wall, IsInWater());
+              m_collides_with_ground, IsInWater());
 
     SetXY(newPos);
     return NO_COLLISION;
@@ -280,12 +294,12 @@ collision_t PhysicalObj::NotifyMove(Point2d oldPos, Point2d newPos)
   {
     Point2i tmpPos( lround(pos.x), lround(pos.y) );
 
-    // Check if we exit the world. If so, we stop moving and return.
+    // Check if we exit the GetWorld(). If so, we stop moving and return.
     if( IsOutsideWorldXY(tmpPos) ){
 
-      if( !world.IsOpen() ){
-        tmpPos.x = InRange_Long(tmpPos.x, 0, world.GetWidth() - GetWidth() - 1);
-        tmpPos.y = InRange_Long(tmpPos.y, 0, world.GetHeight() - GetHeight() - 1);
+      if( !GetWorld().IsOpen() ){
+        tmpPos.x = InRange_Long(tmpPos.x, 0, GetWorld().GetWidth() - GetWidth() - 1);
+        tmpPos.y = InRange_Long(tmpPos.y, 0, GetWorld().GetHeight() - GetHeight() - 1);
         MSG_DEBUG( "physic.state", "%s - DeplaceTestCollision touche un bord : %d, %d",  m_name.c_str(), tmpPos.x, tmpPos.y );
         collision = COLLISION_ON_GROUND;
         break;
@@ -342,13 +356,10 @@ collision_t PhysicalObj::NotifyMove(Point2d oldPos, Point2d newPos)
     break;
   case COLLISION_ON_GROUND:
     SignalGroundCollision(speed_before_collision);
-    SignalCollision(speed_before_collision);
     break;
   case COLLISION_ON_OBJECT:
-    SignalObjectCollision(collided_obj, speed_before_collision);
-    collided_obj->SignalObjectCollision(this, speed_collided_obj);
-    SignalCollision(speed_before_collision);
-    collided_obj->SignalCollision(speed_collided_obj);
+    SignalObjectCollision(speed_before_collision, collided_obj, speed_collided_obj);
+    collided_obj->SignalObjectCollision(speed_collided_obj, this, speed_before_collision);
     break;
   }
   // ===================================
@@ -416,7 +427,7 @@ void PhysicalObj::ContactPointAngleOnGround(const Point2d& oldPos,
     int cx, cy;
 
     if (ContactPoint(cx, cy)) {
-      contactAngle = world.ground.Tangent(cx, cy);
+      contactAngle = GetWorld().ground.Tangent(cx, cy);
       if(!isNaN(contactAngle)) {
         contactPos.x = (double)cx / PIXEL_PER_METER;
         contactPos.y = (double)cy / PIXEL_PER_METER;
@@ -435,7 +446,7 @@ void PhysicalObj::UpdatePosition ()
   // No ghost allowed here !
   if (IsGhost()) return;
 
-  if ( !m_goes_through_wall )
+  if (m_collides_with_ground)
     {
       // object is not moving and has no reason to move
       if ( !IsMoving() && !FootsInVacuum() && !IsInWater() ) return;
@@ -450,7 +461,7 @@ void PhysicalObj::UpdatePosition ()
   if (IsGhost()) return;
 
   // Classical object sometimes sinks in water and sometimes goes out of water!
-  if ( !m_goes_through_wall )
+  if (m_collides_with_ground)
     {
       if ( IsInWater() && m_alive != DROWNED && m_alive != DEAD) Drown();
       else if ( !IsInWater() && m_alive == DROWNED ) GoOutOfWater();
@@ -492,10 +503,10 @@ bool PhysicalObj::PutOutOfGround()
     return true;
 
   bool left,right,top,bottom;
-  left   = world.IsInVacuum_left(*this, 0, 0);
-  right  = world.IsInVacuum_right(*this, 0, 0);
-  top    = world.IsInVacuum_top(*this, 0, 0);
-  bottom = world.IsInVacuum_bottom(*this, 0, 0);
+  left   = GetWorld().IsInVacuum_left(*this, 0, 0);
+  right  = GetWorld().IsInVacuum_right(*this, 0, 0);
+  top    = GetWorld().IsInVacuum_top(*this, 0, 0);
+  bottom = GetWorld().IsInVacuum_bottom(*this, 0, 0);
 
   int dx = (int)GetTestRect().GetSizeX() * (right-left);
   int dy = (int)GetTestRect().GetSizeY() * (top-bottom);
@@ -540,7 +551,7 @@ void PhysicalObj::Drown()
   m_alive = DROWNED;
 
   // Set the air grab to water resist factor.
-  SetAirResistFactor(WATER_RESIST_FACTOR * GetAirResistFactor());
+  SetAirResistFactor(m_cfg.m_water_resist_factor);
 
   // Ensure the gravity factor is upper than 0.0
   if (EqualsZero(GetGravityFactor()))
@@ -548,10 +559,10 @@ void PhysicalObj::Drown()
 
   // If fire, do smoke...
   if (m_is_fire)
-    world.water.Smoke(GetPosition());
+    GetWorld().water.Smoke(GetPosition());
   // make a splash in the water :-)
   else if (GetMass() >= 2)
-    world.water.Splash(GetPosition());
+    GetWorld().water.Splash(GetPosition());
 
   StopMoving();
   StartMoving();
@@ -575,25 +586,25 @@ void PhysicalObj::SignalRebound()
 {
   // TO CLEAN...
    if (!m_rebound_sound.empty())
-     JukeBox::GetInstance()->Play("share", m_rebound_sound) ;
+     JukeBox::GetInstance()->Play("default", m_rebound_sound) ;
 }
 
-void PhysicalObj::SetCollisionModel(bool goes_through_wall,
+void PhysicalObj::SetCollisionModel(bool collides_with_ground,
                                     bool collides_with_characters,
                                     bool collides_with_objects)
 {
-  m_goes_through_wall = goes_through_wall;
+  m_collides_with_ground = collides_with_ground;
   m_collides_with_characters = collides_with_characters;
   m_collides_with_objects = collides_with_objects;
 
   // Check boolean values
   {
     if (m_collides_with_characters || m_collides_with_objects)
-      ASSERT(m_goes_through_wall == false);
+      ASSERT(m_collides_with_ground);
 
-    if (m_goes_through_wall) {
-      ASSERT(m_collides_with_characters == false);
-      ASSERT(m_collides_with_objects == false);
+    if (!m_collides_with_ground) {
+      ASSERT(!m_collides_with_characters);
+      ASSERT(!m_collides_with_objects);
     }
   }
 }
@@ -619,9 +630,9 @@ bool PhysicalObj::IsOutsideWorldXY(const Point2i& position) const{
   int x = position.x + m_test_left;
   int y = position.y + m_test_top;
 
-  if( world.IsOutsideWorldXwidth(x, GetTestWidth()) )
+  if( GetWorld().IsOutsideWorldXwidth(x, GetTestWidth()) )
           return true;
-  if( world.IsOutsideWorldYheight(y, GetTestHeight()) ){
+  if( GetWorld().IsOutsideWorldYheight(y, GetTestHeight()) ){
     if( m_allow_negative_y )
       if( (Y_OBJET_MIN <= y) && (y + GetTestHeight() - 1 < 0) )
                   return false;
@@ -633,7 +644,7 @@ bool PhysicalObj::IsOutsideWorldXY(const Point2i& position) const{
 bool PhysicalObj::IsInVacuumXY(const Point2i &position, bool check_object) const
 {
   if( IsOutsideWorldXY(position) )
-    return world.IsOpen();
+    return GetWorld().IsOpen();
 
   if( check_object && CollidedObjectXY(position) )
     return false;
@@ -645,7 +656,7 @@ bool PhysicalObj::IsInVacuumXY(const Point2i &position, bool check_object) const
   Rectanglei rect(position.x + m_test_left, position.y + m_test_top,
                   width, height);
 
-  return world.RectIsInVacuum (rect);
+  return GetWorld().RectIsInVacuum (rect);
 }
 
 PhysicalObj* PhysicalObj::CollidedObjectXY(const Point2i & position) const
@@ -689,7 +700,7 @@ bool PhysicalObj::FootsInVacuumXY(const Point2i &position) const
 {
   if( IsOutsideWorldXY(position) ){
     MSG_DEBUG("physical", "%s - physobj is outside the world", m_name.c_str());
-    return world.IsOpen();
+    return GetWorld().IsOpen();
   }
 
   int y_test = position.y + m_height - m_test_bottom;
@@ -707,15 +718,15 @@ bool PhysicalObj::FootsInVacuumXY(const Point2i &position) const
   if(CollidedObjectXY( position + Point2i(0, 1)) != NULL )
     return false;
 
-  return world.RectIsInVacuum (rect);
+  return GetWorld().RectIsInVacuum (rect);
 }
 
 bool PhysicalObj::IsInWater () const
 {
   ASSERT (!IsGhost());
-  if (!world.water.IsActive()) return false;
-  int x = InRange_Long(GetCenterX(), 0, world.GetWidth()-1);
-  return (int)world.water.GetHeight(x) < GetCenterY();
+  if (!GetWorld().water.IsActive()) return false;
+  int x = InRange_Long(GetCenterX(), 0, GetWorld().GetWidth()-1);
+  return (int)GetWorld().water.GetHeight(x) < GetCenterY();
 }
 
 void PhysicalObj::DirectFall()
@@ -729,40 +740,40 @@ bool PhysicalObj::ContactPoint (int & contact_x, int & contact_y) const
   int x1, x2, y1, y2;
 
   // We are looking for a point in contact with the bottom of the object:
-  y1 = (GetY()+m_height-m_test_bottom);
-  y2 = y1-1;
-  for (uint x=GetX()+ m_test_left; x<=(GetX()+m_width)-m_test_right; x++)
+  y1 = GetY() + m_height - m_test_bottom;
+  y2 = y1 - 1;
+  for (int x = GetX() + m_test_left; x <= GetX() + m_width - m_test_right; x++)
   {
-    if(!world.IsOutsideWorld(Point2i(x,y1)) && !world.IsOutsideWorld(Point2i(x,y2))
-    && world.ground.IsEmpty(Point2i(x,y2)) && !world.ground.IsEmpty(Point2i(x,y1)))
+    if(!GetWorld().IsOutsideWorld(Point2i(x,y1)) && !GetWorld().IsOutsideWorld(Point2i(x,y2))
+    && GetWorld().ground.IsEmpty(Point2i(x,y2)) && !GetWorld().ground.IsEmpty(Point2i(x,y1)))
     {
       contact_x = x;
-      contact_y = GetY() +m_height-m_test_bottom;
+      contact_y = GetY() + m_height - m_test_bottom;
       return true;
     }
   }
 
   // We are looking for a point in contact on the left hand of object:
-  x1 = GetX()+m_test_left;
-  x2 = x1+1;
-  for(uint y=GetY()+m_test_top;y<=GetY()+m_height-m_test_bottom;y++)
+  x1 = GetX() + m_test_left;
+  x2 = x1 + 1;
+  for (int y = GetY() + m_test_top; y <= GetY() + m_height - m_test_bottom; y++)
   {
-    if(!world.IsOutsideWorld(Point2i(x1,y)) && !world.IsOutsideWorld(Point2i(x2,y))
-    && !world.ground.IsEmpty(Point2i(x1,y)) &&  world.ground.IsEmpty(Point2i(x2,y)))
+    if(!GetWorld().IsOutsideWorld(Point2i(x1,y)) && !GetWorld().IsOutsideWorld(Point2i(x2,y))
+    && !GetWorld().ground.IsEmpty(Point2i(x1,y)) &&  GetWorld().ground.IsEmpty(Point2i(x2,y)))
     {
-      contact_x = GetX() +m_test_left;
+      contact_x = GetX() + m_test_left;
       contact_y = y;
       return true;
     }
   }
 
   // We are looking for a point in contact on the rigth hand of object:
-  x1 = (GetX()+m_width-m_test_right);
-  x2 = x1-1;
-  for(uint y=GetY()+m_test_top;y<=GetY()+m_height-m_test_bottom;y++)
+  x1 = GetX() + m_width - m_test_right;
+  x2 = x1 - 1;
+  for (int y = GetY() + m_test_top; y <= GetY() + m_height - m_test_bottom; y++)
   {
-    if(!world.IsOutsideWorld(Point2i(x1, y)) && !world.IsOutsideWorld(Point2i(x2, y))
-       && !world.ground.IsEmpty(Point2i(x1, y)) && world.ground.IsEmpty(Point2i(x2, y)))
+    if(!GetWorld().IsOutsideWorld(Point2i(x1, y)) && !GetWorld().IsOutsideWorld(Point2i(x2, y))
+       && !GetWorld().ground.IsEmpty(Point2i(x1, y)) && GetWorld().ground.IsEmpty(Point2i(x2, y)))
     {
       contact_x = GetX() + m_width - m_test_right;
       contact_y = y;
@@ -771,15 +782,15 @@ bool PhysicalObj::ContactPoint (int & contact_x, int & contact_y) const
   }
 
   // We are looking for a point in contact on top of object:
-  y1 = GetY()+m_test_top;
+  y1 = GetY() + m_test_top;
   y2 = y1 - 1;
-  for(uint x=GetX()+m_test_left;x<=GetX()+m_width-m_test_right;x++)
+  for (int x = GetX() + m_test_left; x <= GetX() + m_width - m_test_right; x++)
   {
-    if(!world.IsOutsideWorld(Point2i(x,y1)) && !world.IsOutsideWorld(Point2i(x,y2))
-    && !world.ground.IsEmpty(Point2i(x, y1)) && world.ground.IsEmpty(Point2i(x, y2)))
+    if(!GetWorld().IsOutsideWorld(Point2i(x,y1)) && !GetWorld().IsOutsideWorld(Point2i(x,y2))
+    && !GetWorld().ground.IsEmpty(Point2i(x, y1)) && GetWorld().ground.IsEmpty(Point2i(x, y2)))
     {
-      contact_x =x;
-      contact_y = GetY() +m_test_top;
+      contact_x = x;
+      contact_y = GetY() + m_test_top;
       return true;
     }
   }
@@ -808,30 +819,34 @@ bool PhysicalObj::PutRandomly(bool on_top_of_world, double min_dst_with_characte
 
     if (on_top_of_world) {
       // Give a random position for x
-      if(net_sync)
-        position.x = RandomSync().GetLong(0, world.GetWidth() - GetWidth());
-      else
-        position.x = RandomLocal().GetLong(0, world.GetWidth() - GetWidth());
+      if(net_sync) {
+        MSG_DEBUG("random.get", "PhysicalObj::PutRandomly(...)");
+        position.x = RandomSync().GetLong(0, GetWorld().GetWidth() - GetWidth());
+      } else {
+        position.x = RandomLocal().GetLong(0, GetWorld().GetWidth() - GetWidth());
+      }
       position.y = -GetHeight()+1;
     } else {
-      if(net_sync)
-        position = RandomSync().GetPoint(world.GetSize() - GetSize() + 1);
-      else
-        position = RandomLocal().GetPoint(world.GetSize() - GetSize() + 1);
+      if(net_sync) {
+        MSG_DEBUG("random.get", "PhysicalObj::PutRandomly(...)");
+        position = RandomSync().GetPoint(GetWorld().GetSize() - GetSize() + 1);
+      } else {
+        position = RandomLocal().GetPoint(GetWorld().GetSize() - GetSize() + 1);
+      }
     }
     SetXY(position);
     MSG_DEBUG("physic.position", "%s (try %u/%u) - Test in %d, %d",
               m_name.c_str(), bcl, NB_MAX_TRY, position.x, position.y);
 
     // Check physical object is not in the ground
-    ok &= !IsGhost() && world.ParanoiacRectIsInVacuum(GetTestRect())  && IsInVacuum( Point2i(0, 1) );
+    ok &= !IsGhost() && GetWorld().ParanoiacRectIsInVacuum(GetTestRect())  && IsInVacuum( Point2i(0, 1) );
     if (!ok) {
       MSG_DEBUG("physic.position", "%s - Put it in the ground -> try again !", m_name.c_str());
       continue;
     }
 
     /* check if the area rigth under the object has a bottom on the ground */
-    ok &= !world.ParanoiacRectIsInVacuum(Rectanglei(GetCenter().x, position.y, 1, world.GetHeight() -
+    ok &= !GetWorld().ParanoiacRectIsInVacuum(Rectanglei(GetCenter().x, position.y, 1, GetWorld().GetHeight() -
              (WATER_INITIAL_HEIGHT + 30) - position.y));
     if (!ok) {
       MSG_DEBUG("physic.position", "%s - Put in outside the map or in water -> try again", m_name.c_str());
