@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #define PHYSICAL_OBJECT_H
 
 #include "physics.h"
-#include "tool/point.h"
-#include "tool/rectangle.h"
+#include <WORMUX_point.h>
+#include <WORMUX_rectangle.h>
 
 // Alive state
 typedef enum
@@ -54,28 +54,29 @@ class PhysicalObj : public Physics
 
 private:
   // collision management
-  bool m_goes_through_wall;
+  bool m_collides_with_ground;
   bool m_collides_with_characters;
   bool m_collides_with_objects;
   Point2i m_rebound_position;
 
+  // Rectangle used for collision tests
+  int m_test_left, m_test_right, m_test_top, m_test_bottom;
+
+  // Object size and position.
+  int m_width, m_height;
+
 protected:
   PhysicalObj* m_overlapping_object;
   uint m_minimum_overlapse_time;
   bool m_ignore_movements;
   bool m_is_character;
+  bool m_is_fire;
 
   virtual void CheckOverlapping();
 
   std::string m_name;
   std::string m_unique_id;
 
-  // Rectangle used for collision tests
-  uint m_test_left, m_test_right, m_test_top, m_test_bottom;
-
-  // Object size and position.
-  uint m_width, m_height;
-
   std::string m_rebound_sound;
 
   alive_t m_alive;
@@ -94,13 +95,15 @@ public:
   //-------- Set position and size -------
 
   // Set/Get position
-  void SetX (int x) { SetXY( Point2i(x, GetY()) ); };
-  void SetY (int y) { SetXY( Point2i(GetX(), y) ); };
+  void SetX(double x) { SetXY( Point2d(x, GetYdouble()) ); };
+  void SetY(double y) { SetXY( Point2d(GetXdouble(), y) ); };
   void SetXY(const Point2i &position);
   void SetXY(const Point2d &position);
   int GetX() const;
   int GetY() const;
-  const Point2i GetPosition() const { return Point2i(GetX(), GetY()); };
+  double GetXdouble() const;
+  double GetYdouble() const;
+  const Point2d GetPosition() const { return Point2d(GetXdouble(), GetYdouble()) ;};
 
   // Used to sync value across network
   virtual void GetValueFromAction(Action *);
@@ -116,10 +119,11 @@ public:
   void SetTestRect (uint left, uint right, uint top, uint bottom);
   const Rectanglei GetTestRect() const
   {
-    return Rectanglei(GetX()+m_test_left,
-                      GetY()+m_test_top,
-                      m_width-m_test_right-m_test_left,
-                      m_height-m_test_bottom-m_test_top);
+    int width = m_width - m_test_right - m_test_left;
+    int height = m_height - m_test_bottom - m_test_top;
+    width = (width == 0 ? 1 : width);
+    height = (height == 0 ? 1 : height);
+    return Rectanglei(GetX() + m_test_left, GetY() + m_test_top, width, height);
   }
   int GetTestWidth() const { return m_width -m_test_left -m_test_right; };
   int GetTestHeight() const { return m_height -m_test_top -m_test_bottom; };
@@ -134,7 +138,7 @@ public:
   int GetCenterY() const { return GetY() +m_test_top +GetTestHeight()/2; };
   const Point2i GetCenter() const { return Point2i(GetCenterX(), GetCenterY()); };
   const Rectanglei GetRect() const { return Rectanglei( GetX(), GetY(), m_width, m_height); };
-  bool GoesThroughWall() const { return m_goes_through_wall; }
+  bool CollidesWithGround() const { return m_collides_with_ground; }
   bool IsCharacter() const { return m_is_character; }
 
   //----------- Physics related function ----------
@@ -149,7 +153,7 @@ public:
                                          // and max_distance is max distance allowed when putting out
 
   // Collision management
-  void SetCollisionModel(bool goes_through_wall,
+  void SetCollisionModel(bool collides_with_ground,
                          bool collides_with_characters,
                          bool collides_with_objects);
   void SetOverlappingObject(PhysicalObj* obj, int timeout = 0);
@@ -165,8 +169,6 @@ public:
   bool FootsInVacuumXY(const Point2i & position) const;
   bool FootsInVacuum() const { return FootsInVacuumXY(GetPosition()); };
 
-  bool FootsOnFloor(int y) const;
-
   bool IsInWater() const;
 
   // The object is outside of the world
@@ -189,10 +191,12 @@ public:
   void Drown();
   void GoOutOfWater(); // usefull for supertux.
 
-  virtual bool IsImmobile() const { return m_ignore_movements ||(!IsMoving() && !FootsInVacuum())||(m_alive == GHOST); };
+  virtual bool IsImmobile() const { return IsSleeping() || m_ignore_movements ||(!IsMoving() && !FootsInVacuum())||(m_alive == GHOST); };
+
   bool IsGhost() const { return (m_alive == GHOST); };
   bool IsDrowned() const { return (m_alive == DROWNED); };
   bool IsDead() const { return (IsGhost() || IsDrowned() || (m_alive == DEAD)); };
+  bool IsFire() const { return m_is_fire; }
 
   // Are the two object in contact ? (uses test rectangles)
   bool Overlapse(const PhysicalObj &b) const { return GetTestRect().Intersect( b.GetTestRect() ); };
@@ -206,9 +210,10 @@ public:
 
 protected:
   virtual void SignalRebound();
-  virtual void SignalObjectCollision(PhysicalObj *, const Point2d& /* my_speed_before */) { };
   virtual void SignalGroundCollision(const Point2d& /* my_speed_before */) { };
-  virtual void SignalCollision(const Point2d& /* my_speed_before */) { };
+  virtual void SignalObjectCollision(const Point2d& /* my_speed_before */,
+				     PhysicalObj * /* collided/ing object */,
+				     const Point2d& /* object speed_before */) { };
   virtual void SignalOutOfMap() { };
 
 private:
