@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include "game/game_mode.h"
 #include "game/time.h"
 #include "map/wind.h"
-#include "tool/debug.h"
+#include <WORMUX_debug.h>
 #include "tool/isnan.h"
 #include "tool/math_tools.h"
 #include "include/action.h"
@@ -66,6 +66,15 @@ Physics::Physics ():
 //--                         Class Parameters SET/GET                      --//
 //---------------------------------------------------------------------------//
 
+void Physics::SetPhysXY(double x, double y)
+{
+  if (m_pos_x.x0 != x || m_pos_y.x0 != y) {
+    m_pos_x.x0 = x;
+    m_pos_y.x0 = y;
+    UpdateTimeOfLastMove();
+  }
+}
+
 // Set the air resist factor
 void Physics::SetSpeedXY (Point2d vector)
 {
@@ -77,8 +86,10 @@ void Physics::SetSpeedXY (Point2d vector)
   m_pos_y.x1 = vector.y ;
   // setting to FreeFall is done in StartMoving()
 
-  if (!was_moving && IsMoving())
+  if (!was_moving && IsMoving()) {
+    UpdateTimeOfLastMove();
     StartMoving();
+  }
 }
 
 void Physics::AddSpeedXY (Point2d vector)
@@ -91,8 +102,10 @@ void Physics::AddSpeedXY (Point2d vector)
   m_pos_y.x1 += vector.y ;
   // setting to FreeFall is done in StartMoving()
 
-  if (!was_moving && IsMoving())
+  if (!was_moving && IsMoving()) {
+    UpdateTimeOfLastMove();
     StartMoving();
+  }
 }
 
 void Physics::GetSpeed(double &norm, double &angle) const
@@ -175,6 +188,8 @@ void Physics::GetValueFromAction(Action *a)
   m_balancing_damping  = a->PopDouble();
   m_elasticity_off     = !!a->PopInt();
 
+  ASSERT(Time::GetInstance()->Read() >= m_last_move);
+
   MSG_DEBUG( "physic.sync", "%s now - x0:%f, x1:%f, x2:%f - y0:%f, y1:%f, y2:%f - extern_force: %f, %f",
 	     typeid(*this).name(),
              m_pos_x.x0, m_pos_x.x1, m_pos_x.x2,
@@ -186,6 +201,7 @@ void Physics::SetExternForceXY (const Point2d& vector)
 {
   bool was_moving = IsMoving();
 
+  UpdateTimeOfLastMove();
   MSG_DEBUG ("physic.physic", "EXTERN FORCE %s.", typeid(*this).name());
 
   m_extern_force.SetValues(vector);
@@ -207,6 +223,7 @@ void Physics::SetPhysFixationPointXY(double g_x, double g_y, double dx,
   m_fix_point_dxy.x = dx ;
   m_fix_point_dxy.y = dy ;
 
+  UpdateTimeOfLastMove();
   //  printf ("Fixation (%f,%f) dxy(%f,%f)\n",  g_x, g_y, dx, dy);
 
   fix_point_x = m_pos_x.x0 + dx ;
@@ -258,6 +275,8 @@ void Physics::UnsetPhysFixationPoint()
 
   SetSpeed(speed_norm, angle);
 
+  UpdateTimeOfLastMove();
+
   m_pos_x.x2 = 0 ;
   m_pos_y.x2 = 0 ;
 
@@ -290,7 +309,7 @@ void Physics::ChangePhysRopeSize(double dl)
 
 void Physics::StartMoving()
 {
-  m_last_move = Time::GetInstance()->Read();
+  UpdateTimeOfLastMove();
 
   if (m_motion_type == NoMotion)
     m_motion_type = FreeFall ;
@@ -300,12 +319,15 @@ void Physics::StartMoving()
 
 void Physics::StopMoving()
 {
+  if(!IsMoving()) return;
+
   if (IsMoving()) MSG_DEBUG ("physic.physic", "Stops moving: %s.", typeid(*this).name());
   // Always called by PhysicalObj::StopMoving
   m_pos_x.x1 = 0 ;
   m_pos_x.x2 = 0 ;
   m_pos_y.x1 = 0 ;
   m_pos_y.x2 = 0 ;
+  UpdateTimeOfLastMove();
   if (m_motion_type != Pendulum)
     m_motion_type = NoMotion ;
 
@@ -320,6 +342,23 @@ bool Physics::IsMoving() const
          m_motion_type != NoMotion;
 }
 
+bool Physics::IsSleeping() const
+{
+  // return true if not moving since 1 sec.
+  int delta = Time::GetInstance()->Read() - m_last_move;
+  if(delta > 400) {
+    MSG_DEBUG( "physic.sleep", "%s is sleeping since %d ms.", typeid(*this).name(), delta);
+    return true;
+  }
+  MSG_DEBUG( "physic.notsleeping", "%s is not sleeping.", typeid(*this).name());
+  return false;
+}
+
+void Physics::UpdateTimeOfLastMove()
+{
+  m_last_move = Time::GetInstance()->Read();
+}
+
 // Compute the next position of the object during a pendulum motion.
 void Physics::ComputePendulumNextXY (double delta_t)
 {
@@ -389,12 +428,15 @@ void Physics::ComputeFallNextXY (double delta_t)
 
   // Wind force
 
-  wind_force = wind.GetStrength() * m_wind_factor ;
+  wind_force = Wind::GetRef().GetStrength() * m_wind_factor ;
 
   // Air resistanceance factor
 
   GetSpeed(speed_norm, speed_angle);
 
+  if(!EqualsZero(speed_norm))
+    UpdateTimeOfLastMove();
+
   air_resistance_factor = AIR_RESISTANCE_FACTOR * m_air_resist_factor ;
 
   MSG_DEBUG( "physic.fall", "%s falls; mass %5f, weight %5f, wind %5f, air %5f, delta %f", typeid(*this).name(), m_mass, weight_force,wind_force, air_resistance_factor, delta_t);
@@ -438,8 +480,6 @@ Point2d Physics::ComputeNextXY(double delta_t){
   if (m_motion_type == Pendulum)
     ComputePendulumNextXY(delta_t);
 
-  m_last_move = Time::GetInstance()->Read() ;
-
   return Point2d(m_pos_x.x0, m_pos_y.x0);
 }
 
