@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class BodyMemberParticle : public Particle
 {
   double angle_rad;
  public:
-  BodyMemberParticle(const Sprite* spr, const Point2i& position);
+  BodyMemberParticle(const Sprite& spr, const Point2i& position);
  private:
   void Refresh();
 };
