@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@ const int BULLET_PARTICLE_FADE_TIME = 2000;
 BulletParticle::BulletParticle() :
   Particle("bullet_particle")
 {
-  SetCollisionModel(false, false, false);
-  m_rebound_sound = "weapon/grenade_bounce";
+  SetCollisionModel(true, false, false);
+  m_rebound_sound = "weapon/m16_cartridge";
   m_left_time_to_live = 1;
   start_to_fade = 0;
 
@@ -61,7 +61,7 @@ void BulletParticle::Refresh()
 void BulletParticle::SignalRebound()
 {
   PhysicalObj::SignalRebound();
-  //SetCollisionModel(true, false, false);
+  //SetCollisionModel(false, false, false);
   StopMoving();
   start_to_fade = Time::GetInstance()->Read();
 }
