@@ -1,7 +1,7 @@
 
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #include "particles/magic_star.h"
 #include "particles/particle.h"
-#include "tool/random.h"
+#include "network/randomsync.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
 
@@ -33,7 +33,8 @@ MagicStarParticle::MagicStarParticle() :
   m_left_time_to_live = m_initial_time_to_live;
   m_time_between_scale = 25;
 
-  uint color=randomObj.GetLong(0,2);
+  MSG_DEBUG("random.get", "MagicStarParticle::MagicStarParticle()");
+  uint color=RandomSync().GetLong(0,2);
   switch(color)
   {
     case 0 : image = ParticleEngine::GetSprite(MAGIC_STAR_R_spr); break;
