@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,13 +44,18 @@ typedef enum {
   particle_TELEPORT_MEMBER,
   particle_POLECAT_FART,
   particle_WATER,
-  particle_LAVA
+  particle_CLEARWATER,
+  particle_LAVA,
+  particle_RADIOACTIVE,
+  particle_DIRTYWATER,
+  particle_CHOCOLATEWATER,
 } particle_t;
 
 enum particle_spr
 {
   SMOKE_spr,
   EXPLOSION_SMOKE_spr,
+  EXPLOSION_BIG_SMOKE_spr,
   ILL_BUBBLE_spr,
   FIRE_spr,
   STAR_spr,
@@ -60,10 +65,14 @@ enum particle_spr
   MAGIC_STAR_B_spr,
   DARK_SMOKE_spr,
   POLECAT_FART_spr,
-  WATER_spr,
-  LAVA_spr
+  CLEARWATER_spr,
+  LAVA_spr,
+  RADIOACTIVE_spr,
+  DIRTYWATER_spr,
+  CHOCOLATEWATER_spr
 };
-const int particle_spr_nbr = LAVA_spr + 1;
+
+const int particle_spr_nbr = CHOCOLATEWATER_spr + 1;
 
 class Particle : public PhysicalObj
 {
