@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,16 +21,16 @@
 
 #include "particles/teleport_member.h"
 #include "particles/particle.h"
-#include "tool/random.h"
+#include "network/randomsync.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
 #include "map/camera.h"
 
-TeleportMemberParticle::TeleportMemberParticle(const Sprite* spr, const Point2i& position, const Point2i& dest, int direction) :
+TeleportMemberParticle::TeleportMemberParticle(const Sprite& spr, const Point2i& position, const Point2i& dest, int direction) :
   Particle("teleport_member_particle")
 {
-  SetCollisionModel(true, false, false);
-  image = new Sprite(spr->GetSurface());
+  SetCollisionModel(false, false, false);
+  image = new Sprite(spr.GetSurface());
 
   float scale_x, scale_y;
   image->GetScaleFactors(scale_x, scale_y);
@@ -46,9 +46,12 @@ TeleportMemberParticle::TeleportMemberParticle(const Sprite* spr, const Point2i&
   start = position;
   time = Time::GetInstance()->Read();
 
-  sin_x_max = randomObj.GetDouble(M_PI_4, 3.0 * M_PI_4);
-  sin_y_max = randomObj.GetDouble(M_PI_4, 3.0 * M_PI_4);
-  Camera::GetInstance()->FollowObject(this, true);
+  MSG_DEBUG("random.get", "TeleportMemberParticle::TeleportMemberParticle(...)");
+  sin_x_max = RandomSync().GetDouble(M_PI_4, 3.0 * M_PI_4);
+  MSG_DEBUG("random.get", "TeleportMemberParticle::TeleportMemberParticle(...)");
+  sin_y_max = RandomSync().GetDouble(M_PI_4, 3.0 * M_PI_4);
+
+  Camera::GetInstance()->FollowObject(this);
 }
 
 TeleportMemberParticle::~TeleportMemberParticle()
