@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ class TeleportMemberParticle : public Particle
   float sin_x_max;
   float sin_y_max;
  public:
-  TeleportMemberParticle(const Sprite* spr, const Point2i& position, const Point2i& dest, int direction);
+  TeleportMemberParticle(const Sprite& spr, const Point2i& position, const Point2i& dest, int direction);
   ~TeleportMemberParticle();
   void Refresh();
 };
