@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,21 +19,25 @@
  * Particle Engine
  *****************************************************************************/
 
-#include "particles/water_drop.h"
-#include "particles/particle.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
+#include "particles/water_drop.h"
+#include "particles/particle.h"
+#include "tool/resource_manager.h"
 
 const uint living_time = 5000;
 
 WaterParticle::WaterParticle() :
   Particle("water_particle")
 {
-  SetCollisionModel(true, false, false);
+  SetCollisionModel(false, false, false);
   m_left_time_to_live = 100;
   m_check_move_on_end_turn = false;
 
-  image = ParticleEngine::GetSprite(WATER_spr);
+  Profile *res = GetResourceManager().LoadXMLProfile( "weapons.xml", false);
+  image = GetResourceManager().LoadSprite(res, ActiveMap()->GetWaterType() + "_drop");
+  GetResourceManager().UnLoadXMLProfile(res);
+
   image->SetRotation_HotSpot(bottom_center);
   SetSize(image->GetSize());
 }
@@ -51,8 +55,8 @@ void WaterParticle::Refresh()
   if (image->GetSize().x != 0 && image->GetSize().y != 0)
   {
     int dx = (GetWidth() - image->GetWidth()) / 2;
-
-    SetTestRect(dx, dx-1, GetHeight() - 2,1);
+    int dy = std::max(0, GetHeight() - 2);
+    SetTestRect(dx, dx, dy, 1);
   }
 
   double angle = GetSpeedAngle();
@@ -78,6 +82,13 @@ void WaterParticle::SignalOutOfMap()
   m_left_time_to_live = 0;
 }
 
+ClearWaterParticle::ClearWaterParticle()
+{
+  // delete std water image
+  delete image;
+  image = ParticleEngine::GetSprite(CLEARWATER_spr);
+}
+
 LavaParticle::LavaParticle()
 {
   // delete std water image
@@ -89,5 +100,19 @@ RadioactiveParticle::RadioactiveParticle()
 {
   // delete std water image
   delete image;
-  image = ParticleEngine::GetSprite(LAVA_spr);
+  image = ParticleEngine::GetSprite(RADIOACTIVE_spr);
+}
+
+DirtyWaterParticle::DirtyWaterParticle()
+{
+  // delete std water image
+  delete image;
+  image = ParticleEngine::GetSprite(DIRTYWATER_spr);
+}
+
+ChocolateWaterParticle::ChocolateWaterParticle()
+{
+  // delete std water image
+  delete image;
+  image = ParticleEngine::GetSprite(CHOCOLATEWATER_spr);
 }
