@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,10 +25,11 @@
 #include <fstream>
 
 #include "game/config.h"
-#include "tool/debug.h"
-#include "tool/i18n.h"
-#include "tool/random.h"
-#include "tool/file_tools.h"
+#include "sound/sound_sample.h"
+#include <WORMUX_debug.h>
+
+#include <WORMUX_random.h>
+#include <WORMUX_file_tools.h>
 #include "tool/xml_document.h"
 
 JukeBox::JukeBox()
@@ -60,13 +61,12 @@ void JukeBox::Init()
   JukeBox::GetInstance()->ActiveEffects(Config::GetInstance()->GetSoundEffects());
   JukeBox::GetInstance()->SetFrequency(Config::GetInstance()->GetSoundFrequency());
 
+  if (m_init) return;
   if (!m_config.music && !m_config.effects) {
     End();
     return;
   }
 
-  if (m_init) return;
-
   Uint16 audio_format = MIX_DEFAULT_FORMAT;
 
   /* Initialize the SDL library */
@@ -94,7 +94,7 @@ void JukeBox::Init()
 
   m_init = true;
 
-  LoadXML("share");
+  LoadXML("default");
   LoadMusicXML();
 }
 
@@ -154,6 +154,9 @@ void JukeBox::ActiveMusic (bool on)
 
 void JukeBox::LoadMusicXML()
 {
+  if (!m_init) // the sound device has not be initialized (was busy?)
+    return;
+
   // is xml_file already loaded ?
   std::set<std::string>::iterator it_profile = m_profiles_loaded.find("music") ;
   if (it_profile !=  m_profiles_loaded.end())
@@ -177,7 +180,7 @@ void JukeBox::LoadMusicXML()
   if(!doc.Load(xml_filename))
     return;
 
-  xmlNodeArray nodes = XmlReader::GetNamedNeighbours(doc.GetRoot(), "music");
+  xmlNodeArray nodes = XmlReader::GetNamedChildren(doc.GetRoot(), "music");
   xmlNodeArray::const_iterator
     it = nodes.begin(),
     end = nodes.end();
@@ -277,9 +280,14 @@ bool JukeBox::PlayMusic(const std::string& type)
   if(it == playlist.end())
   {
     std::cerr << "[Music] Unable to find " << type << " profile" << std::endl;
-    return false;
+    if (type == "ingame"){
+      return false;
+    } else {
+      return PlayMusic("ingame");
+    }
   }
 
+
   MSG_DEBUG("jukebox", "Loading playlist %s", type.c_str());
 
   StopMusic();
@@ -291,7 +299,7 @@ bool JukeBox::PlayMusic(const std::string& type)
   int i, j = 0;
   do
   {
-    i = rand()%it->second.size();
+    i = RandomLocal().GetInt(0,it->second.size()-1);
     j++;
   } while(!PlayMusicSample(it->second.begin()+i) && j < 10); // After 10 times, we think there is a problem.
 
@@ -327,6 +335,9 @@ bool JukeBox::PlayMusicSample(const std::vector<std::string>::const_iterator& fi
 
 void JukeBox::LoadXML(const std::string& profile)
 {
+  if (!m_init) // the sound device has not be initialized (was busy?)
+    return;
+
   // is xml_file already loaded ?
   std::set<std::string>::iterator it_profile = m_profiles_loaded.find(profile);
   if (it_profile !=  m_profiles_loaded.end())
@@ -351,7 +362,7 @@ void JukeBox::LoadXML(const std::string& profile)
   if(!doc.Load(xml_filename))
     return;
 
-  xmlNodeArray nodes = XmlReader::GetNamedNeighbours(doc.GetRoot(), "sound");
+  xmlNodeArray nodes = XmlReader::GetNamedChildren(doc.GetRoot(), "sound");
   xmlNodeArray::const_iterator
     it = nodes.begin(),
     end = nodes.end();
@@ -359,25 +370,29 @@ void JukeBox::LoadXML(const std::string& profile)
   for (; it != end; ++it)
   {
     // reads XML
-    std::string sample="no_sample";
-    std::string file="no_file";
+    std::string sample = "no_sample";
+    std::string file   = "no_file";
+    double      level  = 1.0;
+
     XmlReader::ReadStringAttr(*it, "sample", sample);
     XmlReader::ReadStringAttr(*it, "file", file);
+    XmlReader::ReadDoubleAttr(*it, "level", level);
 
-    MSG_DEBUG("jukebox", "Load sound sample %s/%s: %s",
-              profile.c_str(), sample.c_str(), file.c_str());
+    MSG_DEBUG("jukebox", "Load sound sample %s/%s: %s (%.3f)",
+              profile.c_str(), sample.c_str(), file.c_str(), level);
 
     // Load sound
     std::string sample_filename = folder + file;
     if( !DoesFileExist(sample_filename) )
     {
-      std::cerr << "Sound error: File " << sample_filename.c_str()
-                << " does not exist !" << std::endl;
+      std::cerr << "Sound warning: File " << sample_filename.c_str()
+                << " does not exist! (probably not yet recorded)" << std::endl;
       continue;
     }
 
     // Inserting sound sample in list
-    m_soundsamples.insert(sound_sample(profile+"/"+sample, sample_filename));
+    sample_info inf = { sample_filename, level };
+    m_soundsamples.insert(sound_sample(profile+"/"+sample, inf));
 
     // Precache
     m_cache.Precache( sample_filename.c_str() );
@@ -390,7 +405,7 @@ void JukeBox::LoadXML(const std::string& profile)
 int JukeBox::Play (const std::string& category, const std::string& sample,
                    const int loop)
 {
-  if (!UseEffects()) return -1;
+  if (!UseEffects() || !m_init) return -1;
 
   uint nb_sons= m_soundsamples.count(category+"/"+sample);
   if (nb_sons)
@@ -402,7 +417,7 @@ int JukeBox::Play (const std::string& category, const std::string& sample,
     // Choose a random sound sample
     if (nb_sons > 1)
     {
-      uint selection = uint(randomObj.GetLong(0, nb_sons));
+      uint selection = uint(RandomLocal().GetLong(0, nb_sons));
       if (selection == nb_sons) --selection ;
 
       it = p.first ;
@@ -411,42 +426,44 @@ int JukeBox::Play (const std::string& category, const std::string& sample,
     }
 
     // Play the sound
-    Mix_Chunk * sampleChunk = m_cache.LoadSound( it->second.c_str() );
+    Mix_Chunk * sampleChunk = m_cache.LoadSound( it->second.filename.c_str() );
     MSG_DEBUG("jukebox.play", "Playing sample %s/%s",
               category.c_str(), sample.c_str());
 
-    return PlaySample(sampleChunk, loop);
+    return PlaySample(sampleChunk, it->second.level, loop);
   }
   else if (category != "default")
   {
     return Play("default", sample, loop) ; // try with default profile
   }
 
-  std::cerr << "Sound error: No sound found for sample" << category.c_str() 
+  std::cerr << "Sound error: No sound found for sample" << category.c_str()
             << "/" << sample.c_str() << std::endl;
   return -1;
 }
 
 int JukeBox::Stop (int channel) const
 {
-  if(!m_config.music && !m_config.effects) return 0;
+  if (!m_init) return 0;
+  if (!m_config.music && !m_config.effects) return 0;
   if (channel == -1) return 0;
   return Mix_HaltChannel(channel);
 }
 
 int JukeBox::StopAll() const
 {
+  if (!m_init) return 0;
   if (!m_config.music && !m_config.effects) return 0;
 
   // halt playback on all channels
   return Mix_HaltChannel(-1);
 }
 
-int JukeBox::PlaySample (Mix_Chunk * sample, int loop)
+int JukeBox::PlaySample (Mix_Chunk * sample, double level, int loop)
 {
   if (loop != -1) loop--;
 
-  Mix_VolumeChunk(sample, Config::GetInstance()->GetVolumeEffects());
+  Mix_VolumeChunk(sample, int(0.5+level*Config::GetInstance()->GetVolumeEffects()));
   int channel = Mix_PlayChannel(-1, sample, loop);
 
   if (channel == -1)
@@ -463,6 +480,7 @@ void JukeBox::EndChunk(int channel)
 {
   JukeBox *jukebox = JukeBox::GetInstance();
   Mix_Chunk* chk = jukebox->chunks[channel];
+  SoundSample::ChannelFinished(channel);
 
   if(!chk) return;
 
