@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,10 +35,9 @@
 #include "network/network.h"
 #include "sound/jukebox.h"
 #include "team/custom_team.h"
-#include "tool/debug.h"
-#include "tool/i18n.h"
-#include "tool/file_tools.h"
-#include "tool/point.h"
+#include <WORMUX_debug.h>
+#include <WORMUX_file_tools.h>
+#include <WORMUX_point.h>
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
 #include "weapon/weapons_list.h"
@@ -62,12 +61,12 @@ Team::Team (const std::string& teams_dir, const std::string& id)
     throw "Invalid file structure: cannot find a name for team ";
 
   // Load flag
-  Profile *res = resource_manager.LoadXMLProfile(nomfich, true);
-  flag = resource_manager.LoadImage(res, "flag");
+  Profile *res = GetResourceManager().LoadXMLProfile(nomfich, true);
+  flag = GetResourceManager().LoadImage(res, "flag");
   mini_flag = flag.RotoZoom(0.0, 0.5, 0.5, true);
-  death_flag = resource_manager.LoadImage(res, "death_flag");
-  big_flag = resource_manager.LoadImage(res, "big_flag");
-  resource_manager.UnLoadXMLProfile(res);
+  death_flag = GetResourceManager().LoadImage(res, "death_flag");
+  big_flag = GetResourceManager().LoadImage(res, "big_flag");
+  GetResourceManager().UnLoadXMLProfile(res);
 
   // Get sound profile
   if (!XmlReader::ReadString(doc.GetRoot(), "sound_profile", m_sound_profile))
@@ -75,8 +74,8 @@ Team::Team (const std::string& teams_dir, const std::string& id)
 
   active_character = characters.end();
 
-  is_camera_saved = false;
   active_weapon = NULL;
+  attached_custom_team = NULL;
 
   m_player_name = "";
 
@@ -112,7 +111,7 @@ bool Team::LoadCharacters()
     XmlReader::ReadStringAttr(*it, "name", character_name);
     XmlReader::ReadStringAttr(*it, "body", body_name);
 
-    if (!(body = body_list.GetBody(body_name)) )
+    if (!(body = BodyList::GetRef().GetBody(body_name)) )
     {
       std::cerr
           << Format(_("Error: can't find the body \"%s\" for the team \"%s\"."),
@@ -130,10 +129,10 @@ bool Team::LoadCharacters()
     }
     characters.push_back(new_character);
     active_character = characters.begin(); // we need active_character to be initialized here !!
-    if (!characters.back().PutRandomly(false, world.GetDistanceBetweenCharacters()))
+    if (!characters.back().PutRandomly(false, GetWorld().GetDistanceBetweenCharacters()))
     {
       // We haven't found any place to put the characters!!
-      if (!characters.back().PutRandomly(false, world.GetDistanceBetweenCharacters() / 2)) {
+      if (!characters.back().PutRandomly(false, GetWorld().GetDistanceBetweenCharacters() / 2)) {
         std::cerr << std::endl;
         std::cerr << "Error: player " << character_name.c_str() << " will be probably misplaced!" << std::endl;
         std::cerr << std::endl;
@@ -198,21 +197,27 @@ void Team::SelectCharacter(const Character * c)
   ActiveCharacter().StartPlaying();
 }
 
-void Team::NextCharacter()
+void Team::NextCharacter(bool newturn)
 {
   ASSERT (0 < NbAliveCharacter());
+
   ActiveCharacter().StopPlaying();
-  do
-  {
-    ++active_character;
-    if (active_character == characters.end())
-      active_character = characters.begin();
-  } while (ActiveCharacter().IsDead());
+
+  // we change character:
+  // - if user asked so
+  // - if it's a new turn and game mode requests a change of character
+  if (!newturn || GameMode::GetInstance()->auto_change_character) {
+
+    do {
+      ++active_character;
+      if (active_character == characters.end())
+	active_character = characters.begin();
+    } while (ActiveCharacter().IsDead());
+  }
   ActiveCharacter().StartPlaying();
 
-  if (is_camera_saved) Camera::GetInstance()->SetXYabs (sauve_camera.x, sauve_camera.y);
-  Camera::GetInstance()->FollowObject (&ActiveCharacter(),
-                          !is_camera_saved);
+  Camera::GetInstance()->CenterOnActiveCharacter();
+
   MSG_DEBUG("team", "%s (%d, %d)is now the active character",
             ActiveCharacter().GetName().c_str(),
             ActiveCharacter().GetX(),
@@ -229,11 +234,10 @@ void Team::PreviousCharacter()
       active_character = characters.end();
     --active_character;
   } while (ActiveCharacter().IsDead());
+
   ActiveCharacter().StartPlaying();
 
-  if (is_camera_saved) Camera::GetInstance()->SetXYabs (sauve_camera.x, sauve_camera.y);
-  Camera::GetInstance()->FollowObject (&ActiveCharacter(),
-                          !is_camera_saved);
+  Camera::GetInstance()->FollowObject(&ActiveCharacter());
   MSG_DEBUG("team", "%s (%d, %d)is now the active character",
             ActiveCharacter().GetName().c_str(),
             ActiveCharacter().GetX(),
@@ -257,15 +261,11 @@ void Team::PrepareTurn()
   current_turn++;
 
   // Get a living character if possible
-  if (ActiveCharacter().IsDead())
-  {
-    is_camera_saved = false;
+  if (ActiveCharacter().IsDead()) {
     NextCharacter();
   }
 
-  if (is_camera_saved) Camera::GetInstance()->SetXYabs (sauve_camera.x, sauve_camera.y);
-  Camera::GetInstance()->FollowObject (&ActiveCharacter(),
-                          !is_camera_saved);
+  Camera::GetInstance()->FollowObject(&ActiveCharacter(),true);
   CharacterCursor::GetInstance()->FollowActiveCharacter();
 
   // Updating weapon ammos (some weapons are not available from the beginning)
@@ -290,7 +290,7 @@ void Team::PrepareTurn()
 
   // Sound the bell, so the local players know when it is their turn
   if (IsLocal())
-    JukeBox::GetInstance()->Play("share", "start_turn");
+    JukeBox::GetInstance()->Play("default", "start_turn");
 }
 
 Character& Team::ActiveCharacter() const
@@ -395,7 +395,6 @@ void Team::LoadGamingData()
   }
 
   active_weapon = WeaponsList::GetInstance()->GetWeapon(Weapon::WEAPON_DYNAMITE);
-  is_camera_saved = false;
 
   LoadCharacters();
 }
