@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "weapon/weapon.h"
 
 class Character;
+class CustomTeam;
 
 typedef enum {
   TEAM_human_local,
@@ -55,7 +56,6 @@ class Team
 
     // Autres
     CrossHair        crosshair;
-    Point2i          sauve_camera;
     TeamEnergy       energy;
 
 
@@ -64,7 +64,6 @@ class Team
     Surface flag;
     Surface death_flag;
     Surface big_flag;
-    bool is_camera_saved;
     std::string m_teams_dir; // parent directory hosting the data
     std::string m_id;
     std::string m_name;
@@ -74,6 +73,9 @@ class Team
     iterator active_character;
     Weapon *active_weapon;
     uint nb_characters;
+    uint current_turn;
+
+    CustomTeam *attached_custom_team;
 
     team_player_type_t type_of_player;
 
@@ -97,7 +99,7 @@ class Team
     uint GetNbCharacters() const { return nb_characters; }
 
   // Switch to next worm.
-    void NextCharacter();
+    void NextCharacter(bool new_turn = false);
     void PreviousCharacter();
     void SelectCharacter(const Character * c);
 
@@ -165,12 +167,19 @@ class Team
   // true if the team belong to a local AI
     bool IsLocalAI() const { return (type_of_player == TEAM_ai_local); };
 
+    bool IsRemote() const { return (type_of_player == TEAM_remote); };
+
     bool IsActiveTeam() const;
 
     void SetLocal() { type_of_player = TEAM_human_local; };
     void SetLocalAI() { type_of_player = TEAM_ai_local; };
     void SetRemote() { type_of_player = TEAM_remote; };
 
+  // reset characters number, type_of_player and player name
+    void SetDefaultPlayingConfig();
+
+  // Custom team
+    void AttachCustomTeam(CustomTeam*);
 };
 
 #endif /* TEAM_H */
