@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,22 +18,19 @@
  ******************************************************************************
  * Team handling
  *****************************************************************************/
-
-#include "team/team.h"
-#include "team/team_config.h"
-#include "team/teams_list.h"
-//-----------------------------------------------------------------------------
+#include <algorithm>
+#include <iostream>
+#include <WORMUX_team_config.h>
 #include "character/character.h"
 #include "character/body_list.h"
 #include "include/action.h"
 #include "game/config.h"
 #include "network/network.h"
-#include "tool/file_tools.h"
-#include "tool/i18n.h"
-#include "team/team_energy.h"
-#include <algorithm>
-#include <iostream>
 #include "network/randomsync.h"
+#include "team/team.h"
+#include "team/team_energy.h"
+#include "team/teams_list.h"
+#include <WORMUX_file_tools.h>
 
 //-----------------------------------------------------------------------------
 //-----------------------------------------------------------------------------
@@ -49,34 +46,31 @@ TeamsList::TeamsList():
 
 TeamsList::~TeamsList()
 {
-  /* The teamslist was never built... nothing to delete.
-   * FIXME This is needed because we are lead to delete things even if they
-   * were not created completely. IMHO, this reflects the fact that the object
-   * life time is not well known...
-   * Actually, this is not that bad whereas free(NULL) is accepted... but it
-   * remains spurious. */
-  if (!singleton)
-  {
-    fprintf(stderr, "Destructor still called on unexisting TeamsList\n");
-    return;
-  }
-
   UnloadGamingData();
   Clear();
   for(full_iterator it = full_list.begin(); it != full_list.end(); ++it)
     delete (*it);
   full_list.clear();
-  singleton = NULL;
 }
 
 //-----------------------------------------------------------------------------
 
 void TeamsList::NextTeam ()
 {
+  ActiveCharacter().StopPlaying();
+
   Team* next = GetNextTeam();
-  GetTeamsList().SetActive (next->GetId());
+  SetActive(next->GetId());
+
+  ActiveTeam().NextCharacter(true);
+
   Action a(Action::ACTION_GAMELOOP_NEXT_TEAM, next->GetId());
-  Network::GetInstance()->SendAction(a);
+  Character::StoreActiveCharacter(&a);
+  Network::GetInstance()->SendActionToAll(a);
+
+  printf("\nPlaying character : %i %s\n", ActiveCharacter().GetCharacterIndex(), ActiveCharacter().GetName().c_str());
+  printf("Playing team : %i %s\n", ActiveCharacter().GetTeamIndex(), ActiveTeam().GetName().c_str());
+  printf("Alive characters: %i / %i\n\n",ActiveTeam().NbAliveCharacter(),ActiveTeam().GetNbCharacters());
 }
 
 //-----------------------------------------------------------------------------
@@ -110,7 +104,7 @@ void TeamsList::LoadOneTeam(const std::string &dir, const std::string &team_name
   if (team_name[0] == '.') return;
 
   // Is it a directory ?
-  if (!IsFolderExist(dir+team_name)) return;
+  if (!DoesFolderExist(dir+team_name)) return;
 
   // Add the team
   try {
@@ -165,7 +159,7 @@ void TeamsList::LoadList()
 
   // We need at least 2 teams
   if (full_list.size() < 2)
-    Error(_("You need at least two valid teams !"));
+    Error(_("You need at least two valid teams!"));
 
   // Default selection
   std::list<uint> nv_selection;
@@ -200,6 +194,7 @@ void TeamsList::LoadGamingData()
 void TeamsList::RandomizeFirstPlayer()
 {
   active_team = playing_list.begin();
+  MSG_DEBUG("random.get", "TeamList::RandomizeFirstPlayer()");
   int skip = RandomSync().GetLong(0, playing_list.size() - 1);
   for(int i = 0; i < skip; i++)
     active_team++;
@@ -209,7 +204,7 @@ void TeamsList::RandomizeFirstPlayer()
 
 void TeamsList::UnloadGamingData()
 {
-  body_list.FreeMem();
+  BodyList::GetRef().FreeMem();
   iterator it=playing_list.begin(), end = playing_list.end();
 
   // Unload the data of all teams
@@ -486,6 +481,8 @@ void TeamsList::AddTeam(Team* the_team, int pos, const ConfigTeam &the_team_cfg,
 void TeamsList::AddTeam(const ConfigTeam &the_team_cfg, bool is_local,
 			bool generate_error)
 {
+  MSG_DEBUG("team", "%s, local: %d\n", the_team_cfg.id.c_str(), is_local);
+
   int pos;
   Team *the_team = FindById (the_team_cfg.id, pos);
   if (the_team != NULL) {
@@ -517,6 +514,8 @@ void TeamsList::UpdateTeam (const std::string& old_team_id,
 {
   int pos;
 
+  MSG_DEBUG("team", "%s/%s\n", old_team_id.c_str(), the_team_cfg.id.c_str());
+
   if (old_team_id == the_team_cfg.id) {
     // this is a simple update
 
@@ -558,6 +557,8 @@ void TeamsList::DelTeam(Team* the_team)
 
   ASSERT(the_team != NULL);
 
+  MSG_DEBUG("team", "%s\n", the_team->GetId().c_str());
+
   the_team->SetDefaultPlayingConfig();
 
   selection_iterator it = find(selection.begin(), selection.end(), pos);
@@ -606,25 +607,6 @@ void TeamsList::SetActive(const std::string &id)
 
 //-----------------------------------------------------------------------------
 
-std::string TeamsList::GetLocalHeadCommanders() const
-{
-  std::string nickname;
-
-  for (std::vector<Team*>::iterator it = GetTeamsList().playing_list.begin();
-       it != GetTeamsList().playing_list.end();
-       it++) {
-    if ((*it)->IsLocal()) {
-      if (nickname != "") nickname += "+";
-
-      nickname += (*it)->GetPlayerName();
-    }
-  }
-
-  return nickname;
-}
-
-//-----------------------------------------------------------------------------
-
 Team& ActiveTeam()
 {
   return GetTeamsList().ActiveTeam();
