@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "tool/resource_manager.h"
 #include <string>
 #include <iostream>
-#include "tool/error.h"
+
 #include "tool/xml_document.h"
 #include "tool/string_tools.h"
 #include "game/config.h"
@@ -47,7 +47,12 @@ Profile::~Profile()
   if (doc != NULL) delete doc;
 }
 
-ResourceManager::ResourceManager()
+ResourceManager& GetResourceManager()
+{
+  return ResourceManager::GetRef();
+}
+
+ResourceManager::ResourceManager() : base_path("")
 {
 }
 
@@ -55,7 +60,7 @@ ResourceManager::~ResourceManager()
 {
 }
 
-void ResourceManager::AddDataPath(const std::string& base_path)
+void ResourceManager::SetDataPath(const std::string& base_path)
 {
   this->base_path = base_path;
 }
@@ -63,7 +68,7 @@ void ResourceManager::AddDataPath(const std::string& base_path)
 int ResourceManager::LoadInt(const Profile *profile, const std::string& resource_name) const
 {
   int tmp = 0;
-  xmlNode* elem = GetElement(profile, "int", resource_name);
+  const xmlNode* elem = GetElement(profile, "int", resource_name);
   if (elem == NULL)
     Error("ResourceManager: can't find int resource \""+resource_name+"\" in profile "+profile->filename);
   if (!profile->doc->ReadIntAttr(elem, "value", tmp))
@@ -74,7 +79,7 @@ int ResourceManager::LoadInt(const Profile *profile, const std::string& resource
 double ResourceManager::LoadDouble(const Profile *profile, const std::string& resource_name) const
 {
   double tmp = 0.0;
-  xmlNode* elem = GetElement(profile, "double", resource_name);
+  const xmlNode* elem = GetElement(profile, "double", resource_name);
   if (elem == NULL)
     Error("ResourceManager: can't find double resource \""+resource_name+"\" in profile "+profile->filename);
   if (!profile->doc->ReadDoubleAttr(elem, "value", tmp))
@@ -84,7 +89,7 @@ double ResourceManager::LoadDouble(const Profile *profile, const std::string& re
 
 Color ResourceManager::LoadColor(const Profile *profile, const std::string& resource_name) const
 {
-  xmlNode* elem = GetElement(profile, "color", resource_name);
+  const xmlNode* elem = GetElement(profile, "color", resource_name);
   if ( elem == NULL)
     Error("ResourceManager: can't find color resource \""+resource_name+"\" in profile "+profile->filename);
 
@@ -99,7 +104,7 @@ Color ResourceManager::LoadColor(const Profile *profile, const std::string& reso
 
 Point2i ResourceManager::LoadPoint2i(const Profile *profile, const std::string& resource_name) const
 {
-  xmlNode* elem = GetElement(profile, "point", resource_name);
+  const xmlNode* elem = GetElement(profile, "point", resource_name);
   if ( elem == NULL)
     Error("ResourceManager: can't find point resource \""+resource_name+"\" in profile "+profile->filename);
 
@@ -114,7 +119,7 @@ Point2i ResourceManager::LoadPoint2i(const Profile *profile, const std::string&
 
 Point2d ResourceManager::LoadPoint2d(const Profile *profile, const std::string& resource_name) const
 {
-  xmlNode* elem = GetElement(profile, "point", resource_name);
+  const xmlNode* elem = GetElement(profile, "point", resource_name);
   if ( elem == NULL)
     Error("ResourceManager: can't find point resource \""+resource_name+"\" in profile "+profile->filename);
 
@@ -130,7 +135,7 @@ Point2d ResourceManager::LoadPoint2d(const Profile *profile, const std::string&
 MouseCursor ResourceManager::LoadMouseCursor(const Profile *profile, const std::string& resource_name,
 					     Mouse::pointer_t _pointer_id) const
 {
-  xmlNode* elem = GetElement ( profile, "mouse_cursor", resource_name);
+  const xmlNode* elem = GetElement ( profile, "mouse_cursor", resource_name);
   if(elem == NULL)
     Error("ResourceManager: can't find mouse cursor resource \""+resource_name+"\" in profile "+profile->filename);
 
@@ -200,19 +205,20 @@ void ResourceManager::UnLoadXMLProfile( Profile *profile) const
    delete profile;
 }
 
-xmlNode*  ResourceManager::GetElement( const Profile *profile, const std::string& resource_type, const std::string& resource_name) const
+const xmlNode*  ResourceManager::GetElement( const Profile *profile, const std::string& resource_type,
+					     const std::string& resource_name) const
 {
-  xmlNode* elem = profile->doc->Access(profile->doc->GetRoot(), resource_type, resource_name);
+  const xmlNode* elem = profile->doc->Access(profile->doc->GetRoot(), resource_type, resource_name);
 
-  if(elem == NULL) {
+  if (elem == NULL) {
     std::string r_name = resource_name;
-    xmlNode* cur_elem = profile->doc->GetRoot();
+    const xmlNode* cur_elem = profile->doc->GetRoot();
 
     while((r_name.find("/") != r_name.npos) && (cur_elem != NULL)) {
       cur_elem = profile->doc->Access(cur_elem, "section", r_name.substr(0, r_name.find("/")));
       r_name = r_name.substr( r_name.find("/") + 1, r_name.length());
     }
-    if(cur_elem)
+    if (cur_elem)
       elem = profile->doc->Access(cur_elem, resource_type, r_name);
   }
   return elem;
@@ -220,7 +226,7 @@ xmlNode*  ResourceManager::GetElement( const Profile *profile, const std::string
 
 Surface ResourceManager::LoadImage( const Profile *profile, const std::string& resource_name) const
 {
-  xmlNode* elem = GetElement ( profile, "surface", resource_name);
+  const xmlNode* elem = GetElement ( profile, "surface", resource_name);
   if(elem == NULL)
     Error("ResourceManager: can't find image resource \""+resource_name+"\" in profile "+profile->filename);
 
@@ -238,17 +244,23 @@ Surface ResourceManager::LoadImage( const Profile *profile, const std::string& r
 
 Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& resource_name) const
 {
-  xmlNode* elem_sprite = GetElement(profile, "sprite", resource_name);
-  if(elem_sprite == NULL)
-    Error("ResourceManager: can't find sprite resource \""+resource_name+"\" in profile "+profile->filename);;
+  const xmlNode* elem_sprite = GetElement(profile, "sprite", resource_name);
+  if (elem_sprite == NULL)
+    Error("ResourceManager: can't find sprite resource \""+resource_name+"\" in profile "+profile->filename);
 
-  xmlNode* elem_image = profile->doc->GetMarker(elem_sprite, "image");
+  return LoadSprite(elem_sprite, resource_name, profile->relative_path);
+}
+
+Sprite *ResourceManager::LoadSprite(const xmlNode* elem_sprite, const std::string& resource_name,
+				    const std::string& main_folder) const
+{
+  const xmlNode* elem_image = XmlReader::GetMarker(elem_sprite, "image");
 
   if(elem_image == NULL)
     Error("ResourceManager: can't load (sprite) resource " + resource_name);
 
   std::string image_filename;
-  if (!profile->doc->ReadStringAttr(elem_image, "file", image_filename) )
+  if (!XmlReader::ReadStringAttr(elem_image, "file", image_filename) )
     Error("ResourceManager: can't load (sprite) resource " + resource_name);
 
   // TODO load more properties in xml : alpha, colorkey....
@@ -257,12 +269,12 @@ Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& r
   bool alpha = true;
   Sprite *sprite = NULL;
 
-  xmlNode* elem_grid = profile->doc->GetMarker(elem_image, "grid");
+  const xmlNode* elem_grid = XmlReader::GetMarker(elem_image, "grid");
 
   if ( elem_grid == NULL ) {
     ASSERT(resource_name != "barrel");
     // No grid element, Load the Sprite like a normal image
-    Surface surface = LoadImage(profile->relative_path+image_filename, alpha);
+    Surface surface = LoadImage(main_folder+image_filename, alpha);
     sprite = new Sprite();
     sprite->Init(surface, surface.GetSize(), 1, 1);
   } else {
@@ -271,7 +283,7 @@ Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& r
     int nb_frames_y = 0;
     std::string size;
 
-    if(!profile->doc->ReadStringAttr(elem_grid, "size", size))
+    if(!XmlReader::ReadStringAttr(elem_grid, "size", size))
       Error("ResourceManager: can't load sprite resource \""+resource_name+"\" has no attribute size");
 
     if(size.find(",") != size.npos) {
@@ -281,7 +293,7 @@ Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& r
       Error("ResourceManager: can't load sprite resource \""+resource_name+"\" has malformed size attribute");
 
     std::string array;
-    if(!profile->doc->ReadStringAttr( elem_grid, "array", array))
+    if(!XmlReader::ReadStringAttr( elem_grid, "array", array))
       Error("ResourceManager: can't load sprite resource \""+resource_name+"\" has no attribute array");
 
     if(array.find(",") != array.npos) {
@@ -294,21 +306,21 @@ Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& r
     } else
       Error("ResourceManager: can't load (sprite) resource "+resource_name);
 
-    Surface surface = LoadImage(profile->relative_path+image_filename, alpha);
+    Surface surface = LoadImage(main_folder+image_filename, alpha);
     sprite = new Sprite();
     sprite->Init(surface, frameSize, nb_frames_x, nb_frames_y);
   }
 
   ASSERT(sprite != NULL);
 
-  xmlNode* elem = profile->doc->GetMarker(elem_sprite, "animation");
+  const xmlNode* elem = XmlReader::GetMarker(elem_sprite, "animation");
   if ( elem != NULL ) {
     std::string str;
     // Set the frame speed
-    if(profile->doc->ReadStringAttr(elem, "speed", str))
+    if(XmlReader::ReadStringAttr(elem, "speed", str))
       sprite->SetFrameSpeed(atoi(str.c_str()));
 
-    if(profile->doc->ReadStringAttr(elem, "loop_mode", str)) {
+    if(XmlReader::ReadStringAttr(elem, "loop_mode", str)) {
       bool loop_value;
       if(str2bool(str, loop_value))
         sprite->animation.SetLoopMode(loop_value);
@@ -318,6 +330,18 @@ Sprite *ResourceManager::LoadSprite(const Profile *profile, const std::string& r
       else
         std::cerr << "Unrecognized xml option loop_mode=\"" << str << "\" in resource " << resource_name;
     }
+
+    if(XmlReader::ReadStringAttr(elem, "loop_wait", str))
+    {
+        sprite->animation.SetLoopWait(atoi(str.c_str()));
+    }
+
+    if(XmlReader::ReadStringAttr(elem, "loop_wait_random", str))
+    {
+        sprite->animation.SetLoopWaitRandom(atoi(str.c_str()));
+    }
+
+
   }
   return sprite;
 }
@@ -330,7 +354,6 @@ Surface ResourceManager::GenerateMap(Profile *profile, InfoMap::Island_type gene
   return random_map.GetRandomMap();
 }
 
-ResourceManager resource_manager;
 
 
 
