@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "team/teams_list.h"
 #include "team/macro.h"
 #include "team/team.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
 
@@ -63,7 +62,7 @@ Airhammer::Airhammer() : Weapon(WEAPON_AIR_HAMMER,"airhammer",new AirhammerConfi
 
   m_category = TOOL;
 
-  impact = resource_manager.LoadImage( weapons_res_profile, "airhammer_impact");
+  impact = GetResourceManager().LoadImage( weapons_res_profile, "airhammer_impact");
   m_time_between_each_shot = MIN_TIME_BETWEEN_JOLT;
 }
 
@@ -72,7 +71,7 @@ Airhammer::Airhammer() : Weapon(WEAPON_AIR_HAMMER,"airhammer",new AirhammerConfi
 void Airhammer::UpdateTranslationStrings()
 {
   m_name = _("Airhammer");
-  m_help = _("Howto use it : keep space key pressed\nan ammo per turn");
+  m_help = _("How to use it : keep the space key pressed\nan ammo per turn");
 }
 
 //-----------------------------------------------------------------------------
@@ -82,7 +81,7 @@ bool Airhammer::p_Shoot()
   //if the sound isn't already playing, play it again.
   select_sound.Stop();
   if (!drill_sound.IsPlaying()) {
-    drill_sound.Play("share","weapon/airhammer", -1);
+    drill_sound.Play("default","weapon/airhammer", -1);
   }
 
   // initiate movement ;-)
@@ -96,7 +95,7 @@ bool Airhammer::p_Shoot()
                          true, -3.0 * M_PI_4, 5.0 + Time::GetInstance()->Read() % 5);
   ParticleEngine::AddNow(pos + Point2i(3*impact.GetWidth()/4,9), 1, particle_AIR_HAMMER,
                          true, -M_PI_4, 5.0 + Time::GetInstance()->Read() % 5);
-  world.Dig( pos, impact );
+  GetWorld().Dig( pos, impact );
 
   uint range = 0;
   int x,y; // Testing coordinates
@@ -163,7 +162,7 @@ bool Airhammer::IsInUse() const
 
 void Airhammer::p_Select()
 {
-  select_sound.Play("share","weapon/airhammer_select",-1);
+  select_sound.Play("default","weapon/airhammer_select",-1);
 }
 
 std::string Airhammer::GetWeaponWinString(const char *TeamName, uint items_count ) const
