@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,11 +19,8 @@
  * Anvil : appear in top of an enemy and crush down his head
  *****************************************************************************/
 
-#include "weapon/weapon_cfg.h"
-#include "weapon/anvil.h"
-#include "weapon/explosion.h"
-//-----------------------------------------------------------------------------
 #include <sstream>
+
 #include "character/character.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
@@ -32,11 +29,15 @@
 #include "interface/mouse.h"
 #include "map/camera.h"
 #include "map/map.h"
+#include "network/network.h"
 #include "object/objects_list.h"
 #include "sound/jukebox.h"
 #include "team/teams_list.h"
-#include "tool/i18n.h"
 #include "tool/math_tools.h"
+#include "weapon/weapon_cfg.h"
+#include "weapon/anvil.h"
+#include "weapon/explosion.h"
+
 //-----------------------------------------------------------------------------
 
 class Anvil : public WeaponProjectile
@@ -54,8 +55,10 @@ class Anvil : public WeaponProjectile
     void PlayCollisionSound();
     void SetEnergyDelta(int /*delta*/, bool /*do_report = true*/) { };
   protected:
-    virtual void SignalObjectCollision(PhysicalObj * obj);
     virtual void SignalGroundCollision(const Point2d& /* speed_before */);
+    virtual void SignalObjectCollision(const Point2d& /* my_speed_before */,
+				       PhysicalObj * obj,
+				       const Point2d& /* obj_speed_before */);
     virtual void SignalOutOfMap();
 };
 
@@ -74,17 +77,23 @@ Anvil::~Anvil()
   falling_sound.Stop(); // paranoiac sound stop
 }
 
-void Anvil::SignalObjectCollision(PhysicalObj * obj)
+void Anvil::SignalObjectCollision(const Point2d& /* my_speed_before */,
+				  PhysicalObj * obj,
+				  const Point2d& /* obj_speed_before */)
 {
   merge_time = Time::GetInstance()->Read() + 5000;
   obj->SetEnergyDelta(-200);
   PlayCollisionSound();
+
+  WeaponProjectile::Collision();
 }
 
 void Anvil::SignalGroundCollision(const Point2d& /* speed_before */)
 {
   merge_time = Time::GetInstance()->Read() + 5000;
   PlayCollisionSound();
+
+  WeaponProjectile::Collision();
 }
 
 void Anvil::SignalOutOfMap()
@@ -95,7 +104,7 @@ void Anvil::SignalOutOfMap()
 void Anvil::Refresh()
 {
   if(merge_time != 0 && merge_time < Time::GetInstance()->Read()) {
-    world.MergeSprite(GetPosition(), image);
+    GetWorld().MergeSprite(GetPosition(), image);
     Ghost();
   } else {
     WeaponProjectile::Refresh();
@@ -104,13 +113,13 @@ void Anvil::Refresh()
 
 void Anvil::PlayFallSound()
 {
-  falling_sound.Play("share", "weapon/anvil_fall", -1);
+  falling_sound.Play("default", "weapon/anvil_fall", -1);
 }
 
 void Anvil::PlayCollisionSound()
 {
   falling_sound.Stop();
-  JukeBox::GetInstance()->Play("share", "weapon/anvil_collision");
+  JukeBox::GetInstance()->Play("default", "weapon/anvil_collision");
 }
 
 //-----------------------------------------------------------------------------
@@ -130,7 +139,7 @@ AnvilLauncher::AnvilLauncher() :
 void AnvilLauncher::UpdateTranslationStrings()
 {
   m_name = _("Anvil");
-  m_help = _("Howto use it : left click on target\nan ammo per turn");
+  m_help = _("How to use it : left click on the target\nan ammo per turn");
 }
 
 void AnvilLauncher::ChooseTarget(Point2i mouse_pos)
@@ -138,7 +147,7 @@ void AnvilLauncher::ChooseTarget(Point2i mouse_pos)
   target.x = mouse_pos.x - (projectile->GetWidth() / 2);
   target.y = 0 - projectile->GetHeight();
 
-  if (!world.ParanoiacRectIsInVacuum(Rectanglei(target, projectile->GetSize())) ||
+  if (!GetWorld().ParanoiacRectIsInVacuum(Rectanglei(target, projectile->GetSize())) ||
      !projectile->IsInVacuumXY(target))
     return;
 
@@ -153,13 +162,14 @@ bool AnvilLauncher::p_Shoot ()
 
   projectile->SetXY(target);
   ((Anvil*)projectile)->PlayFallSound();
-  lst_objects.AddObject(projectile);
-  Camera::GetInstance()->FollowObject(projectile, true);
+  ObjectsList::GetRef().AddObject(projectile);
+  Camera::GetInstance()->FollowObject(projectile);
   projectile = NULL;
   ReloadLauncher();
 
   // Go back to default cursor
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
+  if (Network::GetInstance()->IsTurnMaster())
+    Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
 
   target_chosen = false; // ensure next shoot cannot be done pressing key space
   return true;
@@ -167,13 +177,8 @@ bool AnvilLauncher::p_Shoot ()
 
 void AnvilLauncher::p_Select()
 {
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_FIRE_LEFT);
-}
-
-void AnvilLauncher::p_Deselect()
-{
-  // Go back to default cursor
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
+  if (Network::GetInstance()->IsTurnMaster())
+    Mouse::GetInstance()->SetPointer(Mouse::POINTER_FIRE_LEFT);
 }
 
 WeaponProjectile * AnvilLauncher::GetProjectileInstance()
