@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,10 +19,6 @@
  * auto bazooka : launch a homing missile
  *****************************************************************************/
 
-#include "weapon/auto_bazooka.h"
-#include "weapon/explosion.h"
-#include "weapon/weapon_cfg.h"
-
 #include "character/character.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
@@ -34,13 +30,17 @@
 #include "map/camera.h"
 #include "map/map.h"
 #include "map/wind.h"
+#include "network/network.h"
+#include "object/objects_list.h"
 #include "team/team.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
-#include "object/objects_list.h"
+#include "weapon/auto_bazooka.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
+
 
 class AutomaticBazookaConfig : public ExplosiveWeaponConfig {
   public:
@@ -49,7 +49,7 @@ class AutomaticBazookaConfig : public ExplosiveWeaponConfig {
     double fuel_time;
     double rocket_force;
     AutomaticBazookaConfig();
-    void LoadXml(xmlNode* elem);
+    void LoadXml(const xmlNode* elem);
 };
 
 class RPG : public WeaponProjectile
@@ -71,7 +71,7 @@ public:
   void Shoot(double strength);
   void Explosion();
   void SetTarget (int x,int y);
-  
+
 protected:
   void SignalOutOfMap();
   void SignalDrowning();
@@ -91,7 +91,7 @@ void RPG::Shoot(double strength)
   // Sound must be launched before WeaponProjectile::Shoot
   // in case that the projectile leave the battlefield
   // during WeaponProjectile::Shoot (#bug 10241)
-  flying_sound.Play("share","weapon/automatic_rocket_flying", -1);
+  flying_sound.Play("default","weapon/automatic_rocket_flying", -1);
 
   WeaponProjectile::Shoot(strength);
   angle_local=ActiveCharacter().GetFiringAngle();
@@ -211,14 +211,14 @@ AutomaticBazooka::AutomaticBazooka() :
   m_allow_change_timeout = true;
   m_target = new target_t;
   m_target->selected = false;
-  m_target->image = resource_manager.LoadImage( weapons_res_profile, "baz_cible");
+  m_target->image = GetResourceManager().LoadImage( weapons_res_profile, "baz_cible");
   ReloadLauncher();
 }
 
 void AutomaticBazooka::UpdateTranslationStrings()
 {
   m_name = _("Automatic Bazooka");
-  m_help = _("Howto use it : left clic on target\nInitial fire angle : Up/Down\nFire : keep space key pressed until the desired strength\nan ammo per turn");
+  m_help = _("How to use it : left click on the target\nInitial fire angle : Up/Down\nFire : keep the space key pressed until the desired strength\nan ammo per turn");
 }
 
 AutomaticBazooka::~AutomaticBazooka()
@@ -250,7 +250,8 @@ void AutomaticBazooka::p_Select()
   WeaponLauncher::p_Select();
   m_target->selected = false;
 
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_AIM);
+  if (Network::GetInstance()->IsTurnMaster())
+    Mouse::GetInstance()->SetPointer(Mouse::POINTER_AIM);
 }
 
 void AutomaticBazooka::p_Deselect()
@@ -258,20 +259,18 @@ void AutomaticBazooka::p_Deselect()
   WeaponLauncher::p_Deselect();
   if (m_target->selected) {
     // need to clear the old target
-    world.ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
+    GetWorld().ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
                         m_target->pos.y-m_target->image.GetHeight()/2,
                         m_target->image.GetWidth(),
                         m_target->image.GetHeight()));
   }
-
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
 }
 
 void AutomaticBazooka::ChooseTarget(Point2i mouse_pos)
 {
   if (m_target->selected) {
     // need to clear the old target
-    world.ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
+    GetWorld().ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
                         m_target->pos.y-m_target->image.GetHeight()/2,
                         m_target->image.GetWidth(),
                         m_target->image.GetHeight()));
@@ -290,9 +289,9 @@ void AutomaticBazooka::DrawTarget() const
 {
   if( !m_target->selected ) return;
 
-  AppWormux::GetInstance()->video->window.Blit(m_target->image, m_target->pos - m_target->image.GetSize()/2 - Camera::GetInstance()->GetPosition());
+  GetMainWindow().Blit(m_target->image, m_target->pos - m_target->image.GetSize()/2 - Camera::GetInstance()->GetPosition());
 
-  world.ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
+  GetWorld().ToRedrawOnMap(Rectanglei(m_target->pos.x-m_target->image.GetWidth()/2,
                                  m_target->pos.y-m_target->image.GetHeight()/2,
                                  m_target->image.GetWidth(),
                                  m_target->image.GetHeight()));
@@ -315,7 +314,7 @@ AutomaticBazookaConfig::AutomaticBazookaConfig() {
     rocket_force = 2500;
 }
 
-void AutomaticBazookaConfig::LoadXml(xmlNode* elem) {
+void AutomaticBazookaConfig::LoadXml(const xmlNode* elem) {
     ExplosiveWeaponConfig::LoadXml(elem);
     XmlReader::ReadDouble(elem, "uncontrolled_turn_speed", uncontrolled_turn_speed);
     XmlReader::ReadDouble(elem, "max_controlled_turn_speed", max_controlled_turn_speed);
