@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include "object/objects_list.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 
 class BazookaRocket : public WeaponProjectile
 {
@@ -73,7 +72,7 @@ void BazookaRocket::Shoot(double strength)
   // Sound must be launched before WeaponProjectile::Shoot
   // in case that the projectile leave the battlefield
   // during WeaponProjectile::Shoot (#bug 10241)
-  flying_sound.Play("share","weapon/rocket_flying", -1);
+  flying_sound.Play("default","weapon/rocket_flying", -1);
 
   WeaponProjectile::Shoot(strength);
 }
@@ -121,7 +120,7 @@ WeaponProjectile * Bazooka::GetProjectileInstance()
 void Bazooka::UpdateTranslationStrings()
 {
   m_name = _("Bazooka");
-  m_help = _("Initial fire angle : Up/Down\nFire : keep space key pressed until the desired strength\nan ammo per turn");
+  m_help = _("Initial fire angle : Up/Down\nFire : keep the space key pressed until the desired strength\nan ammo per turn");
 }
 
 std::string Bazooka::GetWeaponWinString(const char *TeamName, uint items_count ) const
