@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "object/objects_list.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "tool/xml_document.h"
 #include "game/time.h"
 
@@ -82,12 +81,12 @@ Cluster::Cluster(ClusterBombConfig& cfg,
 
 void Cluster::Shoot(const Point2i & pos, double strength, double angle)
 {
-  SetCollisionModel( false, true, false ); // a bit hackish...
+  SetCollisionModel(true, true, false ); // a bit hackish...
   // we do need to collide with objects, but if we allow for this, the clusters
   // will explode on spawn (because of colliding with each other)
 
   begin_time = Time::GetInstance()->Read();
-  Camera::GetInstance()->FollowObject(this, true);
+  Camera::GetInstance()->FollowObject(this);
   ResetConstants();
   SetXY( pos );
   SetSpeed(strength, angle);
@@ -165,7 +164,7 @@ void ClusterBomb::DoExplosion()
     cluster = new Cluster(static_cast<ClusterBombConfig &>(cfg), launcher);
     cluster->Shoot( pos, speed, angle + cluster_deviation );
 
-    lst_objects.AddObject(cluster);
+    ObjectsList::GetRef().AddObject(cluster);
   }
 }
 
@@ -186,7 +185,7 @@ ClusterLauncher::ClusterLauncher() :
 void ClusterLauncher::UpdateTranslationStrings()
 {
   m_name = _("Cluster Bomb");
-  m_help = _("Timeout : Wheel mouse or Page Up/Down\nAngle : Up/Down\nFire : keep space key pressed until the desired strength\nan ammo per turn");
+  m_help = _("Timeout : Mouse wheel or Page Up/Down\nAngle : Up/Down\nFire : keep the space key pressed until the desired strength\nan ammo per turn");
 }
 
 WeaponProjectile * ClusterLauncher::GetProjectileInstance()
