@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include "object/objects_list.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "sound/jukebox.h"
 #include "network/randomsync.h"
 #include "tool/xml_document.h"
@@ -56,9 +55,9 @@ protected:
 #endif
 
         // fake explosion 
-        JukeBox::GetInstance()->Play( "share", "weapon/cluzooka_shot" );
+        JukeBox::GetInstance()->Play( "default", "weapon/cluzooka_shot" );
         ParticleEngine::AddExplosionSmoke( pos, 
-            50, 
+            50,
             ParticleEngine::LittleESmoke );
 
         ClusterType * cluster;
@@ -70,7 +69,7 @@ protected:
             cluster = new ClusterType( cfg, p_launcher );
             cluster->Shoot( pos, speed, angle + cluster_deviation, recursion_depth );
 
-            lst_objects.AddObject(cluster);
+            ObjectsList::GetRef().AddObject(cluster);
         }
         m_spawned_clusters = true;
     }
@@ -137,9 +136,9 @@ void CluzookaCluster::Shoot(const Point2i & start_pos, double strength, double a
   recurse_times = 0; // to keep compiler happy
 #endif
 
-  Camera::GetInstance()->FollowObject(this, true);
+  Camera::GetInstance()->FollowObject(this);
   ResetConstants();
-  SetCollisionModel( false, true, false ); // a bit hackish...
+  SetCollisionModel(true, true, false ); // a bit hackish...
   // we do need to collide with objects, but if we allow for this, the clusters
   // will explode on spawn (because of colliding with each other)
   SetXY(start_pos);
@@ -326,7 +325,7 @@ void CluzookaRocket::Shoot(double strength)
   // Sound must be launched before WeaponProjectile::Shoot
   // in case that the projectile leave the battlefield
   // during WeaponProjectile::Shoot (#bug 10241)
-  flying_sound.Play("share","weapon/rocket_flying", -1);
+  flying_sound.Play("default","weapon/rocket_flying", -1);
 
   WeaponProjectile::Shoot(strength);
 }
@@ -387,7 +386,7 @@ WeaponProjectile * Cluzooka::GetProjectileInstance()
 void Cluzooka::UpdateTranslationStrings()
 {
   m_name = _("Cluzooka");
-  m_help = _("Initial fire angle : Up/Down\nFire : keep space key pressed until the desired strength\nan ammo per turn");
+  m_help = _("Initial fire angle : Up/Down\nFire : keep the space key pressed until the desired strength\nan ammo per turn");
 }
 
 std::string Cluzooka::GetWeaponWinString(const char *TeamName, uint items_count ) const
