@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include "game/time.h"
 #include "graphic/sprite.h"
 #include "include/action_handler.h"
+#include "interface/interface.h"
 #include "interface/mouse.h"
 #include "map/camera.h"
 #include "map/map.h"
@@ -36,7 +37,6 @@
 #include "team/macro.h"
 #include "team/team.h"
 #include "team/teams_list.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 
 #ifdef DEBUG
@@ -54,7 +54,7 @@ Construct::Construct() : Weapon(WEAPON_CONSTRUCT, "construct",
 {
   UpdateTranslationStrings();
 
-  construct_spr = resource_manager.LoadSprite( weapons_res_profile, "construct_spr");
+  construct_spr = GetResourceManager().LoadSprite( weapons_res_profile, "construct_spr");
   construct_spr->EnableRotationCache(static_cast<int>(2 * M_PI / DELTA_ANGLE));
   m_name = _("Construct");
   m_category = TOOL;
@@ -87,8 +87,8 @@ bool Construct::p_Shoot ()
 {
   if(!target_chosen)
     return false;
-  JukeBox::GetInstance()->Play("share", "weapon/construct");
-  world.MergeSprite(dst - construct_spr->GetSizeMax()/2, construct_spr);
+  JukeBox::GetInstance()->Play("default", "weapon/construct");
+  GetWorld().MergeSprite(dst - construct_spr->GetSizeMax()/2, construct_spr);
 
   target_chosen = false; // ensure next shoot cannot be done pressing key space
   return true;
@@ -99,17 +99,23 @@ void Construct::Draw()
   if (!IsInUse()) {
     Weapon::Draw();
 
-    dst = Mouse::GetInstance()->GetWorldPosition();
-    construct_spr->SetRotation_rad(angle);
-    construct_spr->Draw(dst - construct_spr->GetSize() / 2);
+    if (EnoughAmmo()
+	&& EnoughAmmoUnit()
+	&& !Interface::GetInstance()->weapons_menu.IsDisplayed()
+	&& Interface::GetInstance()->IsDisplayed()) {
+      dst = Mouse::GetInstance()->GetWorldPosition();
+      construct_spr->SetRotation_rad(angle);
+      construct_spr->Draw(dst - construct_spr->GetSize() / 2);
+
 #ifdef DEBUG
-    if (IsLOGGING("test_rectangle"))
-    {
-      Rectanglei test_rect(dst - construct_spr->GetSizeMax() / 2, construct_spr->GetSizeMax());
-      test_rect.SetPosition(test_rect.GetPosition() - Camera::GetInstance()->GetPosition());
-      AppWormux::GetInstance()->video->window.RectangleColor(test_rect, primary_red_color, 1);
-    }
+      if (IsLOGGING("test_rectangle"))
+	{
+	  Rectanglei test_rect(dst - construct_spr->GetSizeMax() / 2, construct_spr->GetSizeMax());
+	  test_rect.SetPosition(test_rect.GetPosition() - Camera::GetInstance()->GetPosition());
+	  GetMainWindow().RectangleColor(test_rect, primary_red_color, 1);
+	}
 #endif
+    }
   }
 }
 
@@ -120,7 +126,7 @@ void Construct::ChooseTarget(Point2i mouse_pos)
   Point2i test_target = dst - construct_spr->GetSizeMax() / 2;
   Rectanglei rect(test_target, construct_spr->GetSizeMax());
 
-  if (!world.ParanoiacRectIsInVacuum(rect))
+  if (!GetWorld().ParanoiacRectIsInVacuum(rect))
     return;
 
   // Check collision with characters and other physical objects
