@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,13 +24,13 @@
 
 #include "graphic/surface.h"
 #include "include/base.h"
-#include "tool/point.h"
+#include <WORMUX_point.h>
 
 class CrossHair
 {
-public:
+private:
   bool enable;
-  bool display;
+  bool hidden;
 
 private:
   Surface image;
@@ -47,6 +47,12 @@ public:
   // Draw crosshair
   void Draw() const;
 
+  void SetActive(bool enable);
+  bool IsActive() const { return enable; };
+
+  // Use it only for a few seconds (character walking, jumping, ...)
+  void Hide();
+  void Show();
 };
 
 #endif /* CROSSHAIR_H */
