@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "sound/jukebox.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 
 // The Disco Grenade
 class DiscoGrenade : public WeaponProjectile
@@ -64,12 +63,12 @@ DiscoGrenade::DiscoGrenade(ExplosiveWeaponConfig& cfg,
 }
 
 void DiscoGrenade::Shoot(double strength)
-{   
+{
   // Sound must be launched before WeaponProjectile::Shoot
   // in case that the projectile leave the battlefield
   // during WeaponProjectile::Shoot (#bug 10241)
-  disco_sound.Play("share","weapon/disco_grenade_music", -1);
-  
+  disco_sound.Play("default","weapon/disco_grenade_music", -1);
+
   WeaponProjectile::Shoot(strength);
 }
 
@@ -89,7 +88,7 @@ void DiscoGrenade::Explosion()
                                 1,particle_MAGIC_STAR,false,angle,2.5);
   }
   disco_sound.Stop();
-  
+
   WeaponProjectile::Explosion();
 }
 
@@ -116,7 +115,7 @@ void DiscoGrenade::Refresh()
   double tmp = Time::GetInstance()->Read() - begin_time;
   // Ah ! Ah ! Ah ! Staying Alive, staying alive ...
   if (GetTotalTimeout() >= 2 && tmp > (1000 * GetTotalTimeout() - 2000) && !have_played_music) {
-    JukeBox::GetInstance()->Play("share","weapon/alleluia") ;
+    //JukeBox::GetInstance()->Play("default","weapon/alleluia") ;
     have_played_music = true;
   }
   image->SetRotation_rad(GetSpeedAngle());
@@ -124,8 +123,8 @@ void DiscoGrenade::Refresh()
 
 void DiscoGrenade::SignalOutOfMap()
 {
-  GameMessages::GetInstance()->Add (_("The disco grenade has left the dance floor before exploding"));
-  WeaponProjectile::SignalOutOfMap();  
+  GameMessages::GetInstance()->Add (_("The disco grenade has left the dance floor before exploding!"));
+  WeaponProjectile::SignalOutOfMap();
 
   disco_sound.Stop();
 }
