@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,33 +22,16 @@
 #ifndef DISCO_GRENADE_H
 #define DISCO_GRENADE_H
 
-#include "launcher.h"
-#include "../graphic/surface.h"
-#include "../gui/progress_bar.h"
-#include "../include/base.h"
-
-class DiscoGrenadeLauncher;
-
-// The Disco Grenade
-class DiscoGrenade : public WeaponProjectile
-{
-  protected:
-    bool have_played_music;
-
-    ParticleEngine smoke_engine;
-  public:
-    DiscoGrenade(ExplosiveWeaponConfig& cfg,
-                 WeaponLauncher * p_launcher);
-    void Refresh();
-  protected:
-    void Explosion();
-    void SignalOutOfMap();
-};
+#include "weapon/weapon_launcher.h"
+#include "include/base.h"
 
 class DiscoGrenadeLauncher : public WeaponLauncher
 {
   public:
     DiscoGrenadeLauncher();
+    
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
   protected:
     WeaponProjectile * GetProjectileInstance();
 };
