@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,40 +24,18 @@
 #ifndef DYNAMITE_H
 #define DYNAMITE_H
 
-#include "launcher.h"
-#include "../graphic/sprite.h"
-#include "../include/base.h"
-#include "../character/character.h"
-
-class Dynamite;
-
-class DynamiteStick : public WeaponProjectile
-{
-  int channel;
-
-  public:
-    DynamiteStick(ExplosiveWeaponConfig& cfg,
-                  WeaponLauncher * p_launcher);
-
-    void Shoot(double strength);
-    void Refresh();
-
-  protected:
-    void ShootSound();
-    void SignalExplosion();
-    void SignalOutOfMap();
-    void SignalDrowning();
-};
-
+#include "weapon/weapon_launcher.h"
+#include "include/base.h"
 
 // L'arme dynamite
 class Dynamite : public WeaponLauncher
 {
   protected:
     bool p_Shoot();
-  protected:
     WeaponProjectile * GetProjectileInstance();
   public:
     Dynamite();
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count) const;
 };
 #endif /* DYNAMITE_H */
