@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,15 +19,11 @@
  * Weapon gnu : a gnu jump in (more or less) random directions and explodes
  *****************************************************************************/
 
-#include "weapon/explosion.h"
-#include "weapon/gnu.h"
-#include "weapon/weapon_cfg.h"
-
-#include <sstream>
 #include "character/character.h"
 #include "game/config.h"
 #include "game/time.h"
 #include "graphic/sprite.h"
+#include "include/action_handler.h"
 #include "interface/game_msg.h"
 #include "map/camera.h"
 #include "network/randomsync.h"
@@ -35,26 +31,29 @@
 #include "sound/jukebox.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
+#include "weapon/explosion.h"
+#include "weapon/gnu.h"
+#include "weapon/weapon_cfg.h"
 
 const uint TIME_BETWEEN_REBOUND = 600;
 
 class Gnu : public WeaponProjectile
 {
- private:
+private:
   int m_sens;
   int save_x, save_y;
   uint last_rebound_time;
- protected:
+protected:
   void SignalOutOfMap();
 public:
   Gnu(ExplosiveWeaponConfig& cfg,
       WeaponLauncher * p_launcher);
   void Shoot(double strength);
   void Refresh();
-};
 
+  virtual void Explosion();
+};
 
 Gnu::Gnu(ExplosiveWeaponConfig& cfg,
          WeaponLauncher * p_launcher) :
@@ -81,9 +80,14 @@ void Gnu::Shoot(double strength)
 
 void Gnu::Refresh()
 {
-  WeaponProjectile::Refresh();
+  if (m_energy == 0) {
+    Explosion();
+    return;
+  }
+  int tmp = Time::GetInstance()->Read() - begin_time;
+  if(cfg.timeout && tmp > 1000 * (GetTotalTimeout())) SignalTimeout();
 
-  double norme, angle;
+  double norm, angle;
   //When we hit the ground, jump !
   if(!IsMoving()&& !FootsInVacuum()) {
     // Limiting number of rebound to avoid desync
@@ -92,6 +96,7 @@ void Gnu::Refresh()
       return;
     }
     last_rebound_time = Time::GetInstance()->Read();
+    MSG_DEBUG("weapon.gnu", "Jump ! (time = %d)", last_rebound_time);
     //If the GNU is stuck in ground -> change direction
     int x = GetX();
     int y = GetY();
@@ -101,15 +106,15 @@ void Gnu::Refresh()
     save_y = y;
 
     //Do the jump
-    norme = randomSync.GetDouble(2.0, 5.0);
+    norm = RandomSync().GetDouble(2.0, 5.0);
     PutOutOfGround();
-    SetSpeedXY(Point2d(m_sens * norme , - norme * 3.0));
-    JukeBox::GetInstance()->Play("share", "weapon/gnu_bounce");
+    SetSpeedXY(Point2d(m_sens * norm , - norm * 3.0));
+    JukeBox::GetInstance()->Play("default", "weapon/gnu_bounce");
   }
 
   //Due to a bug in the physic engine
   //sometimes, angle==infinite (according to gdb) ??
-  GetSpeed(norme, angle);
+  GetSpeed(norm, angle);
 
   while(angle < -M_PI)
     angle += M_PI;
@@ -131,28 +136,33 @@ void Gnu::Refresh()
   image->SetRotation_rad(angle);
   image->Scale((double)m_sens,1.0);
   image->Update();
-  // Fixes test rectangle ??
-  SetTestRect(image->GetWidth() / 2 - 1,
-              image->GetWidth() / 2 - 1,
-              image->GetHeight() / 2 - 1,
-              image->GetHeight() / 2 - 1);
+}
+
+void Gnu::Explosion()
+{
+  WeaponProjectile::Explosion();
 }
 
 void Gnu::SignalOutOfMap()
 {
-  GameMessages::GetInstance()->Add (_("The Gnu left the battlefield before exploding"));
+  GameMessages::GetInstance()->Add (_("The Gnu left the battlefield before exploding!"));
   WeaponProjectile::SignalOutOfMap();
 }
 
 //-----------------------------------------------------------------------------
 
 GnuLauncher::GnuLauncher() :
-  WeaponLauncher(WEAPON_GNU, "gnulauncher", new ExplosiveWeaponConfig(), VISIBLE_ONLY_WHEN_INACTIVE)
+  WeaponLauncher(WEAPON_GNU, "gnulauncher", new ExplosiveWeaponConfig(), VISIBLE_ONLY_WHEN_INACTIVE),
+  current_gnu(NULL),
+  gnu_death_time(0)
 {
   UpdateTranslationStrings();
 
   m_category = SPECIAL;
   ReloadLauncher();
+
+  // unit will be used when the gnu disappears
+  use_unit_on_first_shoot = false;
 }
 
 void GnuLauncher::UpdateTranslationStrings()
@@ -162,6 +172,80 @@ void GnuLauncher::UpdateTranslationStrings()
   /* m_help = _(""); */
 }
 
+bool GnuLauncher::p_Shoot()
+{
+  if (current_gnu || gnu_death_time)
+    return false;
+
+  current_gnu = static_cast<Gnu *>(projectile);
+  gnu_death_time = 0;
+  bool r = WeaponLauncher::p_Shoot();
+
+  return r;
+}
+
+void GnuLauncher::Refresh()
+{
+  if (current_gnu)
+    return;
+
+  if (gnu_death_time && gnu_death_time + 2000 < Time::GetInstance()->Read()) {
+
+    UseAmmoUnit();
+    gnu_death_time = 0;
+  }
+}
+
+bool GnuLauncher::IsInUse() const
+{
+  return (current_gnu || gnu_death_time);
+}
+
+void GnuLauncher::SignalEndOfProjectile()
+{
+  if (!current_gnu)
+    return;
+
+  current_gnu = NULL;
+  gnu_death_time = Time::GetInstance()->Read();
+}
+
+void GnuLauncher::HandleKeyPressed_Shoot(bool shift)
+{
+  if (current_gnu || gnu_death_time)
+    return;
+
+  Weapon::HandleKeyPressed_Shoot(shift);
+}
+
+void GnuLauncher::HandleKeyRefreshed_Shoot(bool shift)
+{
+  if (current_gnu || gnu_death_time)
+    return;
+
+  Weapon::HandleKeyRefreshed_Shoot(shift);
+}
+
+void GnuLauncher::HandleKeyReleased_Shoot(bool shift)
+{
+  if (current_gnu) {
+    Action* a = new Action(Action::ACTION_WEAPON_GNU);
+    a->Push(current_gnu->GetPos());
+    ActionHandler::GetInstance()->NewAction(a);
+    return;
+  } else if (!gnu_death_time)
+    Weapon::HandleKeyReleased_Shoot(shift);
+}
+
+void GnuLauncher::ExplosionFromNetwork(Point2d gnu_pos)
+{
+  if (!current_gnu)
+    return;
+
+  current_gnu->SetPhysXY(gnu_pos);
+  current_gnu->Explosion();
+}
+
 WeaponProjectile * GnuLauncher::GetProjectileInstance()
 {
   return dynamic_cast<WeaponProjectile *>
