@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #include "team/team.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
 
@@ -58,7 +57,7 @@ bool find_first_contact_point (Point2i from, double angle, uint length,
 
   posd.x += ((double)skip) * x_step;
   posd.y += ((double)skip) * y_step;
-  
+
   from.x = (int)round(posd.x) ;
   from.y = (int)round(posd.y) ;
 
@@ -70,18 +69,18 @@ bool find_first_contact_point (Point2i from, double angle, uint length,
   // make it return the last point still in vacuum
   Point2i new_contact_point = contact_point;
   bool contact_point_uncertain = true;
-  while(!world.IsOutsideWorld(new_contact_point) &&
+  while(!GetWorld().IsOutsideWorld(new_contact_point) &&
         (length > 0))
     {
-      if ( !world.IsInVacuum( new_contact_point ) )
+      if ( !GetWorld().IsInVacuum( new_contact_point ) )
       {
-        ASSERT( contact_point_uncertain || world.IsInVacuum( contact_point ) );
+        ASSERT( contact_point_uncertain || GetWorld().IsInVacuum( contact_point ) );
 
         // for uncertain contact points, see if it's in vacuum
-        if ( contact_point_uncertain && !world.IsInVacuum( contact_point ) )
+        if ( contact_point_uncertain && !GetWorld().IsInVacuum( contact_point ) )
         {
            // it's not, so try our best to return a contact point in vacuum
-           // try searching in area NxN around our original point and return 
+           // try searching in area NxN around our original point and return
            // the closest pixel in vacuum
 
            // FIXME: can be optimized!
@@ -97,7 +96,7 @@ bool find_first_contact_point (Point2i from, double angle, uint length,
              for ( int j = -search_radius; j <= search_radius; j ++ )
              {
                cur = contact_point + Point2i( i, j );
-               if ( world.IsInVacuum( cur ) )
+               if ( GetWorld().IsInVacuum( cur ) )
                {
                  // check for new closest
                  int distance = i * i + j * j;
@@ -138,7 +137,7 @@ class GrappleConfig : public EmptyWeaponConfig
 
  public:
   GrappleConfig();
-  void LoadXml(xmlNode* elem);
+  void LoadXml(const xmlNode* elem);
 };
 
 //-----------------------------------------------------------------------------
@@ -150,9 +149,9 @@ Grapple::Grapple() : Weapon(WEAPON_GRAPPLE, "grapple", new GrappleConfig())
   m_category = MOVE;
   use_unit_on_first_shoot = false;
 
-  m_hook_sprite = resource_manager.LoadSprite(weapons_res_profile,"grapple_hook");
+  m_hook_sprite = GetResourceManager().LoadSprite(weapons_res_profile,"grapple_hook");
   m_hook_sprite->EnableRotationCache(32);
-  m_node_sprite = resource_manager.LoadSprite(weapons_res_profile,"grapple_node");
+  m_node_sprite = GetResourceManager().LoadSprite(weapons_res_profile,"grapple_node");
 
   m_is_active = false;
   m_attaching = false;
@@ -183,7 +182,7 @@ bool Grapple::p_Shoot()
   m_initial_angle = ActiveCharacter().GetFiringAngle();
   last_mvt=Time::GetInstance()->Read();
 
-  if (TryAttachRope()) JukeBox::GetInstance()->Play("share", "weapon/grapple_attaching");
+  if (TryAttachRope()) JukeBox::GetInstance()->Play("default", "weapon/grapple_attaching");
   return true;
 }
 
@@ -275,7 +274,7 @@ bool Grapple::TryAddNode(int CurrentSense)
            (fabs(last_broken_node_angle - rope_angle) < 0.1))
         return false ;
 
-      // if contact point is the same as position of the last node 
+      // if contact point is the same as position of the last node
       // (can happen because of jitter applied in find_first_contact_point),
       // give up adding such node
       if ( rope_nodes.size() > 0 && rope_nodes.back().pos == contact_point )
@@ -291,7 +290,7 @@ bool Grapple::TryAddNode(int CurrentSense)
       a.Push(contact_point);
       a.Push(rope_angle);
       a.Push(CurrentSense);
-      Network::GetInstance()->SendAction(&a);
+      Network::GetInstance()->SendActionToAll(a);
 
       return true;
     }
@@ -325,7 +324,7 @@ bool Grapple::TryRemoveNodes(int currentSense)
     // (NOTE: since nodes are often in ground, we're ignoring traces hitting ground
     // right at the end)
     const float end_proximity_threshold = 0.95f;
-    if ( world.TraceRay( mapRopeStart, it->pos, tr ) && tr.m_fraction < end_proximity_threshold )
+    if ( GetWorld().TraceRay( mapRopeStart, it->pos, tr ) && tr.m_fraction < end_proximity_threshold )
     {
         // collision detected!
         if ( nodes_to_remove > 0 )
@@ -361,7 +360,7 @@ bool Grapple::TryRemoveNodes(int currentSense)
      // Send node suppression over the network
      Action a(Action::ACTION_WEAPON_GRAPPLE);
      a.Push(DETACH_NODE);
-     Network::GetInstance()->SendAction(&a);
+     Network::GetInstance()->SendActionToAll(a);
   }
 
   return nodes_to_remove > 0;
@@ -529,14 +528,16 @@ void Grapple::AttachRope(const Point2i& contact_point)
   ActiveCharacter().SetFiringAngle(-M_PI / 3);
 
   // Camera should focus on it!
-  Camera::GetInstance()->FollowObject (&ActiveCharacter(), true);
+  Camera::GetInstance()->FollowObject(&ActiveCharacter());
 }
 
 void Grapple::DetachRope()
 {
-  ActiveCharacter().UnsetPhysFixationPoint() ;
+  ActiveCharacter().UnsetPhysFixationPoint();
   rope_nodes.clear();
   m_is_active = false;
+
+  cable_sound.Stop();
 }
 
 void Grapple::AttachNode(const Point2i& contact_point,
@@ -612,6 +613,11 @@ void Grapple::GoUp()
   delta_len = 0 ;
 }
 
+void Grapple::StopUp()
+{
+  cable_sound.Stop();
+}
+
 void Grapple::GoDown()
 {
   if(Time::GetInstance()->Read()<last_mvt+DT_MVT)
@@ -627,8 +633,16 @@ void Grapple::GoDown()
   delta_len = 0 ;
 }
 
+void Grapple::StopDown()
+{
+  cable_sound.Stop();
+}
+
 void Grapple::GoRight()
 {
+  if (!go_right) {
+    cable_sound.Play("default", "weapon/grapple_cable");
+  }
   go_right = true ;
   ActiveCharacter().SetExternForce(cfg().push_force,0);
   ActiveCharacter().SetDirection(DIRECTION_RIGHT);
@@ -647,6 +661,9 @@ void Grapple::StopRight()
 
 void Grapple::GoLeft()
 {
+  if (!go_left) {
+    cable_sound.Play("default", "weapon/grapple_cable");
+  }
   go_left = true ;
   ActiveCharacter().SetExternForce(-cfg().push_force,0);
   ActiveCharacter().SetDirection(DIRECTION_LEFT);
@@ -667,8 +684,10 @@ void Grapple::StopLeft()
 
 void Grapple::HandleKeyPressed_Up(bool shift)
 {
-  if (IsInUse())
+  if (IsInUse())  {
+    cable_sound.Play("default", "weapon/grapple_cable", -1);
     GoUp();
+  }
   else
     ActiveCharacter().HandleKeyPressed_Up(shift);
 }
@@ -683,15 +702,18 @@ void Grapple::HandleKeyRefreshed_Up(bool shift)
 
 void Grapple::HandleKeyReleased_Up(bool shift)
 {
-  if (!IsInUse())
+  if (IsInUse())
+    StopUp();
+  else
     ActiveCharacter().HandleKeyReleased_Up(shift);
 }
 
 void Grapple::HandleKeyPressed_Down(bool shift)
 {
-  if (IsInUse())
+  if (IsInUse()) {
+    cable_sound.Play("default", "weapon/grapple_cable", -1);
     GoDown();
-  else
+  } else
     ActiveCharacter().HandleKeyPressed_Down(shift);
 }
 
@@ -705,7 +727,9 @@ void Grapple::HandleKeyRefreshed_Down(bool shift)
 
 void Grapple::HandleKeyReleased_Down(bool shift)
 {
-  if (!IsInUse())
+  if (IsInUse())
+    StopDown();
+  else
     ActiveCharacter().HandleKeyReleased_Down(shift);
 }
 
@@ -764,8 +788,8 @@ void Grapple::HandleKeyPressed_Shoot(bool)
 void Grapple::PrintDebugRope()
 {
   printf("%05d %05d %03.3f\n",
-         ActiveCharacter().GetPosition().GetX(),
-         ActiveCharacter().GetPosition().GetY(),
+         ActiveCharacter().GetX(),
+         ActiveCharacter().GetY(),
          ActiveCharacter().GetRopeAngle());
 
   for (std::list<rope_node_t>::iterator it = rope_nodes.begin();
@@ -800,7 +824,7 @@ GrappleConfig::GrappleConfig()
   push_force = 10;
 }
 
-void GrappleConfig::LoadXml(xmlNode* elem)
+void GrappleConfig::LoadXml(const xmlNode* elem)
 {
   EmptyWeaponConfig::LoadXml(elem);
   XmlReader::ReadUint(elem, "max_rope_length", max_rope_length);
