@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include "weapon/explosion.h"
 #include "team/teams_list.h"
 #include "tool/math_tools.h"
-#include "tool/i18n.h"
 #include "object/objects_list.h"
 //-----------------------------------------------------------------------------
 
@@ -55,7 +54,7 @@ void Grenade::Refresh()
 
 void Grenade::SignalOutOfMap()
 {
-  GameMessages::GetInstance()->Add (_("The grenade left the battlefield before exploding"));
+  GameMessages::GetInstance()->Add (_("The grenade left the battlefield before exploding!"));
   WeaponProjectile::SignalOutOfMap();
 }
 
