@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,20 +22,23 @@
 #ifndef LOWGRAV_H
 #define LOWGRAV_H
 #include "weapon.h"
+#include "sound/sound_sample.h"
 
 class LowGrav : public Weapon
 {
   public:
     LowGrav();
-    void Reset();
-    void HandleKeyEvent(Action::Action_t action, Keyboard::Key_Event_t event_type);
-    void SignalTurnEnd();
-    void Draw();
-    void ActionStopUse();
+    void Draw() { };
+    void ActionStopUse() { UseAmmoUnit(); };
+    void HandleKeyPressed_Shoot(bool shift);
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
   protected:
-    void Refresh();
+    void Refresh() { };
     void p_Deselect();
     bool p_Shoot();
+    SoundSample use;
 };
 
 #endif /* LOWGRAV_H */
