@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,24 +24,22 @@
 
 #include "weapon.h"
 
-class ParachuteConfig : public WeaponConfig
-{
-  public:
-    double wind_factor ;
-    double air_resist_factor ;
-  public:
-    ParachuteConfig();
-    void LoadXml(xmlpp::Element *elem);
-};
+class Sprite;
+class ParachuteConfig;
 
 //-----------------------------------------------------------------------------
 
 class Parachute : public Weapon
 {
   private:
-    bool open ;
-    bool closing ;
-    Sprite* image;
+    bool open;
+    bool closing;
+
+    struct {
+      double x_extern;
+      bool changing;
+    } m_x_strength;
+    Sprite* img;
   protected:
     void p_Select();
     void p_Deselect();
@@ -49,8 +47,18 @@ class Parachute : public Weapon
     bool p_Shoot();
   public:
     Parachute();
-    void Draw() ;
-    void SignalTurnEnd();
+    ~Parachute();
+    void Draw();
+    bool IsInUse() const;
+
+    void HandleKeyPressed_Shoot(bool shift);
+    void HandleKeyPressed_MoveRight(bool shift);
+    void HandleKeyReleased_MoveRight(bool shift);
+    void HandleKeyPressed_MoveLeft(bool shift);
+    void HandleKeyReleased_MoveLeft(bool shift);
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
 
     ParachuteConfig& cfg();
 };
