@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "map/camera.h"
 #include "team/macro.h"
 #include "team/team.h"
-#include "tool/i18n.h"
 #include "tool/math_tools.h"
 #include "tool/resource_manager.h"
 #include "tool/xml_document.h"
@@ -111,17 +110,17 @@ Weapon::Weapon(Weapon_type type,
 
   if (m_visibility != NEVER_VISIBLE)
   {
-    m_image = new Sprite( resource_manager.LoadImage(weapons_res_profile, m_id));
+    m_image = new Sprite( GetResourceManager().LoadImage(weapons_res_profile, m_id));
     if(!EqualsZero(min_angle - max_angle))
       m_image->cache.EnableLastFrameCache();
   }
 
-  icon = new Sprite(resource_manager.LoadImage(weapons_res_profile,m_id+"_ico"), true);
+  icon = new Sprite(GetResourceManager().LoadImage(weapons_res_profile,m_id+"_ico"), true);
   icon->cache.EnableLastFrameCache();
 
   mouse_character_selection = true;
 
-  const xmlNode* elem = resource_manager.GetElement(weapons_res_profile, "position", m_id);
+  const xmlNode* elem = GetResourceManager().GetElement(weapons_res_profile, "position", m_id);
   if (elem != NULL) {
     // E.g. <position name="my_weapon_id" origin="hand" x="-1" y="0" />
     std::string origin_xml;
@@ -143,7 +142,7 @@ Weapon::Weapon(Weapon_type type,
     ASSERT(false);
   }
 
-  elem = resource_manager.GetElement(weapons_res_profile, "hole", m_id);
+  elem = GetResourceManager().GetElement(weapons_res_profile, "hole", m_id);
   if (elem != NULL) {
     // E.g. <hole name="my_weapon_id" dx="-1" dy="0" />
     XmlReader::ReadIntAttr(elem, "dx", hole_delta.x);
@@ -173,10 +172,7 @@ void Weapon::Select()
 
   // is there a crosshair ?
   if (m_display_crosshair)
-    ActiveTeam().crosshair.display = true;
-
-  if(!EqualsZero(min_angle - max_angle))
-    ActiveTeam().crosshair.enable = true;
+    ActiveTeam().crosshair.SetActive(true);
 
   p_Select();
 
@@ -197,8 +193,9 @@ void Weapon::Select()
 
 void Weapon::Deselect()
 {
-  ActiveTeam().crosshair.enable = false;
-  ActiveTeam().crosshair.display = false;
+  ActiveTeam().crosshair.SetActive(false);
+  ActiveCharacter().SetFiringAngle(0);
+  ActiveCharacter().SetMovement("breathe");
   m_is_active = false;
   MSG_DEBUG("weapon.change", "Deselect %s", m_name.c_str());
   p_Deselect();
@@ -331,7 +328,7 @@ bool Weapon::Shoot()
 
   if (max_strength != 0) ActiveCharacter().previous_strength = m_strength;
 
-  Game::GetInstance()->character_already_chosen = true;
+  Game::GetInstance()->SetCharacterChosen(true);
 
   return true;
 }
@@ -448,13 +445,13 @@ void Weapon::InitLoading(){
   if (max_strength == 0)
     return ;
 
-  loading_sound.Play("share","weapon/load");
+  loading_sound.Play("default","weapon/load");
 
   m_first_time_loading = Time::GetInstance()->Read();
 
   m_strength = 0;
 
-  Game::GetInstance()->character_already_chosen = true;
+  Game::GetInstance()->SetCharacterChosen(true);
 }
 
 void Weapon::StopLoading(){
@@ -562,7 +559,7 @@ void Weapon::Draw(){
 		    3,
 		    3);
 
-    world.ToRedrawOnMap(rect);
+    GetWorld().ToRedrawOnMap(rect);
 
     GetMainWindow().RectangleColor(rect, c_red);
 
@@ -578,7 +575,7 @@ void Weapon::Draw(){
                   GetGunHolePosition().GetY() - Camera::GetInstance()->GetPositionY()- 1,
       	    	  3, 3);
 
-  world.ToRedrawOnMap(rect);
+  GetWorld().ToRedrawOnMap(rect);
   GetMainWindow().RectangleColor(rect, c_red);
 
 //  rect = Rectangle(
@@ -704,20 +701,18 @@ void Weapon::ActionStopUse()
 // #################### SHOOT
 void Weapon::HandleKeyPressed_Shoot(bool)
 {
-  if(ActiveCharacter().IsPreparingShoot())
+  if (ActiveCharacter().IsPreparingShoot())
     return;
 
-  if (max_strength == 0)
-    NewActionWeaponShoot();
-  else if ( IsReady() )
+  if (max_strength != 0 && IsReady())
     InitLoading();
 }
 
 void Weapon::HandleKeyRefreshed_Shoot(bool)
 {
-  if(ActiveCharacter().IsPreparingShoot())
+  if (ActiveCharacter().IsPreparingShoot())
     return;
-  if ( !IsLoading() )
+  if (!IsLoading())
     return;
 
   // Strength == max strength -> Fire !!!
@@ -731,16 +726,15 @@ void Weapon::HandleKeyRefreshed_Shoot(bool)
 
 void Weapon::HandleKeyReleased_Shoot(bool)
 {
-  if(ActiveCharacter().IsPreparingShoot())
-    return;
-  if ( !IsLoading())
-    return;
-
-  NewActionWeaponShoot();
+  if (!ActiveCharacter().IsPreparingShoot()) {
+    NewActionWeaponShoot();
+  }
 }
 
 void Weapon::p_Deselect()
 {
+  Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
+
   ActiveCharacter().SetMovement("breathe");
 }
 
