@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "tool/xml_document.h"
 //-----------------------------------------------------------------------------
 
-void EmptyWeaponConfig::LoadXml(xmlNode* /*elem*/)
+void EmptyWeaponConfig::LoadXml(const xmlNode* /*elem*/)
 {}
 
 //-----------------------------------------------------------------------------
@@ -32,9 +32,13 @@ void EmptyWeaponConfig::LoadXml(xmlNode* /*elem*/)
 WeaponConfig::WeaponConfig()
 { damage = 10; }
 
-void WeaponConfig::LoadXml(xmlNode* elem)
+void WeaponConfig::LoadXml(const xmlNode* elem)
 {
-  XmlReader::ReadUint(elem, "damage", damage);
+  bool r;
+
+  r = XmlReader::ReadUint(elem, "damage", damage);
+  if (!r)
+    damage = 10;
 }
 
 //-----------------------------------------------------------------------------
@@ -50,16 +54,38 @@ ExplosiveWeaponConfig::ExplosiveWeaponConfig()
   speed_on_hit = 0 ;
 }
 
-void ExplosiveWeaponConfig::LoadXml(xmlNode* elem)
+void ExplosiveWeaponConfig::LoadXml(const xmlNode* elem)
 {
+  bool r;
+
   WeaponConfig::LoadXml (elem);
-  XmlReader::ReadUint(elem, "timeout", timeout);
-  XmlReader::ReadBool(elem, "allow_change_timeout", allow_change_timeout);
-  XmlReader::ReadUint(elem, "explosion_range", explosion_range);
-  XmlReader::ReadUint(elem, "particle_range", particle_range);
-  XmlReader::ReadUint(elem, "blast_range", blast_range);
-  XmlReader::ReadUint(elem, "blast_force", blast_force);
-  XmlReader::ReadUint(elem, "speed_on_hit", speed_on_hit);
+  r = XmlReader::ReadUint(elem, "timeout", timeout);
+  if (!r)
+    timeout = 0;
+
+  r = XmlReader::ReadBool(elem, "allow_change_timeout", allow_change_timeout);
+  if (!r)
+    allow_change_timeout = false;
+
+  r = XmlReader::ReadUint(elem, "explosion_range", explosion_range);
+  if (!r)
+    explosion_range = 0;
+
+  r = XmlReader::ReadUint(elem, "particle_range", particle_range);
+  if (!r)
+    particle_range = 0;
+
+  r = XmlReader::ReadUint(elem, "blast_range", blast_range);
+  if (!r)
+    blast_range = 0;
+
+  r = XmlReader::ReadUint(elem, "blast_force", blast_force);
+  if (!r)
+    blast_force = 0;
+
+  r = XmlReader::ReadUint(elem, "speed_on_hit", speed_on_hit);
+  if (!r)
+    speed_on_hit = 0;
 }
 
 //-----------------------------------------------------------------------------
