@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,12 +19,9 @@
  * WeaponLauncher: generic weapon to launch a projectile
  *****************************************************************************/
 
-#include "weapon/weapon_launcher.h"
-#include "weapon/weapon_cfg.h"
-
 #include <sstream>
+#include <WORMUX_debug.h>
 
-#include "weapon/explosion.h"
 #include "character/character.h"
 #include "game/config.h"
 #include "game/game.h"
@@ -38,10 +35,11 @@
 #include "team/macro.h"
 #include "team/team.h"
 #include "team/teams_list.h"
-#include "tool/debug.h"
-#include "tool/i18n.h"
 #include "tool/math_tools.h"
 #include "tool/resource_manager.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
+#include "weapon/weapon_launcher.h"
 
 #ifdef DEBUG
 //#define DEBUG_EXPLOSION_CONFIG
@@ -62,7 +60,7 @@ WeaponBullet::WeaponBullet(const std::string &name,
 // Signal that the bullet has hit the ground
 void WeaponBullet::SignalGroundCollision(const Point2d& speed_before)
 {
-  JukeBox::GetInstance()->Play("share", "weapon/ricoche1");
+  JukeBox::GetInstance()->Play("default", "weapon/ricoche1");
   WeaponProjectile::SignalGroundCollision(speed_before);
   launcher->IncMissedShots();
 }
@@ -71,16 +69,33 @@ void WeaponBullet::SignalOutOfMap()
 {
   WeaponProjectile::SignalOutOfMap();
   launcher->IncMissedShots();
-  Camera::GetInstance()->FollowObject(&ActiveCharacter(), true);
+  Camera::GetInstance()->FollowObject(&ActiveCharacter());
 }
 
-void WeaponBullet::SignalObjectCollision(PhysicalObj * obj, const Point2d& my_speed_before)
+void WeaponBullet::SignalObjectCollision(const Point2d& my_speed_before,
+					 PhysicalObj * obj,
+					 const Point2d& /*obj_speed*/)
 {
+#if 1
+  obj->AddSpeed(cfg.speed_on_hit, my_speed_before.ComputeAngle());
+#else
+  // multiply by ten to get something more funny
+  double bullet_mass = GetMass()/* * 10*/;
+  double total_mass = bullet_mass + obj->GetMass();
+  // computing new speed of character
+  Point2d v2 = (my_speed_before * (1 + 0.8) * bullet_mass +
+                obj->GetSpeed() * (obj->GetMass() - 0.8 * bullet_mass)) / total_mass;
+  // Pushing a little upward character to allow him to be pushed by the projectile
+  obj->SetXY(Point2i(obj->GetX(), obj->GetY() - 3));
+  obj->SetSpeedXY(v2);
+#endif
+
+  obj->SetEnergyDelta(-(int)cfg.damage);
   if (!obj->IsCharacter())
     Explosion();
-  obj->SetEnergyDelta(-(int)cfg.damage);
-  obj->AddSpeed(cfg.speed_on_hit, my_speed_before.ComputeAngle());
   Ghost();
+
+  WeaponProjectile::Collision();
 }
 
 void WeaponBullet::Refresh()
@@ -103,16 +118,16 @@ WeaponProjectile::WeaponProjectile(const std::string &name,
   : PhysicalObj(name), cfg(p_cfg)
 {
   m_allow_negative_y = true;
-  SetCollisionModel(false, true, true);
+  SetCollisionModel(true, true, true);
   launcher = p_launcher;
 
   explode_colliding_character = false;
   explode_with_timeout = true;
   explode_with_collision = true;
   can_drown = true;
-  camera_in_advance = true;
+  camera_follow_closely = false;
 
-  image = resource_manager.LoadSprite( weapons_res_profile, name);
+  image = GetResourceManager().LoadSprite( weapons_res_profile, name);
   image->EnableRotationCache(32);
   SetSize(image->GetSize());
 
@@ -146,8 +161,7 @@ void WeaponProjectile::Shoot(double strength)
 
   // Set the initial position.
   SetOverlappingObject(&ActiveCharacter(), 100);
-  lst_objects.AddObject(this);
-  Camera::GetInstance()->FollowObject(this, true, camera_in_advance);
+  ObjectsList::GetRef().AddObject(this);
 
   double angle = ActiveCharacter().GetFiringAngle();
   RandomizeShoot(angle, strength);
@@ -174,6 +188,11 @@ void WeaponProjectile::Shoot(double strength)
   Point2d f_hole_position(hole_position.GetX() / PIXEL_PER_METER, hole_position.GetY() / PIXEL_PER_METER);
   SetXY(hand_position);
   SetSpeed(strength, angle);
+
+  // Camera::FollowObject must be called after setting initial speed else
+  // camera_follow_closely will have no effect
+  Camera::GetInstance()->FollowObject(this, camera_follow_closely);
+
   collision_t collision = NotifyMove(f_hand_position, f_hole_position);
   if (collision == NO_COLLISION) {
     // Set the initial position and speed.
@@ -196,7 +215,7 @@ void WeaponProjectile::Refresh()
   }
   SetSize(image->GetSizeMax());
   // Explose after timeout
-  double tmp = Time::GetInstance()->Read() - begin_time;
+  int tmp = Time::GetInstance()->Read() - begin_time;
 
   if(cfg.timeout && tmp > 1000 * (GetTotalTimeout())) SignalTimeout();
 }
@@ -232,10 +251,10 @@ void WeaponProjectile::Draw()
   {
     Rectanglei test_rect(GetTestRect());
     test_rect.SetPosition(test_rect.GetPosition() - Camera::GetInstance()->GetPosition());
-    AppWormux::GetInstance()->video->window.RectangleColor(test_rect, primary_red_color, 1);
+    GetMainWindow().RectangleColor(test_rect, primary_red_color, 1);
 
     Rectanglei rect(GetPosition() - Camera::GetInstance()->GetPosition(), image->GetSizeMax());
-    AppWormux::GetInstance()->video->window.RectangleColor(rect, primary_blue_color, 1);
+    GetMainWindow().RectangleColor(rect, primary_blue_color, 1);
   }
 #endif
 }
@@ -248,13 +267,17 @@ bool WeaponProjectile::IsImmobile() const
 }
 
 // projectile explode and signal to the launcher the collision
-void WeaponProjectile::SignalObjectCollision(PhysicalObj * obj, const Point2d& /* my_speed_before */)
+void WeaponProjectile::SignalObjectCollision(const Point2d& /* my_speed_before */,
+					     PhysicalObj * obj,
+					     const Point2d& /* obj_speed_before */)
 {
   ASSERT(obj != NULL);
   MSG_DEBUG("weapon.projectile", "SignalObjectCollision \"%s\" with \"%s\": %d, %d",
 	    m_name.c_str(), obj->GetName().c_str(), GetX(), GetY());
   if (explode_colliding_character)
     Explosion();
+
+  Collision();
 }
 
 // projectile explode when hiting the ground
@@ -263,14 +286,16 @@ void WeaponProjectile::SignalGroundCollision(const Point2d& /*speed_before*/)
   MSG_DEBUG("weapon.projectile", "SignalGroundCollision \"%s\": %d, %d", m_name.c_str(), GetX(), GetY());
   if (explode_with_collision)
     Explosion();
+
+  Collision();
 }
 
-// Default behavior : signal to launcher a collision and explode
-void WeaponProjectile::SignalCollision(const Point2d& speed_before)
+// Signal to launcher a collision
+void WeaponProjectile::Collision()
 {
-  MSG_DEBUG("weapon.projectile", "SignalCollision \"%s\": %d, %d", m_name.c_str(), GetX(), GetY());
+  MSG_DEBUG("weapon.projectile", "Collision \"%s\": %d, %d", m_name.c_str(), GetX(), GetY());
   if (launcher != NULL && !launcher->ignore_collision_signal)
-    launcher->SignalProjectileCollision(speed_before);
+    launcher->SignalProjectileCollision();
 }
 
 // Default behavior : signal to launcher projectile is drowning
@@ -281,8 +306,8 @@ void WeaponProjectile::SignalDrowning()
   if (launcher != NULL && !launcher->ignore_drowning_signal)
     launcher->SignalProjectileDrowning();
 
-  if (can_drown) JukeBox::GetInstance()->Play("share", "sink");
-  //else JukeBox::GetInstance()->Play("share", "pschiiit");
+  if (can_drown) JukeBox::GetInstance()->Play("default", "sink");
+  //else JukeBox::GetInstance()->Play("default", "pschiiit");
 }
 
 // Default behavior : signal to launcher a projectile is going out of water
@@ -455,11 +480,11 @@ void WeaponLauncher::Draw()
   {
     Point2i p = ActiveCharacter().GetHandPosition() - Camera::GetInstance()->GetPosition();
     // Red color for the blast range (should be superior to the explosion_range)
-    AppWormux::GetInstance()->video->window.CircleColor(p.x, p.y, (int)cfg->blast_range, c_red);
+    GetMainWindow().CircleColor(p.x, p.y, (int)cfg->blast_range, c_red);
     // Yellow color for the blast range (should be superior to the explosion_range)
-    AppWormux::GetInstance()->video->window.CircleColor(p.x, p.y, (int)cfg->explosion_range, c_black);
+    GetMainWindow().CircleColor(p.x, p.y, (int)cfg->explosion_range, c_black);
   }
-  AppWormux::GetInstance()->video->window.CircleColor(GetGunHolePosition().x-Camera::GetInstance()->GetPositionX(), GetGunHolePosition().y-Camera::GetInstance()->GetPositionY(), 5, c_black);
+  GetMainWindow().CircleColor(GetGunHolePosition().x-Camera::GetInstance()->GetPositionX(), GetGunHolePosition().y-Camera::GetInstance()->GetPositionY(), 5, c_black);
 #endif
 }
 
