@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ class WeaponProjectile : public PhysicalObj
     bool explode_with_timeout;
     bool explode_with_collision;
     bool can_drown;
-    bool camera_in_advance;
+    bool camera_follow_closely;
     uint begin_time;
 
     ExplosiveWeaponConfig& cfg;
@@ -68,9 +68,12 @@ class WeaponProjectile : public PhysicalObj
     void ResetTimeOut() { m_timeout_modifier = 0; };
     bool change_timeout_allowed() const;
   protected:
-    virtual void SignalObjectCollision(PhysicalObj * obj, const Point2d& my_speed_before);
+    void Collision();
+
     virtual void SignalGroundCollision(const Point2d& speed_before);
-    virtual void SignalCollision(const Point2d& speed_before);
+    virtual void SignalObjectCollision(const Point2d& my_speed_before,
+				       PhysicalObj * obj,
+				       const Point2d& obj_speed);
     virtual void SignalOutOfMap();
     virtual void SignalTimeout();
     virtual void SignalExplosion();
@@ -95,8 +98,10 @@ class WeaponBullet : public WeaponProjectile
     virtual void Refresh();
   protected:
     virtual void SignalGroundCollision(const Point2d& speed_before);
+    virtual void SignalObjectCollision(const Point2d& my_speed_before,
+				       PhysicalObj * obj,
+				       const Point2d& obj_speed);
     virtual void SignalOutOfMap();
-    virtual void SignalObjectCollision(PhysicalObj * obj, const Point2d& my_speed_before);
     void DoExplosion();
 };
 
@@ -121,7 +126,7 @@ class WeaponLauncher : public Weapon
     virtual void p_Select();
     virtual WeaponProjectile * GetProjectileInstance() = 0;
     virtual bool ReloadLauncher();
-    void Refresh() { };
+    virtual void Refresh() { };
   private:
     void DirectExplosion();
     void NetworkSetTimeoutProjectile() const;
@@ -142,7 +147,7 @@ class WeaponLauncher : public Weapon
     // Signal that a projectile explosion
     virtual void SignalProjectileExplosion() { SignalEndOfProjectile(); };
     // Signal that a projectile fired by this weapon has hit something (ground, character etc)
-    virtual void SignalProjectileCollision(const Point2d& /*speed_before*/) { SignalEndOfProjectile(); };
+    virtual void SignalProjectileCollision() { SignalEndOfProjectile(); };
     // Signal a projectile is drowning
     virtual void SignalProjectileDrowning() { SignalEndOfProjectile(); };
     // Signal a projectile is fishing out of water (supertux)
