@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2008 Wormux Team.
+ *  Copyright (C) 2001-2009 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ WeaponsList::~WeaponsList()
 
 WeaponsList::WeaponsList()
 {
-  weapons_res_profile = resource_manager.LoadXMLProfile( "weapons.xml", false);
+  weapons_res_profile = GetResourceManager().LoadXMLProfile( "weapons.xml", false);
   m_weapons_list.push_back(new Bazooka);
   m_weapons_list.push_back(new SubMachineGun);
   m_weapons_list.push_back(new Gun);
@@ -88,11 +88,28 @@ WeaponsList::WeaponsList()
 
 //-----------------------------------------------------------------------------
 
-void WeaponsList::Refresh () const
+// Static method
+void WeaponsList::LoadXml(const xmlNode* weapons_xml)
 {
-  ActiveTeam().AccessWeapon().Manage();
+  // to destroy all the already loaded weapons
+  // else some parameters may be not overwritten by the new game mode
+  // cf bug #14231
+  delete singleton;
+  singleton = NULL;
+
+  std::list<Weapon*> l_weapons_list = GetInstance()->GetList();
+
+  std::list<Weapon*>::iterator
+    itw = l_weapons_list.begin(),
+    end = l_weapons_list.end();
+
+  for (; itw != end ; ++itw) {
+    (*itw)->LoadXml(weapons_xml);
+  }
 }
 
+//-----------------------------------------------------------------------------
+
 void WeaponsList::UpdateTranslation()
 {
   if (singleton == NULL) return;
